@@ -23,7 +23,7 @@ import java.util.List;
 import java.util.Properties;
 import java.util.TimeZone;
 
-import org.apache.commons.lang.StringUtils;
+import org.apache.commons.lang3.StringUtils;
 import org.dogtagpki.acme.ACMEAccount;
 import org.dogtagpki.acme.ACMEAuthorization;
 import org.dogtagpki.acme.ACMECertificate;
@@ -47,6 +47,9 @@ public class PostgreSQLDatabase extends ACMEDatabase {
     protected Properties statements;
     protected Connection connection;
 
+    Boolean enabled;
+    PostgreSQLConfigMonitor monitor;
+
     public void init() throws Exception {
 
         logger.info("Initializing PostgreSQL database");
@@ -79,6 +82,27 @@ public class PostgreSQLDatabase extends ACMEDatabase {
             String value = statements.getProperty(name);
             logger.info("- " + name + ": " + value);
         }
+
+        String monitorEnabled = config.getParameter("monitor.enabled");
+        logger.info("- monitor enabled: " + monitorEnabled);
+
+        if ("true".equals(monitorEnabled)) {
+
+            monitor = new PostgreSQLConfigMonitor();
+            monitor.setDatabase(this);
+
+            String monitorInterval = config.getParameter("monitor.interval");
+            if (monitorInterval == null) {
+                monitorInterval = PostgreSQLConfigMonitor.DEFAULT_INTERVAL + "";
+            }
+            logger.info("- monitor interval (minutes): " + monitorInterval);
+
+            if (monitorInterval != null) {
+                monitor.setInterval(Integer.parseInt(monitorInterval));
+            }
+
+            new Thread(monitor, "PostgreSQLConfigMonitor").start();
+        }
     }
 
     /**
@@ -156,12 +180,108 @@ public class PostgreSQLDatabase extends ACMEDatabase {
         }
     }
 
-    public void close() throws Exception {
-        if (connection != null) {
-            connection.close();
+    String getConfig(String id) throws Exception {
+
+        logger.info("Getting config " + id);
+
+        String sql = statements.getProperty("getConfig");
+        logger.info("SQL: " + sql);
+
+        try (PreparedStatement ps = connection.prepareStatement(sql)) {
+            ps.setString(1, id);
+
+            try (ResultSet rs = ps.executeQuery()) {
+
+                if (!rs.next()) {
+                    return null;
+                }
+
+                return rs.getString("value");
+            }
         }
     }
 
+    void addConfig(String id, String value) throws Exception {
+
+        logger.info("Setting config " + id + ": " + value);
+
+        String sql = statements.getProperty("addConfig");
+        logger.info("SQL: " + sql);
+
+        try (PreparedStatement ps = connection.prepareStatement(sql)) {
+            ps.setString(1, id);
+            ps.setString(2, value);
+            ps.executeUpdate();
+        }
+    }
+
+    int updateConfig(String id, String value) throws Exception {
+
+        logger.info("Updating config " + id + ": " + value);
+
+        String sql = statements.getProperty("updateConfig");
+        logger.info("SQL: " + sql);
+
+        try (PreparedStatement ps = connection.prepareStatement(sql)) {
+            ps.setString(1, value);
+            ps.setString(2, id);
+            return ps.executeUpdate();
+        }
+    }
+
+    void removeConfig(String id) throws Exception {
+
+        logger.info("Removing config " + id);
+
+        String sql = statements.getProperty("removeConfig");
+        logger.info("SQL: " + sql);
+
+        try (PreparedStatement ps = connection.prepareStatement(sql)) {
+            ps.setString(1, id);
+            ps.executeUpdate();
+        }
+    }
+
+    void setConfig(String id, String value) throws Exception {
+
+        if (value == null) {
+            removeConfig(id);
+            return;
+        }
+
+        int updatedRows = updateConfig(id, value);
+        if (updatedRows > 0) return;
+
+        addConfig(id, value);
+    }
+
+    public Boolean getEnabled() throws Exception {
+
+        // If monitor is not enabled, get config from database on each request.
+        // Otherwise, return the config stored in memory which is updated by
+        // PostgreSQLConfigMonitor.
+
+        if (monitor == null) {
+
+            connect();
+
+            String value = getConfig("enabled");
+            enabled = value == null ? null : Boolean.valueOf(value);
+        }
+
+        return enabled;
+    }
+
+    public void setEnabled(Boolean enabled) throws Exception {
+
+        connect();
+
+        String value = enabled == null ? null : enabled.toString();
+        setConfig("enabled", value);
+
+        this.enabled = enabled;
+    }
+
     private ACMENonce getNonce(String nonceID) throws Exception {
 
         logger.info("Getting nonce " + nonceID);
@@ -181,6 +301,9 @@ public class PostgreSQLDatabase extends ACMEDatabase {
                 ACMENonce nonce = new ACMENonce();
                 nonce.setID(nonceID);
 
+                Timestamp created = rs.getTimestamp("created");
+                nonce.setCreationTime(new Date(created.getTime()));
+
                 Timestamp expires = rs.getTimestamp("expires");
                 nonce.setExpirationTime(new Date(expires.getTime()));
 
@@ -203,8 +326,11 @@ public class PostgreSQLDatabase extends ACMEDatabase {
 
             ps.setString(1, nonceID);
 
+            Date creationTime = nonce.getCreationTime();
+            ps.setTimestamp(2, new Timestamp(creationTime.getTime()), UTC);
+
             Date expirationTime = nonce.getExpirationTime();
-            ps.setTimestamp(2, new Timestamp(expirationTime.getTime()), UTC);
+            ps.setTimestamp(3, new Timestamp(expirationTime.getTime()), UTC);
 
             ps.executeUpdate();
         }
@@ -292,6 +418,10 @@ public class PostgreSQLDatabase extends ACMEDatabase {
                 }
 
                 account.setID(accountID);
+
+                Timestamp created = rs.getTimestamp("created");
+                account.setCreationTime(new Date(created.getTime()));
+
                 account.setStatus(rs.getString("status"));
 
                 String jwk = rs.getString("jwk");
@@ -344,8 +474,12 @@ public class PostgreSQLDatabase extends ACMEDatabase {
         try (PreparedStatement ps = connection.prepareStatement(sql)) {
 
             ps.setString(1, accountID);
-            ps.setString(2, account.getStatus());
-            ps.setString(3, account.getJWK().toJSON());
+
+            Date creationTime = account.getCreationTime();
+            ps.setTimestamp(2, creationTime == null ? null : new Timestamp(creationTime.getTime()), UTC);
+
+            ps.setString(3, account.getStatus());
+            ps.setString(4, account.getJWK().toJSON());
 
             ps.executeUpdate();
         }
@@ -435,6 +569,10 @@ public class PostgreSQLDatabase extends ACMEDatabase {
 
                 order.setID(orderID);
                 order.setAccountID(rs.getString("account_id"));
+
+                Timestamp created = rs.getTimestamp("created");
+                order.setCreationTime(created == null ? null : new Date(created.getTime()));
+
                 order.setStatus(rs.getString("status"));
 
                 Timestamp expires = rs.getTimestamp("expires");
@@ -456,6 +594,54 @@ public class PostgreSQLDatabase extends ACMEDatabase {
         return order;
     }
 
+    public Collection<ACMEOrder> getOrdersByAccount(String accountID) throws Exception {
+
+        connect();
+
+        logger.info("Getting orders for account " + accountID);
+
+        String sql = statements.getProperty("getOrdersByAccount");
+        logger.info("SQL: " + sql);
+
+        Collection<ACMEOrder> orders = new ArrayList<>();
+
+        try (PreparedStatement ps = connection.prepareStatement(sql)) {
+            ps.setString(1, accountID);
+
+            try (ResultSet rs = ps.executeQuery()) {
+
+                while (rs.next()) {
+                    ACMEOrder order = new ACMEOrder();
+                    order.setID(rs.getString("id"));
+                    order.setAccountID(accountID);
+
+                    Timestamp created = rs.getTimestamp("created");
+                    order.setCreationTime(created == null ? null : new Date(created.getTime()));
+
+                    order.setStatus(rs.getString("status"));
+
+                    Timestamp expires = rs.getTimestamp("expires");
+                    order.setExpirationTime(expires == null ? null : new Date(expires.getTime()));
+
+                    Timestamp notBefore = rs.getTimestamp("not_before");
+                    order.setNotBeforeTime(notBefore == null ? null : new Date(notBefore.getTime()));
+
+                    Timestamp notAfter = rs.getTimestamp("not_after");
+                    order.setNotAfterTime(notAfter == null ? null : new Date(notAfter.getTime()));
+
+                    order.setCertID(rs.getString("cert_id"));
+
+                    getOrderIdentifiers(order);
+                    getOrderAuthorizations(order);
+
+                    orders.add(order);
+                }
+            }
+        }
+
+        return orders;
+    }
+
     public Collection<ACMEOrder> getOrdersByAuthorizationAndStatus(String authzID, String status)
             throws Exception {
 
@@ -478,6 +664,10 @@ public class PostgreSQLDatabase extends ACMEDatabase {
                     ACMEOrder order = new ACMEOrder();
                     order.setID(rs.getString("id"));
                     order.setAccountID(rs.getString("account_id"));
+
+                    Timestamp created = rs.getTimestamp("created");
+                    order.setCreationTime(created == null ? null : new Date(created.getTime()));
+
                     order.setStatus(rs.getString("status"));
 
                     Timestamp expires = rs.getTimestamp("expires");
@@ -527,6 +717,10 @@ public class PostgreSQLDatabase extends ACMEDatabase {
 
                 order.setID(rs.getString("id"));
                 order.setAccountID(rs.getString("account_id"));
+
+                Timestamp created = rs.getTimestamp("created");
+                order.setCreationTime(created == null ? null : new Date(created.getTime()));
+
                 order.setStatus(rs.getString("status"));
 
                 Timestamp expires = rs.getTimestamp("expires");
@@ -640,18 +834,22 @@ public class PostgreSQLDatabase extends ACMEDatabase {
 
             ps.setString(1, orderID);
             ps.setString(2, order.getAccountID());
-            ps.setString(3, order.getStatus());
+
+            Date creationTime = order.getCreationTime();
+            ps.setTimestamp(3, creationTime == null ? null : new Timestamp(creationTime.getTime()), UTC);
+
+            ps.setString(4, order.getStatus());
 
             Date expirationTime = order.getExpirationTime();
-            ps.setTimestamp(4, expirationTime == null ? null : new Timestamp(expirationTime.getTime()), UTC);
+            ps.setTimestamp(5, expirationTime == null ? null : new Timestamp(expirationTime.getTime()), UTC);
 
             Date notBefore = order.getNotBeforeTime();
-            ps.setTimestamp(5, notBefore == null ? null : new Timestamp(notBefore.getTime()), UTC);
+            ps.setTimestamp(6, notBefore == null ? null : new Timestamp(notBefore.getTime()), UTC);
 
             Date notAfter = order.getNotAfterTime();
-            ps.setTimestamp(6, notAfter == null ? null : new Timestamp(notAfter.getTime()), UTC);
+            ps.setTimestamp(7, notAfter == null ? null : new Timestamp(notAfter.getTime()), UTC);
 
-            ps.setString(7, order.getCertID());
+            ps.setString(8, order.getCertID());
 
             ps.executeUpdate();
         }
@@ -810,6 +1008,10 @@ public class PostgreSQLDatabase extends ACMEDatabase {
 
                 authorization.setID(authzID);
                 authorization.setAccountID(rs.getString("account_id"));
+
+                Timestamp created = rs.getTimestamp("created");
+                authorization.setCreationTime(created == null ? null : new Date(created.getTime()));
+
                 authorization.setStatus(rs.getString("status"));
 
                 Timestamp expires = rs.getTimestamp("expires");
@@ -852,6 +1054,10 @@ public class PostgreSQLDatabase extends ACMEDatabase {
 
                 authorization.setID(rs.getString("id"));
                 authorization.setAccountID(rs.getString("account_id"));
+
+                Timestamp created = rs.getTimestamp("created");
+                authorization.setCreationTime(created == null ? null : new Date(created.getTime()));
+
                 authorization.setStatus(rs.getString("status"));
 
                 Timestamp expires = rs.getTimestamp("expires");
@@ -917,6 +1123,10 @@ public class PostgreSQLDatabase extends ACMEDatabase {
 
                     authorization.setID(rs.getString("id"));
                     authorization.setAccountID(accountID);
+
+                    Timestamp created = rs.getTimestamp("created");
+                    authorization.setCreationTime(created == null ? null : new Date(created.getTime()));
+
                     authorization.setStatus(rs.getString("status"));
 
                     Timestamp expires = rs.getTimestamp("expires");
@@ -991,17 +1201,21 @@ public class PostgreSQLDatabase extends ACMEDatabase {
 
             ps.setString(1, authzID);
             ps.setString(2, authorization.getAccountID());
-            ps.setString(3, authorization.getStatus());
+
+            Date creationTime = authorization.getCreationTime();
+            ps.setTimestamp(3, creationTime == null ? null : new Timestamp(creationTime.getTime()), UTC);
+
+            ps.setString(4, authorization.getStatus());
 
             Date expirationTime = authorization.getExpirationTime();
-            ps.setTimestamp(4, expirationTime == null ? null : new Timestamp(expirationTime.getTime()), UTC);
+            ps.setTimestamp(5, expirationTime == null ? null : new Timestamp(expirationTime.getTime()), UTC);
 
             ACMEIdentifier identifier = authorization.getIdentifier();
-            ps.setString(5, identifier.getType());
-            ps.setString(6, identifier.getValue());
+            ps.setString(6, identifier.getType());
+            ps.setString(7, identifier.getValue());
 
             Boolean wildcard = authorization.getWildcard();
-            ps.setBoolean(7, wildcard == null ? false : wildcard);
+            ps.setBoolean(8, wildcard == null ? false : wildcard);
 
             ps.executeUpdate();
         }
@@ -1127,6 +1341,10 @@ public class PostgreSQLDatabase extends ACMEDatabase {
 
                 ACMECertificate certificate = new ACMECertificate();
                 certificate.setID(certID);
+
+                Timestamp created = rs.getTimestamp("created");
+                certificate.setCreationTime(created == null ? null : new Date(created.getTime()));
+
                 certificate.setData(rs.getBytes("data"));
 
                 Timestamp expires = rs.getTimestamp("expires");
@@ -1171,10 +1389,14 @@ public class PostgreSQLDatabase extends ACMEDatabase {
         try (PreparedStatement ps = connection.prepareStatement(sql)) {
 
             ps.setString(1, certID);
-            ps.setBytes(2, certificate.getData());
+
+            Date creationTime = certificate.getCreationTime();
+            ps.setTimestamp(2, creationTime == null ? null : new Timestamp(creationTime.getTime()), UTC);
+
+            ps.setBytes(3, certificate.getData());
 
             Date expirationTime = certificate.getExpirationTime();
-            ps.setTimestamp(3, expirationTime == null ? null : new Timestamp(expirationTime.getTime()), UTC);
+            ps.setTimestamp(4, expirationTime == null ? null : new Timestamp(expirationTime.getTime()), UTC);
 
             ps.executeUpdate();
         }
@@ -1207,4 +1429,15 @@ public class PostgreSQLDatabase extends ACMEDatabase {
             removeCertificate(certID);
         }
     }
+
+    public void close() throws Exception {
+
+        if (monitor != null) {
+            monitor.stop();
+        }
+
+        if (connection != null) {
+            connection.close();
+        }
+    }
 }
