@@ -26,6 +26,11 @@ public class ACMEApplication extends Application {
 
         logger.info("Initializing ACMEApplication");
 
+        classes.add(ACMELoginService.class);
+        classes.add(ACMELogoutService.class);
+        classes.add(ACMEEnableService.class);
+        classes.add(ACMEDisableService.class);
+
         classes.add(ACMEDirectoryService.class);
         classes.add(ACMENewNonceService.class);
         classes.add(ACMENewAccountService.class);
@@ -36,6 +41,7 @@ public class ACMEApplication extends Application {
         classes.add(ACMEOrderService.class);
         classes.add(ACMECertificateService.class);
         classes.add(ACMEAccountService.class);
+        classes.add(ACMEAccountOrdersService.class);
         classes.add(ACMERevokeCertificateService.class);
 
         singletons.add(new ACMERequestFilter());
