@@ -11,6 +11,7 @@ import java.io.FileReader;
 import java.math.BigInteger;
 import java.security.KeyFactory;
 import java.security.MessageDigest;
+import java.security.Principal;
 import java.security.PublicKey;
 import java.security.SecureRandom;
 import java.security.Signature;
@@ -25,6 +26,7 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Properties;
+import java.util.Random;
 import java.util.Set;
 import java.util.function.Consumer;
 
@@ -35,9 +37,11 @@ import javax.ws.rs.WebApplicationException;
 import javax.ws.rs.core.Response;
 import javax.ws.rs.core.Response.ResponseBuilder;
 
+import org.apache.catalina.realm.RealmBase;
 import org.apache.commons.codec.binary.Base64;
-import org.apache.commons.lang.NotImplementedException;
-import org.apache.commons.lang.StringUtils;
+import org.apache.commons.lang3.NotImplementedException;
+import org.apache.commons.lang3.RandomStringUtils;
+import org.apache.commons.lang3.StringUtils;
 import org.dogtagpki.acme.ACMEAccount;
 import org.dogtagpki.acme.ACMEAuthorization;
 import org.dogtagpki.acme.ACMEError;
@@ -52,6 +56,8 @@ import org.dogtagpki.acme.database.ACMEDatabase;
 import org.dogtagpki.acme.database.ACMEDatabaseConfig;
 import org.dogtagpki.acme.issuer.ACMEIssuer;
 import org.dogtagpki.acme.issuer.ACMEIssuerConfig;
+import org.dogtagpki.acme.realm.ACMERealm;
+import org.dogtagpki.acme.realm.ACMERealmConfig;
 import org.dogtagpki.acme.scheduler.ACMEScheduler;
 import org.dogtagpki.acme.scheduler.ACMESchedulerConfig;
 import org.dogtagpki.acme.validator.ACMEValidator;
@@ -72,6 +78,8 @@ import org.mozilla.jss.netscape.security.x509.SubjectAlternativeNameExtension;
 import org.mozilla.jss.netscape.security.x509.X500Name;
 import org.mozilla.jss.netscape.security.x509.X509CertImpl;
 
+import com.netscape.cms.tomcat.ProxyRealm;
+
 /**
  * @author Endi S. Dewata
  */
@@ -90,6 +98,8 @@ public class ACMEEngine implements ServletContextListener {
     private Properties monitorsConfig;
     private ACMEEngineConfigSource engineConfigSource = null;
 
+    public Random random;
+
     private ACMEMetadata metadata;
 
     private ACMEDatabaseConfig databaseConfig;
@@ -104,6 +114,9 @@ public class ACMEEngine implements ServletContextListener {
     private ACMESchedulerConfig schedulerConfig;
     private ACMEScheduler scheduler;
 
+    private ACMERealmConfig realmConfig;
+    private ACMERealm realm;
+
     public static ACMEEngine getInstance() {
         return INSTANCE;
     }
@@ -186,6 +199,10 @@ public class ACMEEngine implements ServletContextListener {
         return config.isEnabled();
     }
 
+    public void setEnabled(boolean enabled) {
+        config.setEnabled(enabled);
+    }
+
     public void loadConfig(String filename) throws Exception {
 
         File configFile = new File(filename);
@@ -221,6 +238,10 @@ public class ACMEEngine implements ServletContextListener {
         policy = new ACMEPolicy(policyConfig);
     }
 
+    public void initRandomGenerator() throws Exception {
+        random = SecureRandom.getInstance("pkcs11prng", "Mozilla-JSS");
+    }
+
     public void initMetadata(String filename) throws Exception {
 
         File metadataConfigFile = new File(filename);
@@ -402,6 +423,65 @@ public class ACMEEngine implements ServletContextListener {
         engineConfigSource.init(monitorsConfig);
     }
 
+    public void initRealm(String filename) throws Exception {
+
+        File realmConfigFile = new File(filename);
+
+        if (realmConfigFile.exists()) {
+            logger.info("Loading ACME realm config from " + realmConfigFile);
+            Properties props = new Properties();
+            try (FileReader reader = new FileReader(realmConfigFile)) {
+                props.load(reader);
+            }
+            realmConfig = ACMERealmConfig.fromProperties(props);
+
+        } else {
+            logger.info("Loading default ACME realm config");
+            realmConfig = new ACMERealmConfig();
+        }
+
+        logger.info("Initializing ACME realm");
+
+        String className = realmConfig.getClassName();
+        Class<ACMERealm> realmClass = (Class<ACMERealm>) Class.forName(className);
+
+        realm = realmClass.newInstance();
+        realm.setConfig(realmConfig);
+        realm.init();
+
+        ProxyRealm.registerRealm(name, new RealmBase() {
+            @Override
+            public Principal getPrincipal(String username) {
+                return null;
+            }
+
+            @Override
+            public String getPassword(String username) {
+                return null;
+            }
+
+            @Override
+            public Principal authenticate(String username, String password) {
+                try {
+                    return realm.authenticate(username, password);
+                } catch (Exception e) {
+                    logger.warn("Unable to authenticate with username: " + e.getMessage(), e);
+                    throw new RuntimeException(e);
+                }
+            }
+
+            @Override
+            public Principal authenticate(final X509Certificate[] certs) {
+                try {
+                    return realm.authenticate(certs);
+                } catch (Exception e) {
+                    logger.warn("Unable to authenticate with certificate: " + e.getMessage(), e);
+                    throw new RuntimeException(e);
+                }
+            }
+        });
+    }
+
     public void start() throws Exception {
 
         logger.info("Starting ACME engine");
@@ -413,12 +493,14 @@ public class ACMEEngine implements ServletContextListener {
         logger.info("ACME configuration directory: " + acmeConfDir);
         loadConfig(acmeConfDir + File.separator + "engine.conf");
 
+        initRandomGenerator();
         initMetadata(acmeConfDir + File.separator + "metadata.conf");
         initDatabase(acmeConfDir + File.separator + "database.conf");
         initValidators(acmeConfDir + File.separator + "validators.conf");
         initIssuer(acmeConfDir + File.separator + "issuer.conf");
         initScheduler(acmeConfDir + File.separator + "scheduler.conf");
         initMonitors(acmeConfDir + File.separator + "configsources.conf");
+        initRealm(acmeConfDir + File.separator + "realm.conf");
 
         logger.info("ACME engine started");
     }
@@ -460,10 +542,18 @@ public class ACMEEngine implements ServletContextListener {
         engineConfigSource = null;
     }
 
+    public void shutdownRealm() throws Exception {
+        if (realm == null) return;
+
+        realm.close();
+        realm = null;
+    }
+
     public void stop() throws Exception {
 
         logger.info("Stopping ACME engine");
 
+        shutdownRealm();
         shutdownMonitors();
         shutdownScheduler();
         shutdownIssuer();
@@ -473,8 +563,15 @@ public class ACMEEngine implements ServletContextListener {
         logger.info("ACME engine stopped");
     }
 
+    public String randomAlphanumeric(int length) {
+        // Wrap RandomStringUtils.random instead of calling randomAlphanumeric
+        // so that we control choice of RNG.
+        return RandomStringUtils.random(length, 0, 0, true, true, null, random);
+    }
+
     public ACMENonce createNonce() throws Exception {
 
+        Date currentTime = new Date();
         ACMENonce nonce = new ACMENonce();
 
         // generate 128-bit nonce with JSS
@@ -486,8 +583,9 @@ public class ACMEEngine implements ServletContextListener {
         String nonceID = Base64.encodeBase64URLSafeString(bytes);
 
         nonce.setID(nonceID);
+        nonce.setCreationTime(currentTime);
 
-        Date expirationTime = policy.getNonceExpirationTime(new Date());
+        Date expirationTime = policy.getNonceExpirationTime(currentTime);
         nonce.setExpirationTime(expirationTime);
 
         database.addNonce(nonce);
@@ -726,6 +824,10 @@ public class ACMEEngine implements ServletContextListener {
         return order;
     }
 
+    public Collection<ACMEOrder> getOrdersByAccount(ACMEAccount account) throws Exception {
+        return database.getOrdersByAccount(account.getID());
+    }
+
     public Collection<ACMEOrder> getOrdersByAuthorizationAndStatus(
             ACMEAccount account, String authzID, String status)
             throws Exception {
@@ -782,7 +884,7 @@ public class ACMEEngine implements ServletContextListener {
             logger.info("- " + dnsName);
         }
 
-        // RFC 8555 §7.4 says: The CSR MUST indicate the exact same
+        // RFC 8555 Section 7.4 says: The CSR MUST indicate the exact same
         // set of requested identifiers as the initial newOrder request.
 
         // check for unauthorized names in CSR
@@ -887,7 +989,7 @@ public class ACMEEngine implements ServletContextListener {
                 // with unvalidated SAN values will be passed along to the
                 // CA, and these are likely to be accepted as-is.
                 //
-                // This is also required by RFC 8555 §7.4:
+                // This is also required by RFC 8555 Section 7.4:
                 //
                 //    The CSR MUST indicate the exact same set of requested
                 //    identifiers as the initial newOrder request.
