@@ -17,43 +17,37 @@
 // --- END COPYRIGHT BLOCK ---
 package com.netscape.ca;
 
-import java.lang.reflect.InvocationTargetException;
 import java.security.PublicKey;
 import java.util.Collection;
 
+import org.dogtagpki.server.ca.CAEngine;
 import org.mozilla.jss.CryptoManager;
 import org.mozilla.jss.crypto.CryptoToken;
 import org.mozilla.jss.crypto.PrivateKey;
 import org.mozilla.jss.crypto.X509Certificate;
 
-import com.netscape.certsrv.base.EBaseException;
-import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.ca.AuthorityID;
 import com.netscape.certsrv.ca.CAMissingCertException;
 import com.netscape.certsrv.ca.CAMissingKeyException;
-import com.netscape.cmscore.apps.CMS;
-import com.netscape.cmscore.apps.CMSEngine;
+import com.netscape.cmscore.apps.EngineConfig;
 import com.netscape.cmsutil.crypto.CryptoUtil;
 
 public class KeyRetrieverRunner implements Runnable {
 
     public final static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(KeyRetrieverRunner.class);
 
+    private KeyRetriever keyRetriever;
     private CertificateAuthority certificateAuthority;
     private AuthorityID aid;
     private String nickname;
     private Collection<String> hosts;
 
-    public KeyRetrieverRunner(
-            CertificateAuthority certificateAuthority,
-            AuthorityID aid,
-            String nickname,
-            Collection<String> hosts) {
-
+    public KeyRetrieverRunner(KeyRetriever keyRetriever, CertificateAuthority certificateAuthority) {
+        this.keyRetriever = keyRetriever;
         this.certificateAuthority = certificateAuthority;
-        this.aid = aid;
-        this.nickname = nickname;
-        this.hosts = hosts;
+        this.aid = certificateAuthority.getAuthorityID();
+        this.nickname = certificateAuthority.getNickname();
+        this.hosts = certificateAuthority.getAuthorityKeyHosts();
     }
 
     public void run() {
@@ -72,7 +66,8 @@ public class KeyRetrieverRunner implements Runnable {
 
         } finally {
             // remove self from tracker
-            CertificateAuthority.keyRetrieverThreads.remove(aid);
+            CAEngine engine = CAEngine.getInstance();
+            engine.removeKeyRetriever(aid);
         }
     }
 
@@ -87,54 +82,12 @@ public class KeyRetrieverRunner implements Runnable {
      */
     private boolean _run() {
 
-        String KR_CLASS_KEY = "features.authority.keyRetrieverClass";
-        String KR_CONFIG_KEY = "features.authority.keyRetrieverConfig";
-
-        CMSEngine engine = CMS.getCMSEngine();
-        String className = null;
-
-        try {
-            className = engine.getConfig().getString(KR_CLASS_KEY);
-        } catch (EBaseException e) {
-            logger.warn("Unable to read key retriever class from CS.cfg: " + e.getMessage(), e);
-            return false;
-        }
-
-        IConfigStore krConfig = engine.getConfig().getSubStore(KR_CONFIG_KEY);
-
-        KeyRetriever kr = null;
-        try {
-            Class<? extends KeyRetriever> cls =
-                Class.forName(className).asSubclass(KeyRetriever.class);
-
-            // If there is an accessible constructor that takes
-            // an IConfigStore, invoke that; otherwise invoke
-            // the nullary constructor.
-            try {
-                kr = cls.getDeclaredConstructor(IConfigStore.class)
-                    .newInstance(krConfig);
-            } catch (NoSuchMethodException | SecurityException
-                    | IllegalAccessException e) {
-                kr = cls.newInstance();
-            }
-
-        } catch (ClassNotFoundException e) {
-            logger.warn("Could not find class: " + className, e);
-            return false;
-
-        } catch (ClassCastException e) {
-            logger.warn("Class is not an instance of KeyRetriever: " + className, e);
-            return false;
-
-        } catch (InstantiationException | IllegalAccessException
-                | IllegalArgumentException | InvocationTargetException e) {
-            logger.warn("Could not instantiate class: " + className, e);
-            return false;
-        }
+        CAEngine engine = CAEngine.getInstance();
+        EngineConfig cs = engine.getConfig();
 
         KeyRetriever.Result krr = null;
         try {
-            krr = kr.retrieveKey(nickname, hosts);
+            krr = keyRetriever.retrieveKey(nickname, hosts);
         } catch (Throwable e) {
             logger.warn("Caught exception during execution of KeyRetriever.retrieveKey", e);
             return false;
@@ -157,7 +110,7 @@ public class KeyRetrieverRunner implements Runnable {
             PublicKey pubkey = cert.getPublicKey();
             token.getCryptoStore().deleteCert(cert);
 
-            PrivateKey unwrappingKey = this.certificateAuthority.hostCA.mSigningUnit.getPrivateKey();
+            PrivateKey unwrappingKey = engine.getCA().mSigningUnit.getPrivateKey();
 
             CryptoUtil.importPKIArchiveOptions(
                 token, unwrappingKey, pubkey, paoData);
@@ -171,10 +124,10 @@ public class KeyRetrieverRunner implements Runnable {
         logger.debug("Reinitialising SigningUnit");
 
         /* While we were retrieving the key and cert, the
-         * CertificateAuthority instance in the caMap might
+         * CA instance in the CAEngine might
          * have been replaced, so look it up afresh.
          */
-        CertificateAuthority ca = (CertificateAuthority) this.certificateAuthority.getCA(aid);
+        CertificateAuthority ca = engine.getCA(aid);
         if (ca == null) {
             /* We got the key, but the authority has been
              * deleted.  Do not retry.
@@ -189,8 +142,10 @@ public class KeyRetrieverRunner implements Runnable {
             // key replication if initialisation fails again
             // for some reason
             //
-            logger.info("CertificateAuthority: reinitializing signing unit in KeyRetrieverRunner");
-            ca.initSigUnit();
+            logger.info("CertificateAuthority: reinitializing signing units in KeyRetrieverRunner");
+            ca.initCertSigningUnit();
+            ca.initCRLSigningUnit();
+            ca.initOCSPSigningUnit();
             initSigUnitSucceeded = true;
 
         } catch (CAMissingCertException e) {
@@ -213,7 +168,8 @@ public class KeyRetrieverRunner implements Runnable {
 
         logger.debug("Adding self to authorityKeyHosts attribute");
         try {
-            ca.addInstanceToAuthorityKeyHosts();
+            String host = cs.getHostname() + ":" + engine.getEESSLPort();
+            engine.addAuthorityKeyHost(ca, host);
         } catch (Throwable e) {
             /* We retrieved key, imported it, and successfully
              * re-inited the signing unit.  The only thing that
