@@ -22,6 +22,7 @@ import java.security.NoSuchAlgorithmException;
 import java.security.PublicKey;
 import java.security.SignatureException;
 
+import org.dogtagpki.server.ca.CAEngine;
 import org.mozilla.jss.CryptoManager;
 import org.mozilla.jss.NoSuchTokenException;
 import org.mozilla.jss.NotInitializedException;
@@ -40,7 +41,6 @@ import org.mozilla.jss.netscape.security.x509.X509Key;
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.EPropertyNotFound;
 import com.netscape.certsrv.base.IConfigStore;
-import com.netscape.certsrv.base.ISubsystem;
 import com.netscape.certsrv.ca.CAMissingCertException;
 import com.netscape.certsrv.ca.CAMissingKeyException;
 import com.netscape.certsrv.ca.ECAException;
@@ -48,7 +48,6 @@ import com.netscape.certsrv.logging.ConsoleError;
 import com.netscape.certsrv.logging.SystemEvent;
 import com.netscape.certsrv.security.ISigningUnit;
 import com.netscape.cmscore.apps.CMS;
-import com.netscape.cmscore.apps.CMSEngine;
 import com.netscape.cmsutil.crypto.CryptoUtil;
 
 /**
@@ -73,9 +72,6 @@ public final class SigningUnit implements ISigningUnit {
     private boolean mInited = false;
     private IConfigStore mConfig;
 
-    @SuppressWarnings("unused")
-    private ISubsystem mOwner;
-
     private String mDefSigningAlgname = null;
     private SignatureAlgorithm mDefSigningAlgorithm = null;
 
@@ -120,17 +116,10 @@ public final class SigningUnit implements ISigningUnit {
     }
 
 
-    public void init(ISubsystem owner, IConfigStore config)
-            throws EBaseException {
-        init(owner, config, null);
-    }
+    public void init(IConfigStore config, String nickname) throws EBaseException {
 
-    public void init(ISubsystem owner, IConfigStore config, String nickname)
-            throws EBaseException {
+        logger.debug("CA SigningUnit.init(" + config.getName() + ", " + nickname + ")");
 
-        logger.debug("CA SigningUnit.init(" + owner.getId() + ", " + config.getName() + ", " + nickname + ")");
-
-        mOwner = owner;
         mConfig = config;
 
         String tokenname = null;
@@ -255,7 +244,7 @@ public final class SigningUnit implements ISigningUnit {
      */
     public byte[] sign(byte[] data, String algname)
             throws EBaseException {
-        CMSEngine engine = CMS.getCMSEngine();
+        CAEngine engine = CAEngine.getInstance();
         if (!mInited) {
             throw new EBaseException("CASigningUnit not initialized!");
         }
@@ -328,7 +317,7 @@ public final class SigningUnit implements ISigningUnit {
 
     public boolean verify(byte[] data, byte[] signature, String algname)
             throws EBaseException {
-        CMSEngine engine = CMS.getCMSEngine();
+        CAEngine engine = CAEngine.getInstance();
         if (!mInited) {
             throw new EBaseException("CASigningUnit not initialized!");
         }
