@@ -20,6 +20,7 @@ package com.netscape.cms.servlet.cert;
 import java.io.IOException;
 import java.io.OutputStream;
 import java.math.BigInteger;
+import java.util.Collections;
 import java.util.Date;
 import java.util.Enumeration;
 import java.util.Locale;
@@ -31,8 +32,8 @@ import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
 import org.dogtagpki.server.authentication.AuthToken;
-import org.dogtagpki.server.authentication.IAuthSubsystem;
 import org.dogtagpki.server.authorization.AuthzToken;
+import org.dogtagpki.server.ca.CAEngine;
 import org.dogtagpki.server.ca.ICRLIssuingPoint;
 import org.dogtagpki.server.ca.ICertificateAuthority;
 import org.dogtagpki.server.connector.IRemoteRequest;
@@ -50,12 +51,10 @@ import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.IArgBlock;
 import com.netscape.certsrv.common.ICMSRequest;
 import com.netscape.certsrv.dbs.certdb.ICertRecord;
-import com.netscape.certsrv.dbs.certdb.ICertificateRepository;
 import com.netscape.certsrv.logging.AuditFormat;
 import com.netscape.certsrv.logging.ILogger;
 import com.netscape.certsrv.logging.event.CertStatusChangeRequestEvent;
 import com.netscape.certsrv.logging.event.CertStatusChangeRequestProcessedEvent;
-import com.netscape.certsrv.publish.IPublisherProcessor;
 import com.netscape.certsrv.request.IRequest;
 import com.netscape.certsrv.request.IRequestQueue;
 import com.netscape.certsrv.request.RequestStatus;
@@ -65,7 +64,10 @@ import com.netscape.cms.servlet.common.CMSTemplate;
 import com.netscape.cms.servlet.common.CMSTemplateParams;
 import com.netscape.cms.servlet.common.ECMSGWException;
 import com.netscape.cmscore.apps.CMS;
+import com.netscape.cmscore.authentication.AuthSubsystem;
 import com.netscape.cmscore.base.ArgBlock;
+import com.netscape.cmscore.dbs.CertificateRepository;
+import com.netscape.cmscore.ldap.PublisherProcessor;
 
 /**
  * Revoke a Certificate
@@ -79,10 +81,10 @@ public class DoRevokeTPS extends CMSServlet {
     private static final long serialVersionUID = -2980600514636454836L;
     private final static String TPL_FILE = "revocationResult.template";
 
-    private ICertificateRepository mCertDB = null;
+    private CertificateRepository mCertDB;
     private String mFormPath = null;
     private IRequestQueue mQueue = null;
-    private IPublisherProcessor mPublisherProcessor = null;
+    private PublisherProcessor mPublisherProcessor;
     private String errorString = "error=";
     private String o_status = "status=0";
     private int mTimeLimits = 30; /* in seconds */
@@ -103,10 +105,13 @@ public class DoRevokeTPS extends CMSServlet {
      */
     public void init(ServletConfig sc) throws ServletException {
         super.init(sc);
+
+        CAEngine engine = CAEngine.getInstance();
+
         mFormPath = "/" + mAuthority.getId() + "/" + TPL_FILE;
 
         if (mAuthority instanceof ICertificateAuthority) {
-            mCertDB = ((ICertificateAuthority) mAuthority).getCertificateRepository();
+            mCertDB = engine.getCertificateRepository();
         }
         if (mAuthority instanceof ICertAuthority) {
             mPublisherProcessor = ((ICertAuthority) mAuthority).getPublisherProcessor();
@@ -223,7 +228,7 @@ public class DoRevokeTPS extends CMSServlet {
                 return;
             }
 
-            if (mAuthMgr != null && mAuthMgr.equals(IAuthSubsystem.CERTUSERDB_AUTHMGR_ID)) {
+            if (mAuthMgr != null && mAuthMgr.equals(AuthSubsystem.CERTUSERDB_AUTHMGR_ID)) {
                 if (authToken != null) {
                     authMgr = authToken.getInString(AuthToken.TOKEN_AUTHMGR_INST_NAME);
                     String agentID = authToken.getInString("userid");
@@ -318,6 +323,8 @@ public class DoRevokeTPS extends CMSServlet {
             Locale locale)
             throws EBaseException {
 
+        CAEngine engine = CAEngine.getInstance();
+
         String auditSubjectID = auditSubjectID();
         String auditSerialNumber = auditSerialNumber(null);
         String auditRequestType = auditRequestType(reason);
@@ -658,9 +665,7 @@ public class DoRevokeTPS extends CMSServlet {
 
                 if (mAuthority instanceof ICertificateAuthority) {
                     // let known update and publish status of all crls.
-                    Enumeration<ICRLIssuingPoint> otherCRLs =
-                            ((ICertificateAuthority) mAuthority).getCRLIssuingPoints();
-
+                    Enumeration<ICRLIssuingPoint> otherCRLs = Collections.enumeration(engine.getCRLIssuingPoints());
                     while (otherCRLs.hasMoreElements()) {
                         ICRLIssuingPoint crl = otherCRLs.nextElement();
                         String crlId = crl.getId();
