@@ -20,6 +20,7 @@ package com.netscape.cms.servlet.cert;
 import java.io.IOException;
 import java.io.OutputStream;
 import java.math.BigInteger;
+import java.util.Collections;
 import java.util.Enumeration;
 import java.util.Locale;
 import java.util.StringTokenizer;
@@ -32,6 +33,7 @@ import javax.servlet.http.HttpServletResponse;
 
 import org.dogtagpki.server.authentication.AuthToken;
 import org.dogtagpki.server.authorization.AuthzToken;
+import org.dogtagpki.server.ca.CAEngine;
 import org.dogtagpki.server.ca.ICRLIssuingPoint;
 import org.dogtagpki.server.ca.ICertificateAuthority;
 import org.dogtagpki.server.connector.IRemoteRequest;
@@ -42,12 +44,10 @@ import com.netscape.certsrv.authority.ICertAuthority;
 import com.netscape.certsrv.authorization.EAuthzAccessDenied;
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.common.ICMSRequest;
-import com.netscape.certsrv.dbs.certdb.ICertificateRepository;
 import com.netscape.certsrv.logging.AuditFormat;
 import com.netscape.certsrv.logging.ILogger;
 import com.netscape.certsrv.logging.event.CertStatusChangeRequestEvent;
 import com.netscape.certsrv.logging.event.CertStatusChangeRequestProcessedEvent;
-import com.netscape.certsrv.publish.IPublisherProcessor;
 import com.netscape.certsrv.request.IRequest;
 import com.netscape.certsrv.request.IRequestQueue;
 import com.netscape.certsrv.request.RequestStatus;
@@ -55,6 +55,8 @@ import com.netscape.cms.servlet.base.CMSServlet;
 import com.netscape.cms.servlet.common.CMSRequest;
 import com.netscape.cms.servlet.common.ECMSGWException;
 import com.netscape.cmscore.apps.CMS;
+import com.netscape.cmscore.dbs.CertificateRepository;
+import com.netscape.cmscore.ldap.PublisherProcessor;
 
 /**
  * 'Unrevoke' a certificate. (For certificates that are on-hold only,
@@ -68,10 +70,10 @@ public class DoUnrevokeTPS extends CMSServlet {
     private static final long serialVersionUID = -6245049221697655642L;
 
     @SuppressWarnings("unused")
-    private ICertificateRepository mCertDB;
+    private CertificateRepository mCertDB;
 
     private IRequestQueue mQueue = null;
-    private IPublisherProcessor mPublisherProcessor = null;
+    private PublisherProcessor mPublisherProcessor;
     private String errorString = "error=";
     private String o_status = "status=0";
 
@@ -89,8 +91,11 @@ public class DoUnrevokeTPS extends CMSServlet {
      */
     public void init(ServletConfig sc) throws ServletException {
         super.init(sc);
+
+        CAEngine engine = CAEngine.getInstance();
+
         if (mAuthority instanceof ICertificateAuthority) {
-            mCertDB = ((ICertificateAuthority) mAuthority).getCertificateRepository();
+            mCertDB = engine.getCertificateRepository();
         }
         if (mAuthority instanceof ICertAuthority) {
             mPublisherProcessor = ((ICertAuthority) mAuthority).getPublisherProcessor();
@@ -233,6 +238,8 @@ public class DoUnrevokeTPS extends CMSServlet {
             Locale locale, String initiative)
             throws EBaseException {
 
+        CAEngine engine = CAEngine.getInstance();
+
         String auditSubjectID = auditSubjectID();
         String auditSerialNumber = auditSerialNumber(serialNumbers[0].toString());
         String auditRequestType = OFF_HOLD;
@@ -357,9 +364,7 @@ public class DoUnrevokeTPS extends CMSServlet {
                 }
 
                 // let known update and publish status of all crls.
-                Enumeration<ICRLIssuingPoint> otherCRLs =
-                        ((ICertificateAuthority) mAuthority).getCRLIssuingPoints();
-
+                Enumeration<ICRLIssuingPoint> otherCRLs = Collections.enumeration(engine.getCRLIssuingPoints());
                 while (otherCRLs.hasMoreElements()) {
                     ICRLIssuingPoint crl = otherCRLs.nextElement();
                     String crlId = crl.getId();
