@@ -30,7 +30,8 @@ import java.util.Map;
 
 import javax.servlet.http.HttpServletRequest;
 
-import org.apache.commons.lang.StringUtils;
+import org.apache.commons.lang3.StringUtils;
+import org.dogtagpki.server.ca.CAEngine;
 import org.mozilla.jss.netscape.security.x509.BasicConstraintsExtension;
 import org.mozilla.jss.netscape.security.x509.X509CertImpl;
 
@@ -47,7 +48,7 @@ import com.netscape.certsrv.profile.ProfileAttribute;
 import com.netscape.certsrv.profile.ProfileInput;
 import com.netscape.certsrv.registry.IPluginInfo;
 import com.netscape.certsrv.request.IRequest;
-import com.netscape.cms.profile.IProfileAuthenticator;
+import com.netscape.cms.profile.ProfileAuthenticator;
 import com.netscape.cms.profile.common.EnrollProfile;
 import com.netscape.cms.profile.common.Profile;
 import com.netscape.cms.profile.input.SerialNumRenewInput;
@@ -56,7 +57,6 @@ import com.netscape.cms.servlet.common.AuthCredentials;
 import com.netscape.cms.servlet.common.CMSTemplate;
 import com.netscape.cms.servlet.profile.SSLClientCertProvider;
 import com.netscape.cmscore.apps.CMS;
-import com.netscape.cmscore.apps.CMSEngine;
 import com.netscape.cmscore.registry.PluginRegistry;
 
 public class RenewalProcessor extends CertProcessor {
@@ -89,7 +89,7 @@ public class RenewalProcessor extends CertProcessor {
 
             logger.debug("RenewalProcessor: processRenewal()");
 
-            CMSEngine engine = CMS.getCMSEngine();
+            CAEngine engine = CAEngine.getInstance();
 
             startTiming("enrollment");
             request.setAttribute("reqType", "renewal");
@@ -234,8 +234,8 @@ public class RenewalProcessor extends CertProcessor {
             if (aidString != null)
                 ctx.put(EnrollProfile.REQUEST_AUTHORITY_ID, aidString);
 
-            IProfileAuthenticator authenticator = ps.getProfileAuthenticator(renewProfile);
-            IProfileAuthenticator origAuthenticator = ps.getProfileAuthenticator(profile);
+            ProfileAuthenticator authenticator = ps.getProfileAuthenticator(renewProfile);
+            ProfileAuthenticator origAuthenticator = ps.getProfileAuthenticator(profile);
 
             if (authenticator != null) {
                 logger.debug("RenewalSubmitter: authenticator " + authenticator.getName() + " found");
