@@ -27,6 +27,7 @@ import java.util.Collection;
 import java.util.Date;
 import java.util.Locale;
 
+import org.dogtagpki.server.ca.CAEngine;
 import org.dogtagpki.server.ca.ICertificateAuthority;
 import org.mozilla.jss.netscape.security.x509.CRLExtensions;
 import org.mozilla.jss.netscape.security.x509.CRLReasonExtension;
@@ -41,18 +42,18 @@ import com.netscape.certsrv.base.EPropertyNotFound;
 import com.netscape.certsrv.base.UnauthorizedException;
 import com.netscape.certsrv.dbs.certdb.CertId;
 import com.netscape.certsrv.dbs.certdb.ICertRecord;
-import com.netscape.certsrv.dbs.certdb.ICertificateRepository;
 import com.netscape.certsrv.logging.AuditFormat;
 import com.netscape.certsrv.logging.ILogger;
 import com.netscape.certsrv.logging.event.CertStatusChangeRequestEvent;
 import com.netscape.certsrv.logging.event.CertStatusChangeRequestProcessedEvent;
-import com.netscape.certsrv.publish.IPublisherProcessor;
 import com.netscape.certsrv.request.IRequest;
 import com.netscape.certsrv.request.IRequestQueue;
 import com.netscape.certsrv.request.RequestStatus;
 import com.netscape.certsrv.usrgrp.Certificates;
-import com.netscape.certsrv.usrgrp.IUser;
 import com.netscape.cmscore.apps.CMS;
+import com.netscape.cmscore.dbs.CertificateRepository;
+import com.netscape.cmscore.ldap.PublisherProcessor;
+import com.netscape.cmscore.usrgrp.User;
 
 /**
  * @author Endi S. Dewata
@@ -68,9 +69,9 @@ public class RevocationProcessor extends CertProcessor {
     long startTime;
 
     ICertificateAuthority authority;
-    ICertificateRepository repo;
+    CertificateRepository repo;
     IRequestQueue requestQueue;
-    IPublisherProcessor publisherProcessor;
+    PublisherProcessor publisherProcessor;
 
     String initiative;
     CertId serialNumber;
@@ -95,7 +96,10 @@ public class RevocationProcessor extends CertProcessor {
 
     public void setAuthority(ICertificateAuthority authority) {
         this.authority = authority;
-        repo = authority.getCertificateRepository();
+
+        CAEngine engine = CAEngine.getInstance();
+        repo = engine.getCertificateRepository();
+
         requestQueue = authority.getRequestQueue();
         publisherProcessor = authority.getPublisherProcessor();
     }
@@ -186,7 +190,7 @@ public class RevocationProcessor extends CertProcessor {
             X509Certificate certChain[] = new X509Certificate[1];
             certChain[0] = clientCert;
 
-            IUser user = ul.locateUser(new Certificates(certChain));
+            User user = ul.locateUser(new Certificates(certChain));
             return ug.isMemberOf(user, "Subsystem Group");
 
         } catch (Exception e) {
