@@ -37,7 +37,6 @@ import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
 import org.dogtagpki.server.authentication.AuthToken;
-import org.dogtagpki.server.authentication.IAuthSubsystem;
 import org.dogtagpki.server.ca.CAEngine;
 import org.dogtagpki.server.ca.ICertificateAuthority;
 import org.mozilla.jss.CryptoManager;
@@ -107,20 +106,20 @@ import com.netscape.certsrv.logging.AuditEvent;
 import com.netscape.certsrv.logging.AuditFormat;
 import com.netscape.certsrv.logging.ILogger;
 import com.netscape.certsrv.profile.EProfileException;
-import com.netscape.certsrv.publish.IPublisherProcessor;
 import com.netscape.certsrv.request.IRequest;
 import com.netscape.certsrv.request.IRequestQueue;
 import com.netscape.certsrv.request.RequestId;
 import com.netscape.certsrv.request.RequestStatus;
 import com.netscape.cms.logging.Logger;
 import com.netscape.cms.logging.SignedAuditLogger;
-import com.netscape.cms.profile.IProfileAuthenticator;
+import com.netscape.cms.profile.ProfileAuthenticator;
 import com.netscape.cms.profile.common.EnrollProfile;
 import com.netscape.cms.profile.common.Profile;
 import com.netscape.cms.servlet.profile.SSLClientCertProvider;
 import com.netscape.cmscore.apps.CMS;
-import com.netscape.cmscore.apps.CMSEngine;
+import com.netscape.cmscore.authentication.AuthSubsystem;
 import com.netscape.cmscore.base.ArgBlock;
+import com.netscape.cmscore.ldap.PublisherProcessor;
 import com.netscape.cmscore.profile.ProfileSubsystem;
 import com.netscape.cmscore.security.JssSubsystem;
 import com.netscape.cmscore.security.PWCBsdr;
@@ -157,7 +156,7 @@ public class CRSEnrollment extends HttpServlet {
     protected String mProfileId = null;
     protected ICertAuthority mAuthority;
     protected IConfigStore mConfig = null;
-    protected IAuthSubsystem mAuthSubsystem;
+    protected AuthSubsystem mAuthSubsystem;
     protected String mAppendDN = null;
     protected String mEntryObjectclass = null;
     protected boolean mCreateEntry = false;
@@ -233,7 +232,7 @@ public class CRSEnrollment extends HttpServlet {
         if (crsCA == null)
             crsCA = "ca";
 
-        CAEngine engine = (CAEngine) CMS.getCMSEngine();
+        CAEngine engine = CAEngine.getInstance();
         JssSubsystem jssSubsystem = engine.getJSSSubsystem();
 
         mAuthority = (ICertAuthority) engine.getSubsystem(crsCA);
@@ -296,7 +295,7 @@ public class CRSEnrollment extends HttpServlet {
             mProfileId = sc.getInitParameter("profileId");
             logger.debug("CRSEnrollment: init: mProfileId=" + mProfileId);
 
-            mAuthSubsystem = (IAuthSubsystem) engine.getSubsystem(IAuthSubsystem.ID);
+            mAuthSubsystem = engine.getAuthSubsystem();
             mAuthManagerName = sc.getInitParameter(PROP_CRSAUTHMGR);
             mAppendDN = sc.getInitParameter(PROP_APPENDDN);
             String tmp = sc.getInitParameter(PROP_CREATEENTRY);
@@ -344,7 +343,7 @@ public class CRSEnrollment extends HttpServlet {
                       HttpServletResponse httpResp)
             throws ServletException {
 
-        CMSEngine engine = CMS.getCMSEngine();
+        CAEngine engine = CAEngine.getInstance();
         boolean running_state = engine.isInRunningState();
 
         if (!running_state)
@@ -418,7 +417,7 @@ public class CRSEnrollment extends HttpServlet {
         return allowed;
     }
 
-    public IAuthToken authenticate(AuthCredentials credentials, IProfileAuthenticator authenticator,
+    public IAuthToken authenticate(AuthCredentials credentials, ProfileAuthenticator authenticator,
             HttpServletRequest request) throws EBaseException {
 
         // build credential
@@ -633,7 +632,7 @@ public class CRSEnrollment extends HttpServlet {
                 logger.debug("Found profile '" + mProfileId + "'.");
             }
 
-            IProfileAuthenticator authenticator = null;
+            ProfileAuthenticator authenticator = null;
             try {
                 logger.debug("Retrieving authenticator");
                 authenticator = mProfileSubsystem.getProfileAuthenticator(profile);
@@ -1059,7 +1058,7 @@ public class CRSEnrollment extends HttpServlet {
     private boolean createEntry(String dn) {
         boolean result = false;
 
-        IPublisherProcessor ldapPub = mAuthority.getPublisherProcessor();
+        PublisherProcessor ldapPub = mAuthority.getPublisherProcessor();
         if (ldapPub == null || !ldapPub.isCertPublishingEnabled()) {
             logger.warn("CRSEnrollment: " + CMS.getLogMessage("CMSGW_ERROR_CREATE_ENTRY_FROM_CEP"));
             return result;
@@ -1561,7 +1560,7 @@ public class CRSEnrollment extends HttpServlet {
             }
             Map<String, String> ctx = new HashMap<>();
 
-            IProfileAuthenticator authenticator = null;
+            ProfileAuthenticator authenticator = null;
             try {
                 logger.debug("Retrieving authenticator");
                 authenticator = mProfileSubsystem.getProfileAuthenticator(profile);
