@@ -35,11 +35,10 @@ import java.util.StringTokenizer;
 import javax.servlet.http.HttpServletRequest;
 
 import org.dogtagpki.server.authorization.AuthzToken;
-import org.dogtagpki.server.authorization.IAuthzSubsystem;
 import org.dogtagpki.server.ca.CAEngine;
-import org.dogtagpki.server.ca.ICertificateAuthority;
 import org.mozilla.jss.netscape.security.x509.X509CertImpl;
 
+import com.netscape.ca.CertificateAuthority;
 import com.netscape.certsrv.authentication.EAuthException;
 import com.netscape.certsrv.authentication.IAuthToken;
 import com.netscape.certsrv.base.BadRequestException;
@@ -50,7 +49,6 @@ import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.base.MetaInfo;
 import com.netscape.certsrv.base.SessionContext;
 import com.netscape.certsrv.dbs.certdb.ICertRecord;
-import com.netscape.certsrv.dbs.certdb.ICertificateRepository;
 import com.netscape.certsrv.logging.ILogger;
 import com.netscape.certsrv.logging.event.AuthEvent;
 import com.netscape.certsrv.logging.event.AuthzEvent;
@@ -58,19 +56,21 @@ import com.netscape.certsrv.logging.event.RoleAssumeEvent;
 import com.netscape.certsrv.request.IRequest;
 import com.netscape.certsrv.request.IRequestQueue;
 import com.netscape.certsrv.request.RequestId;
-import com.netscape.certsrv.usrgrp.ICertUserLocator;
-import com.netscape.certsrv.usrgrp.IGroup;
+import com.netscape.certsrv.usrgrp.CertUserLocator;
 import com.netscape.certsrv.util.IStatsSubsystem;
-import com.netscape.cms.profile.IProfileAuthenticator;
+import com.netscape.cms.profile.ProfileAuthenticator;
 import com.netscape.cms.profile.common.Profile;
 import com.netscape.cms.servlet.common.AuthCredentials;
 import com.netscape.cms.servlet.common.CMSGateway;
 import com.netscape.cms.servlet.common.ServletUtils;
 import com.netscape.cmscore.apps.CMS;
-import com.netscape.cmscore.apps.CMSEngine;
 import com.netscape.cmscore.apps.EngineConfig;
+import com.netscape.cmscore.authorization.AuthzSubsystem;
 import com.netscape.cmscore.base.ArgBlock;
+import com.netscape.cmscore.dbs.CertificateRepository;
 import com.netscape.cmscore.profile.ProfileSubsystem;
+import com.netscape.cmscore.usrgrp.ExactMatchCertUserLocator;
+import com.netscape.cmscore.usrgrp.Group;
 import com.netscape.cmscore.usrgrp.UGSubsystem;
 
 public class CAProcessor extends Processor {
@@ -128,14 +128,13 @@ public class CAProcessor extends Processor {
     protected String authMgr;
     protected String getClientCert = "false";
     // subsystems
-    CMSEngine engine = CMS.getCMSEngine();
-    protected ICertificateAuthority authority = (ICertificateAuthority) engine.getSubsystem(ICertificateAuthority.ID);
-    protected IAuthzSubsystem authz = (IAuthzSubsystem) engine.getSubsystem(IAuthzSubsystem.ID);
-    protected UGSubsystem ug = engine.getUGSubsystem();
-    protected ICertUserLocator ul = ug.getCertUserLocator();
+    protected CertificateAuthority authority;
+    protected AuthzSubsystem authz;
+    protected UGSubsystem ug;
+    protected CertUserLocator ul;
     protected IRequestQueue queue;
     protected ProfileSubsystem ps;
-    protected ICertificateRepository certdb;
+    protected CertificateRepository certdb;
 
     //logging and stats
 
@@ -144,9 +143,14 @@ public class CAProcessor extends Processor {
     public CAProcessor(String id, Locale locale) throws EPropertyNotFound, EBaseException {
         super(id, locale);
 
-        CAEngine engine = (CAEngine) CMS.getCMSEngine();
+        CAEngine engine = CAEngine.getInstance();
         EngineConfig config = engine.getConfig();
 
+        authority = engine.getCA();
+        authz = engine.getAuthzSubsystem();
+        ug = engine.getUGSubsystem();
+        ul = new ExactMatchCertUserLocator();
+
         IConfigStore cs = config.getSubStore("processor." + id);
         this.profileID = cs.getString(PROFILE_ID, "").isEmpty() ? null : cs.getString(PROFILE_ID);
         this.authzResourceName = cs.getString(AUTHZ_RESOURCE_NAME, "").isEmpty() ? null :
@@ -181,7 +185,7 @@ public class CAProcessor extends Processor {
             throw new EBaseException("CAProcessor: Profile Subsystem not found");
         }
 
-        certdb = authority.getCertificateRepository();
+        certdb = engine.getCertificateRepository();
         if (certdb == null) {
             throw new EBaseException("CAProcessor: Certificate repository not found");
         }
@@ -204,7 +208,7 @@ public class CAProcessor extends Processor {
      ******************************************/
 
     public void startTiming(String event) {
-        CMSEngine engine = CMS.getCMSEngine();
+        CAEngine engine = CAEngine.getInstance();
         IStatsSubsystem statsSub = (IStatsSubsystem) engine.getSubsystem(IStatsSubsystem.ID);
         if (statsSub != null) {
             statsSub.startTiming(event, true);
@@ -213,7 +217,7 @@ public class CAProcessor extends Processor {
     }
 
     public void endTiming(String event) {
-        CMSEngine engine = CMS.getCMSEngine();
+        CAEngine engine = CAEngine.getInstance();
         IStatsSubsystem statsSub = (IStatsSubsystem) engine.getSubsystem(IStatsSubsystem.ID);
         if (statsSub != null) {
             statsSub.endTiming(event);
@@ -222,7 +226,7 @@ public class CAProcessor extends Processor {
     }
 
     public void endAllEvents() {
-        CMSEngine engine = CMS.getCMSEngine();
+        CAEngine engine = CAEngine.getInstance();
         IStatsSubsystem statsSub = (IStatsSubsystem) engine.getSubsystem(IStatsSubsystem.ID);
         if (statsSub != null) {
             Iterator<String> iter = statEvents.iterator();
@@ -343,7 +347,7 @@ public class CAProcessor extends Processor {
      *   to the session context
      */
     public IAuthToken authenticate(
-            IProfileAuthenticator authenticator,
+            ProfileAuthenticator authenticator,
             HttpServletRequest request,
             IRequest origReq,
             SessionContext context,
@@ -406,7 +410,7 @@ public class CAProcessor extends Processor {
     }
 
     public IAuthToken authenticate(
-            IProfileAuthenticator authenticator,
+            ProfileAuthenticator authenticator,
             HttpServletRequest request,
             AuthCredentials credentials) throws EBaseException {
 
@@ -445,7 +449,7 @@ public class CAProcessor extends Processor {
     public IAuthToken authenticate(
             HttpServletRequest request,
             IRequest origReq,
-            IProfileAuthenticator authenticator,
+            ProfileAuthenticator authenticator,
             SessionContext context,
             boolean isRenewal,
             AuthCredentials credentials) throws EBaseException {
@@ -976,7 +980,7 @@ public class CAProcessor extends Processor {
             return null;
         }
 
-        Enumeration<IGroup> groups = null;
+        Enumeration<Group> groups = null;
 
         try {
             groups = ug.findGroups("*");
@@ -987,7 +991,7 @@ public class CAProcessor extends Processor {
         StringBuffer membersString = new StringBuffer();
 
         while (groups.hasMoreElements()) {
-            IGroup group = groups.nextElement();
+            Group group = groups.nextElement();
 
             if (group.isMember(SubjectID) == true) {
                 if (membersString.length() != 0) {
