@@ -38,9 +38,9 @@ import com.netscape.certsrv.property.IDescriptor;
 import com.netscape.certsrv.request.IRequestQueue;
 import com.netscape.certsrv.template.ArgList;
 import com.netscape.certsrv.template.ArgSet;
-import com.netscape.cms.profile.IProfileAuthenticator;
-import com.netscape.cms.profile.common.ProfileInput;
+import com.netscape.cms.profile.ProfileAuthenticator;
 import com.netscape.cms.profile.common.Profile;
+import com.netscape.cms.profile.common.ProfileInput;
 import com.netscape.cms.profile.common.ProfilePolicy;
 import com.netscape.cms.profile.constraint.PolicyConstraint;
 import com.netscape.cms.profile.def.PolicyDefault;
@@ -87,7 +87,7 @@ public class ProfileSelectServlet extends ProfileServlet {
 
         Locale locale = getLocale(request);
 
-        CAEngine engine = (CAEngine) CMS.getCMSEngine();
+        CAEngine engine = CAEngine.getInstance();
         EngineConfig cs = engine.getConfig();
 
         IAuthToken authToken = null;
@@ -245,7 +245,7 @@ public class ProfileSelectServlet extends ProfileServlet {
 
         // build authentication
         ArgList authlist = new ArgList();
-        IProfileAuthenticator authenticator = null;
+        ProfileAuthenticator authenticator = null;
 
         try {
             authenticator = ps.getProfileAuthenticator(profile);
