@@ -32,7 +32,7 @@ import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
-import org.dogtagpki.server.authorization.IAuthzSubsystem;
+import org.dogtagpki.server.ca.CAEngine;
 
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.logging.ILogger;
@@ -47,8 +47,7 @@ import com.netscape.cms.servlet.base.UserInfo;
 import com.netscape.cms.servlet.common.CMSRequest;
 import com.netscape.cms.servlet.common.CMSTemplate;
 import com.netscape.cms.servlet.common.ServletUtils;
-import com.netscape.cmscore.apps.CMS;
-import com.netscape.cmscore.apps.CMSEngine;
+import com.netscape.cmscore.authorization.AuthzSubsystem;
 
 /**
  * This servlet is the base class of all profile servlets.
@@ -153,7 +152,7 @@ public class ProfileServlet extends CMSServlet {
     protected String mId = null;
     protected String mGetClientCert = "false";
     protected String mAuthMgr = null;
-    protected IAuthzSubsystem mAuthz = null;
+    protected AuthzSubsystem mAuthz;
     protected String mAclMethod = null;
     protected String mAuthzResourceName = null;
     protected LogSource mLogCategory = ILogger.S_OTHER;
@@ -181,8 +180,8 @@ public class ProfileServlet extends CMSServlet {
         mGetClientCert = sc.getInitParameter(PROP_CLIENTAUTH);
         mAuthMgr = sc.getInitParameter(PROP_AUTHMGR);
 
-        CMSEngine engine = CMS.getCMSEngine();
-        mAuthz = (IAuthzSubsystem) engine.getSubsystem(IAuthzSubsystem.ID);
+        CAEngine engine = CAEngine.getInstance();
+        mAuthz = engine.getAuthzSubsystem();
 
         mAuthzResourceName = sc.getInitParameter(PROP_RESOURCEID);
         mProfileSubId = sc.getInitParameter(PROP_PROFILE_SUB_ID);
@@ -259,7 +258,7 @@ public class ProfileServlet extends CMSServlet {
             return;
         }
 
-        CMSEngine engine = CMS.getCMSEngine();
+        CAEngine engine = CAEngine.getInstance();
         IStatsSubsystem statsSub = (IStatsSubsystem) engine.getSubsystem(IStatsSubsystem.ID);
         if (statsSub != null) {
             statsSub.startTiming("output_template");
@@ -384,7 +383,7 @@ public class ProfileServlet extends CMSServlet {
     }
 
     public void startTiming(String event) {
-        CMSEngine engine = CMS.getCMSEngine();
+        CAEngine engine = CAEngine.getInstance();
         IStatsSubsystem statsSub = (IStatsSubsystem) engine.getSubsystem(IStatsSubsystem.ID);
         if (statsSub != null) {
             statsSub.startTiming(event, true);
@@ -393,7 +392,7 @@ public class ProfileServlet extends CMSServlet {
     }
 
     public void endTiming(String event) {
-        CMSEngine engine = CMS.getCMSEngine();
+        CAEngine engine = CAEngine.getInstance();
         IStatsSubsystem statsSub = (IStatsSubsystem) engine.getSubsystem(IStatsSubsystem.ID);
         if (statsSub != null) {
             statsSub.endTiming(event);
