@@ -31,7 +31,7 @@ import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
-import org.dogtagpki.server.authentication.IAuthManager;
+import org.dogtagpki.server.authentication.AuthManager;
 import org.dogtagpki.server.authorization.AuthzToken;
 import org.dogtagpki.server.ca.CAEngine;
 import org.mozilla.jss.asn1.ASN1Util;
@@ -72,7 +72,7 @@ import com.netscape.certsrv.request.RequestId;
 import com.netscape.certsrv.request.RequestStatus;
 import com.netscape.cms.logging.Logger;
 import com.netscape.cms.logging.SignedAuditLogger;
-import com.netscape.cms.profile.IProfileAuthenticator;
+import com.netscape.cms.profile.ProfileAuthenticator;
 import com.netscape.cms.profile.common.EnrollProfile;
 import com.netscape.cms.profile.common.Profile;
 import com.netscape.cms.profile.common.ProfileInput;
@@ -142,7 +142,7 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
 
     }
 
-    private void setCredentialsIntoContext(HttpServletRequest request, IProfileAuthenticator authenticator,
+    private void setCredentialsIntoContext(HttpServletRequest request, ProfileAuthenticator authenticator,
             Map<String, String> ctx) {
         Enumeration<String> authIds = authenticator.getValueNames();
 
@@ -157,7 +157,7 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
         }
     }
 
-    public IAuthToken authenticate(IProfileAuthenticator authenticator,
+    public IAuthToken authenticate(ProfileAuthenticator authenticator,
             HttpServletRequest request) throws EBaseException {
         String method = "ProfileSubmitCMCServlet: authenticate: ";
         AuthCredentials credentials = new AuthCredentials();
@@ -329,7 +329,7 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
 
         logger.debug("ProfileSubmitCMCServlet: SubId=" + mProfileSubId);
 
-        CAEngine engine = (CAEngine) CMS.getCMSEngine();
+        CAEngine engine = CAEngine.getInstance();
         ProfileSubsystem ps = engine.getProfileSubsystem();
 
         if (ps == null) {
@@ -399,7 +399,7 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
             ctx.put("cert_request", Utils.normalizeString(requestB64));
         }
         // passing auths into context
-        IProfileAuthenticator authenticator = null;
+        ProfileAuthenticator authenticator = null;
 
         try {
             authenticator = ps.getProfileAuthenticator(profile);
@@ -510,21 +510,21 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
         ///////////////////////////////////////////////
         // create request
         ///////////////////////////////////////////////
-        String tmpCertSerialS = ctx.get(IAuthManager.CRED_CMC_SIGNING_CERT);
+        String tmpCertSerialS = ctx.get(AuthManager.CRED_CMC_SIGNING_CERT);
         if (tmpCertSerialS != null) {
             // unlikely to happen, but do this just in case
             logger.debug("ProfileSubmitCMCServlet: found existing CRED_CMC_SIGNING_CERT in ctx for CMCUserSignedAuth:" + tmpCertSerialS);
             logger.debug("ProfileSubmitCMCServlet: null it out");
-            ctx.put(IAuthManager.CRED_CMC_SIGNING_CERT, "");
+            ctx.put(AuthManager.CRED_CMC_SIGNING_CERT, "");
         }
 
         String signingCertSerialS = null;
         if (authToken != null) {
-            signingCertSerialS = (String) authToken.get(IAuthManager.CRED_CMC_SIGNING_CERT);
+            signingCertSerialS = (String) authToken.get(AuthManager.CRED_CMC_SIGNING_CERT);
         }
         if (signingCertSerialS != null) {
             logger.debug("ProfileSubmitCMCServlet: setting CRED_CMC_SIGNING_CERT in ctx for CMCUserSignedAuth");
-            ctx.put(IAuthManager.CRED_CMC_SIGNING_CERT, signingCertSerialS);
+            ctx.put(AuthManager.CRED_CMC_SIGNING_CERT, signingCertSerialS);
         }
 
         String tmpSharedTokenAuthenticatedCertSubject = ctx.get(IAuthToken.TOKEN_SHARED_TOKEN_AUTHENTICATED_CERT_SUBJECT);
@@ -728,17 +728,17 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
                     }
                 }
 
-                tmpCertSerialS = reqs[k].getExtDataInString(IAuthManager.CRED_CMC_SIGNING_CERT);
+                tmpCertSerialS = reqs[k].getExtDataInString(AuthManager.CRED_CMC_SIGNING_CERT);
                 if (tmpCertSerialS != null) {
                     // unlikely to happen, but do this just in case
                     logger.debug("ProfileSubmitCMCServlet: found existing CRED_CMC_SIGNING_CERT in request for CMCUserSignedAuth:" + tmpCertSerialS);
                     logger.debug("ProfileSubmitCMCServlet: null it out");
-                    reqs[k].setExtData(IAuthManager.CRED_CMC_SIGNING_CERT, "");
+                    reqs[k].setExtData(AuthManager.CRED_CMC_SIGNING_CERT, "");
                 }
                 // put CMCUserSignedAuth authToken in request
                 if (signingCertSerialS != null) {
                      logger.debug("ProfileSubmitCMCServlet: setting CRED_CMC_SIGNING_CERT in request for CMCUserSignedAuth");
-                     reqs[k].setExtData(IAuthManager.CRED_CMC_SIGNING_CERT, signingCertSerialS);
+                     reqs[k].setExtData(AuthManager.CRED_CMC_SIGNING_CERT, signingCertSerialS);
                  }
 
                 tmpSharedTokenAuthenticatedCertSubject = reqs[k].getExtDataInString(IAuthToken.TOKEN_SHARED_TOKEN_AUTHENTICATED_CERT_SUBJECT);
@@ -756,7 +756,7 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
                 }
                 if (tmpSharedTokenAuthenticatedCertSubject != null) {
                     logger.debug("ProfileSubmitCMCServlet: setting CRED_CMC_SIGNING_CERT in request for CMCUserSignedAuth");
-                    reqs[k].setExtData(IAuthManager.CRED_CMC_SIGNING_CERT, signingCertSerialS);
+                    reqs[k].setExtData(AuthManager.CRED_CMC_SIGNING_CERT, signingCertSerialS);
                 }
             }
 
