@@ -24,12 +24,10 @@ import org.dogtagpki.server.ca.CAEngine;
 import com.netscape.ca.CertificateAuthority;
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.IConfigStore;
-import com.netscape.certsrv.base.ISubsystem;
 import com.netscape.certsrv.request.IPolicy;
 import com.netscape.certsrv.request.IRequest;
 import com.netscape.certsrv.request.PolicyResult;
 import com.netscape.cms.profile.common.Profile;
-import com.netscape.cmscore.apps.CMS;
 import com.netscape.cmscore.profile.ProfileSubsystem;
 
 /**
@@ -65,9 +63,9 @@ public class CAPolicy implements IPolicy {
         return mPolicies;
     }
 
-    public void init(ISubsystem owner, IConfigStore config)
+    public void init(CertificateAuthority owner, IConfigStore config)
             throws EBaseException {
-        mCA = (CertificateAuthority) owner;
+        mCA = owner;
         mConfig = config;
 
         String processorType = // XXX - need to upgrade 4.2
@@ -106,7 +104,7 @@ public class CAPolicy implements IPolicy {
                 r.getRequestId().toString() + ",requestStatus=" +
                 r.getRequestStatus().toString() + ")");
 
-        CAEngine engine = (CAEngine) CMS.getCMSEngine();
+        CAEngine engine = CAEngine.getInstance();
         if (isProfileRequest(r)) {
             logger.debug("CAPolicy: Profile-base Request " +
                     r.getRequestId().toString());
