@@ -30,10 +30,12 @@ import java.util.Map;
 import javax.ws.rs.core.GenericEntity;
 import javax.ws.rs.core.Response;
 
+import org.dogtagpki.server.ca.CAEngine;
 import org.dogtagpki.server.ca.ICertificateAuthority;
 import org.mozilla.jss.netscape.security.util.Utils;
 import org.mozilla.jss.netscape.security.x509.X500Name;
 
+import com.netscape.ca.CertificateAuthority;
 import com.netscape.certsrv.authentication.IAuthToken;
 import com.netscape.certsrv.authority.AuthorityData;
 import com.netscape.certsrv.authority.AuthorityResource;
@@ -61,7 +63,6 @@ import com.netscape.certsrv.logging.AuditEvent;
 import com.netscape.certsrv.logging.ILogger;
 import com.netscape.cms.servlet.base.SubsystemService;
 import com.netscape.cmscore.apps.CMS;
-import com.netscape.cmscore.apps.CMSEngine;
 
 /**
  * @author ftweedal
@@ -69,38 +70,54 @@ import com.netscape.cmscore.apps.CMSEngine;
 public class AuthorityService extends SubsystemService implements AuthorityResource {
 
     public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(AuthorityService.class);
-    ICertificateAuthority hostCA;
+
+    CertificateAuthority hostCA;
 
     public AuthorityService() {
-        CMSEngine engine = CMS.getCMSEngine();
-        hostCA = (ICertificateAuthority) engine.getSubsystem(ICertificateAuthority.ID);
+        CAEngine engine = CAEngine.getInstance();
+        hostCA = engine.getCA();
     }
 
     @Override
     public Response findCAs(String id, String parentID, String dn, String issuerDN) throws Exception {
 
+        logger.info("AuthorityService: getting authorities:");
+
         X500Name x500dn = dn == null ? null : new X500Name(dn);
         X500Name x500issuerDN = issuerDN == null ? null : new X500Name(issuerDN);
 
         List<AuthorityData> results = new ArrayList<>();
 
-        for (ICertificateAuthority ca : hostCA.getCAs()) {
+        CAEngine engine = CAEngine.getInstance();
+        for (CertificateAuthority ca : engine.getCAs()) {
 
             AuthorityData authority = readAuthorityData(ca);
 
+            // search by ID
             if (id != null && !id.equalsIgnoreCase(authority.getID())) continue;
+
+            // search by parent ID
             if (parentID != null && !parentID.equalsIgnoreCase(authority.getParentID())) continue;
 
+            // search by DN
             if (x500dn != null) {
                 X500Name caDN = new X500Name(authority.getDN());
                 if (!x500dn.equals(caDN)) continue;
             }
 
+            // search by issuer DN
             if (x500issuerDN != null) {
                 X500Name caIssuerDN = new X500Name(authority.getIssuerDN());
                 if (!x500issuerDN.equals(caIssuerDN)) continue;
             }
 
+            logger.info("AuthorityService: - ID: " + authority.getID());
+            logger.info("AuthorityService:   DN: " + authority.getDN());
+            if (authority.getParentID() != null) {
+                logger.info("AuthorityService:   Parent ID: " + authority.getParentID());
+            }
+            logger.info("AuthorityService:   Issuer DN: " + authority.getIssuerDN());
+
             results.add(authority);
         }
 
@@ -112,7 +129,11 @@ public class AuthorityService extends SubsystemService implements AuthorityResou
 
     @Override
     public Response getCA(String aidString) {
-        ICertificateAuthority ca = hostCA;
+
+        logger.info("AuthorityService: getting authority " + aidString + ":");
+
+        CAEngine engine = CAEngine.getInstance();
+        CertificateAuthority ca = engine.getCA();
 
         if (!AuthorityResource.HOST_AUTHORITY.equals(aidString)) {
             AuthorityID aid;
@@ -122,16 +143,28 @@ public class AuthorityService extends SubsystemService implements AuthorityResou
                 throw new BadRequestException("Bad AuthorityID: " + aidString);
             }
 
-            ca = hostCA.getCA(aid);
+            ca = engine.getCA(aid);
+
             if (ca == null)
                 throw new ResourceNotFoundException("CA \"" + aidString + "\" not found");
         }
 
-        return createOKResponse(readAuthorityData(ca));
+        AuthorityData authority = readAuthorityData(ca);
+
+        logger.info("AuthorityService:   DN: " + authority.getDN());
+        if (authority.getParentID() != null) {
+            logger.info("AuthorityService:   Parent ID: " + authority.getParentID());
+        }
+        logger.info("AuthorityService:   Issuer DN: " + authority.getIssuerDN());
+
+        return createOKResponse(authority);
     }
 
     @Override
     public Response getCert(String aidString) {
+
+        logger.info("AuthorityService: getting cert for authority " + aidString);
+
         AuthorityID aid;
         try {
             aid = new AuthorityID(aidString);
@@ -139,7 +172,9 @@ public class AuthorityService extends SubsystemService implements AuthorityResou
             throw new BadRequestException("Bad AuthorityID: " + aidString);
         }
 
-        ICertificateAuthority ca = hostCA.getCA(aid);
+        CAEngine engine = CAEngine.getInstance();
+        CertificateAuthority ca = engine.getCA(aid);
+
         if (ca == null)
             throw new ResourceNotFoundException("CA \"" + aidString + "\" not found");
 
@@ -164,6 +199,9 @@ public class AuthorityService extends SubsystemService implements AuthorityResou
 
     @Override
     public Response getChain(String aidString) {
+
+        logger.info("AuthorityService: getting cert chain for authority " + aidString);
+
         AuthorityID aid;
         try {
             aid = new AuthorityID(aidString);
@@ -171,7 +209,9 @@ public class AuthorityService extends SubsystemService implements AuthorityResou
             throw new BadRequestException("Bad AuthorityID: " + aidString);
         }
 
-        ICertificateAuthority ca = hostCA.getCA(aid);
+        CAEngine engine = CAEngine.getInstance();
+        CertificateAuthority ca = engine.getCA(aid);
+
         if (ca == null)
             throw new ResourceNotFoundException("CA \"" + aidString + "\" not found");
 
@@ -198,6 +238,9 @@ public class AuthorityService extends SubsystemService implements AuthorityResou
 
     @Override
     public Response createCA(AuthorityData data) {
+
+        logger.info("AuthorityService: creating authority " + data.getDN());
+
         String parentAIDString = data.getParentID();
         AuthorityID parentAID = null;
         if (AuthorityResource.HOST_AUTHORITY.equals(parentAIDString)) {
@@ -221,8 +264,12 @@ public class AuthorityService extends SubsystemService implements AuthorityResou
             SessionContext.getContext().get(SessionContext.AUTH_TOKEN);
 
         try {
-            ICertificateAuthority subCA = hostCA.createCA(
-                authToken, data.getDN(), parentAID, data.getDescription());
+            CAEngine engine = CAEngine.getInstance();
+            CertificateAuthority subCA = engine.createCA(
+                    parentAID,
+                    authToken,
+                    data.getDN(),
+                    data.getDescription());
             audit(ILogger.SUCCESS, OpDef.OP_ADD,
                     subCA.getAuthorityID().toString(), auditParams);
             return createOKResponse(readAuthorityData(subCA));
@@ -247,6 +294,9 @@ public class AuthorityService extends SubsystemService implements AuthorityResou
 
     @Override
     public Response modifyCA(String aidString, AuthorityData data) {
+
+        logger.info("AuthorityService: modifying authority " + aidString);
+
         AuthorityID aid = null;
         try {
             aid = new AuthorityID(aidString);
@@ -254,21 +304,28 @@ public class AuthorityService extends SubsystemService implements AuthorityResou
             throw new BadRequestException("Bad AuthorityID: " + aidString);
         }
 
-        ICertificateAuthority ca = hostCA.getCA(aid);
+        CAEngine engine = CAEngine.getInstance();
+        CertificateAuthority ca = engine.getCA(aid);
+
         if (ca == null)
             throw new ResourceNotFoundException("CA \"" + aidString + "\" not found");
 
         Map<String, String> auditParams = new LinkedHashMap<>();
-        if (data.getEnabled() != ca.getAuthorityEnabled())
+        if (data.getEnabled() != ca.getAuthorityEnabled()) {
+            logger.info("AuthorityService:   enabled: " + data.getEnabled());
             auditParams.put("enabled", data.getEnabled().toString());
+        }
+
         String curDesc = ca.getAuthorityDescription();
         String newDesc = data.getDescription();
         if (curDesc != null && !curDesc.equals(newDesc)
-                || curDesc == null && newDesc != null)
+                || curDesc == null && newDesc != null) {
+            logger.info("AuthorityService:   description: " + data.getDescription());
             auditParams.put("description", data.getDescription());
+        }
 
         try {
-            ca.modifyAuthority(data.getEnabled(), data.getDescription());
+            engine.modifyAuthority(ca, data.getEnabled(), data.getDescription());
             audit(ILogger.SUCCESS, OpDef.OP_MODIFY, ca.getAuthorityID().toString(), auditParams);
             return createOKResponse(readAuthorityData(ca));
         } catch (CATypeException e) {
@@ -304,6 +361,9 @@ public class AuthorityService extends SubsystemService implements AuthorityResou
 
     @Override
     public Response renewCA(String aidString) {
+
+        logger.info("AuthorityService: renewing cert for authority " + aidString);
+
         AuthorityID aid = null;
         try {
             aid = new AuthorityID(aidString);
@@ -311,7 +371,9 @@ public class AuthorityService extends SubsystemService implements AuthorityResou
             throw new BadRequestException("Bad AuthorityID: " + aidString);
         }
 
-        ICertificateAuthority ca = hostCA.getCA(aid);
+        CAEngine engine = CAEngine.getInstance();
+        CertificateAuthority ca = engine.getCA(aid);
+
         if (ca == null)
             throw new ResourceNotFoundException("CA \"" + aidString + "\" not found");
 
@@ -336,6 +398,9 @@ public class AuthorityService extends SubsystemService implements AuthorityResou
 
     @Override
     public Response deleteCA(String aidString) {
+
+        logger.info("AuthorityService: deleting authority " + aidString);
+
         AuthorityID aid = null;
         try {
             aid = new AuthorityID(aidString);
@@ -343,7 +408,9 @@ public class AuthorityService extends SubsystemService implements AuthorityResou
             throw new BadRequestException("Bad AuthorityID: " + aidString);
         }
 
-        ICertificateAuthority ca = hostCA.getCA(aid);
+        CAEngine engine = CAEngine.getInstance();
+        CertificateAuthority ca = engine.getCA(aid);
+
         if (ca == null)
             throw new ResourceNotFoundException("CA \"" + aidString + "\" not found");
 
@@ -418,5 +485,4 @@ public class AuthorityService extends SubsystemService implements AuthorityResou
                 auditor.getParamString(ScopeDef.SC_AUTHORITY, op, id, params));
         signedAuditLogger.log(msg);
     }
-
 }
