@@ -28,10 +28,10 @@ import javax.ws.rs.PathParam;
 import javax.ws.rs.core.Response;
 
 import org.dogtagpki.server.ca.CAEngine;
-import org.dogtagpki.server.ca.ICertificateAuthority;
 import org.jboss.resteasy.plugins.providers.atom.Link;
 import org.mozilla.jss.netscape.security.x509.X500Name;
 
+import com.netscape.ca.CertificateAuthority;
 import com.netscape.certsrv.authentication.EAuthException;
 import com.netscape.certsrv.authorization.EAuthzException;
 import com.netscape.certsrv.base.BadRequestDataException;
@@ -66,7 +66,6 @@ import com.netscape.certsrv.request.RequestNotFoundException;
 import com.netscape.cms.profile.common.Profile;
 import com.netscape.cms.servlet.base.PKIService;
 import com.netscape.cmscore.apps.CMS;
-import com.netscape.cmscore.apps.CMSEngine;
 import com.netscape.cmscore.profile.ProfileSubsystem;
 import com.netscape.cmsutil.ldap.LDAPUtil;
 
@@ -128,8 +127,8 @@ public class CertRequestService extends PKIService implements CertRequestResourc
         if (aidString != null && adnString != null)
             throw new BadRequestException("Cannot provide both issuer-id and issuer-dn");
 
-        CMSEngine engine = CMS.getCMSEngine();
-        ICertificateAuthority ca = (ICertificateAuthority) engine.getSubsystem(ICertificateAuthority.ID);
+        CAEngine engine = CAEngine.getInstance();
+        CertificateAuthority ca = engine.getCA();
 
         AuthorityID aid = null;
         if (aidString != null) {
@@ -138,7 +137,9 @@ public class CertRequestService extends PKIService implements CertRequestResourc
             } catch (IllegalArgumentException e) {
                 throw new BadRequestException("invalid AuthorityID: " + aidString, e);
             }
-            ca = ca.getCA(aid);
+
+            ca = engine.getCA(aid);
+
             if (ca == null)
                 throw new ResourceNotFoundException("CA not found: " + aidString);
         }
@@ -150,9 +151,12 @@ public class CertRequestService extends PKIService implements CertRequestResourc
             } catch (IOException e) {
                 throw new BadRequestException("invalid DN: " + adnString, e);
             }
-            ca = ca.getCA(adn);
+
+            ca = engine.getCA(adn);
+
             if (ca == null)
                 throw new ResourceNotFoundException("CA not found: " + adnString);
+
             aid = ca.getAuthorityID();
         }
 
@@ -423,7 +427,7 @@ public class CertRequestService extends PKIService implements CertRequestResourc
             throw new BadRequestException(message);
         }
 
-        CAEngine engine = (CAEngine) CMS.getCMSEngine();
+        CAEngine engine = CAEngine.getInstance();
         ProfileSubsystem ps = engine.getProfileSubsystem();
 
         if (ps == null) {
@@ -484,7 +488,7 @@ public class CertRequestService extends PKIService implements CertRequestResourc
         start = start == null ? DEFAULT_START : start;
         size = size == null ? DEFAULT_PAGESIZE : size;
 
-        CAEngine engine = (CAEngine) CMS.getCMSEngine();
+        CAEngine engine = CAEngine.getInstance();
         ProfileSubsystem ps = engine.getProfileSubsystem();
 
         if (ps == null) {
