@@ -37,7 +37,7 @@ import javax.ws.rs.core.UriBuilder;
 import javax.ws.rs.core.UriInfo;
 
 import org.apache.catalina.realm.GenericPrincipal;
-import org.apache.commons.lang.StringUtils;
+import org.apache.commons.lang3.StringUtils;
 import org.dogtagpki.server.ca.CAEngine;
 import org.jboss.resteasy.plugins.providers.atom.Link;
 
@@ -92,7 +92,7 @@ public class ProfileService extends SubsystemService implements ProfileResource
     private ProfileSubsystem ps;
 
     public ProfileService() {
-        CAEngine engine = (CAEngine) CMS.getCMSEngine();
+        CAEngine engine = CAEngine.getInstance();
         registry = engine.getPluginRegistry();
         ps = engine.getProfileSubsystem();
     }
@@ -358,7 +358,7 @@ public class ProfileService extends SubsystemService implements ProfileResource
     public static ProfileDataInfo createProfileDataInfo(String profileId, boolean visibleOnly, UriInfo uriInfo,
             Locale locale) throws EBaseException {
 
-        CAEngine engine = (CAEngine) CMS.getCMSEngine();
+        CAEngine engine = CAEngine.getInstance();
         ProfileSubsystem ps = engine.getProfileSubsystem();
 
         if (profileId == null) {
@@ -617,7 +617,7 @@ public class ProfileService extends SubsystemService implements ProfileResource
             try {
                 PropConfigStore tempConfig = new PropConfigStore();
                 tempConfig.load(new ByteArrayInputStream(data));
-                tempProfile.init(ps, tempConfig);
+                tempProfile.init(tempConfig);
 
             } catch (Exception e) {
                 String message = "Unable to create profile: " + e.getMessage();
@@ -747,7 +747,7 @@ public class ProfileService extends SubsystemService implements ProfileResource
             try {
                 PropConfigStore tempConfig = new PropConfigStore();
                 tempConfig.load(new ByteArrayInputStream(data));
-                tempProfile.init(ps, tempConfig);
+                tempProfile.init(tempConfig);
             } catch (Exception e) {
                 throw new BadRequestException("Invalid profile data", e);
             }
