@@ -18,9 +18,6 @@
 
 package org.dogtagpki.server.rest;
 
-import java.net.MalformedURLException;
-import java.net.URISyntaxException;
-
 import javax.servlet.http.HttpSession;
 import javax.ws.rs.core.Response;
 
@@ -28,6 +25,7 @@ import org.dogtagpki.common.CAInfo;
 import org.dogtagpki.common.CAInfoResource;
 import org.dogtagpki.common.KRAInfo;
 import org.dogtagpki.common.KRAInfoClient;
+import org.dogtagpki.server.ca.CAEngine;
 import org.mozilla.jss.crypto.EncryptionAlgorithm;
 import org.mozilla.jss.crypto.KeyWrapAlgorithm;
 import org.slf4j.Logger;
@@ -41,8 +39,6 @@ import com.netscape.certsrv.client.PKIClient;
 import com.netscape.certsrv.system.KRAConnectorInfo;
 import com.netscape.cms.servlet.admin.KRAConnectorProcessor;
 import com.netscape.cms.servlet.base.PKIService;
-import com.netscape.cmscore.apps.CMS;
-import com.netscape.cmscore.apps.CMSEngine;
 import com.netscape.cmscore.apps.EngineConfig;
 import com.netscape.cmsutil.crypto.CryptoUtil;
 
@@ -129,7 +125,7 @@ public class CAInfoService extends PKIService implements CAInfoResource {
 
     private static void queryKRAInfo(KRAConnectorInfo connInfo) throws Exception {
 
-        CMSEngine engine = CMS.getCMSEngine();
+        CAEngine engine = CAEngine.getInstance();
         EngineConfig cs = engine.getConfig();
 
         KRAInfoClient kraInfoClient = getKRAInfoClient(connInfo);
@@ -178,10 +174,9 @@ public class CAInfoService extends PKIService implements CAInfoResource {
     /**
      * Construct KRAInfoClient given KRAConnectorInfo
      */
-    private static KRAInfoClient getKRAInfoClient(KRAConnectorInfo connInfo)
-            throws MalformedURLException, URISyntaxException, EBaseException {
+    private static KRAInfoClient getKRAInfoClient(KRAConnectorInfo connInfo) throws Exception {
 
-        CMSEngine engine = CMS.getCMSEngine();
+        CAEngine engine = CAEngine.getInstance();
         EngineConfig cs = engine.getConfig();
         IConfigStore kraConnectorConfig = cs.getSubStore(KRAConnectorProcessor.PREFIX);
 
