@@ -99,8 +99,12 @@ class SecurityDomainSubsystem(object):
 
     def get_host(self, hostname, secure_port):
 
+        logger.info('Searching for %s:%s', hostname, secure_port)
+
         for host in self.hosts.values():
 
+            logger.info('- %s:%s', host.Hostname, host.SecurePort)
+
             if host.Hostname != hostname:
                 continue
 
@@ -109,7 +113,8 @@ class SecurityDomainSubsystem(object):
 
             return host
 
-        return None
+        raise Exception('Unable to find security domain host: %s:%s' %
+                        (hostname, secure_port))
 
     @classmethod
     def from_json(cls, json_value):
@@ -299,17 +304,6 @@ class SecurityDomainClient(object):
         return InstallToken.from_json(response.json())
 
 
-class CloneSetupRequest(object):
-    def __init__(self):
-        self.domainInfo = None
-        self.installToken = None
-
-
-class DatabaseSetupRequest(object):
-    def __init__(self):
-        pass
-
-
 class CertificateSetupRequest(object):
     def __init__(self):
         self.installToken = None
@@ -331,17 +325,6 @@ class AdminSetupResponse(object):
         pass
 
 
-class SecurityDomainSetupRequest(object):
-    def __init__(self):
-        self.installToken = None
-        self.clone = 'false'
-
-
-class DatabaseUserSetupRequest(object):
-    def __init__(self):
-        pass
-
-
 class FinalizeConfigRequest(object):
     def __init__(self):
         self.installToken = None
@@ -374,14 +357,10 @@ class SystemConfigClient(object):
 
         self.connection = connection
 
-        self.configure_url = '/rest/installer/configure'
-        self.setup_clone_url = '/rest/installer/setupClone'
-        self.setup_database_url = '/rest/installer/setupDatabase'
         self.setup_cert_url = '/rest/installer/setupCert'
         self.setup_admin_url = '/rest/installer/setupAdmin'
         self.backup_keys_url = '/rest/installer/backupKeys'
         self.setup_security_domain_url = '/rest/installer/setupSecurityDomain'
-        self.setup_db_user_url = '/rest/installer/setupDatabaseUser'
         self.finalize_config_url = '/rest/installer/finalizeConfiguration'
 
         if connection.subsystem is None:
@@ -389,46 +368,12 @@ class SystemConfigClient(object):
             if subsystem is None:
                 raise Exception('Missing subsystem for SystemConfigClient')
 
-            self.configure_url = '/' + subsystem + self.configure_url
-            self.setup_clone_url = '/' + subsystem + self.setup_clone_url
-            self.setup_database_url = '/' + subsystem + self.setup_database_url
             self.setup_cert_url = '/' + subsystem + self.setup_cert_url
             self.setup_admin_url = '/' + subsystem + self.setup_admin_url
             self.backup_keys_url = '/' + subsystem + self.backup_keys_url
             self.setup_security_domain_url = '/' + subsystem + self.setup_security_domain_url
-            self.setup_db_user_url = '/' + subsystem + self.setup_db_user_url
             self.finalize_config_url = '/' + subsystem + self.finalize_config_url
 
-    def setupClone(self, request):
-        """
-        Set up clone.
-
-        :param request: Clone setup request
-        :type request: CloneSetupRequest
-        """
-        data = json.dumps(request, cls=pki.encoder.CustomTypeEncoder)
-        headers = {'Content-type': 'application/json',
-                   'Accept': 'application/json'}
-        self.connection.post(
-            self.setup_clone_url,
-            data,
-            headers)
-
-    def setupDatabase(self, request):
-        """
-        Set up database.
-
-        :param request: Database setup request
-        :type request: DatabaseSetupRequest
-        """
-        data = json.dumps(request, cls=pki.encoder.CustomTypeEncoder)
-        headers = {'Content-type': 'application/json',
-                   'Accept': 'application/json'}
-        self.connection.post(
-            self.setup_database_url,
-            data,
-            headers)
-
     def setupCert(self, request):
         """
         Set up certificate.
@@ -468,36 +413,6 @@ class SystemConfigClient(object):
             headers)
         return response.json()
 
-    def setupSecurityDomain(self, request):
-        """
-        Setup security domain.
-
-        :param request: Security domain setup request
-        :type request: SecurityDomainSetupRequest
-        """
-        data = json.dumps(request, cls=pki.encoder.CustomTypeEncoder)
-        headers = {'Content-type': 'application/json',
-                   'Accept': 'application/json'}
-        self.connection.post(
-            self.setup_security_domain_url,
-            data,
-            headers)
-
-    def setupDatabaseUser(self, request):
-        """
-        Set up database user.
-
-        :param request: Database user setup request
-        :type request: DatabaseUserSetupRequest
-        """
-        data = json.dumps(request, cls=pki.encoder.CustomTypeEncoder)
-        headers = {'Content-type': 'application/json',
-                   'Accept': 'application/json'}
-        self.connection.post(
-            self.setup_db_user_url,
-            data,
-            headers)
-
     def finalizeConfiguration(self, request):
         """
         Finalize server configuration.
@@ -551,13 +466,9 @@ pki.encoder.NOTYPES['DomainInfo'] = DomainInfo
 pki.encoder.NOTYPES['SecurityDomainSubsystem'] = SecurityDomainSubsystem
 pki.encoder.NOTYPES['SecurityDomainHost'] = SecurityDomainHost
 pki.encoder.NOTYPES['InstallToken'] = InstallToken
-pki.encoder.NOTYPES['CloneSetupRequest'] = CloneSetupRequest
-pki.encoder.NOTYPES['DatabaseSetupRequest'] = DatabaseSetupRequest
 pki.encoder.NOTYPES['CertificateSetupRequest'] = CertificateSetupRequest
 pki.encoder.NOTYPES['CertificateSetupResponse'] = CertificateSetupResponse
 pki.encoder.NOTYPES['AdminSetupRequest'] = AdminSetupRequest
 pki.encoder.NOTYPES['AdminSetupResponse'] = AdminSetupResponse
-pki.encoder.NOTYPES['SecurityDomainSetupRequest'] = SecurityDomainSetupRequest
-pki.encoder.NOTYPES['DatabaseUserSetupRequest'] = DatabaseUserSetupRequest
 pki.encoder.NOTYPES['FinalizeConfigRequest'] = FinalizeConfigRequest
 pki.encoder.NOTYPES['SystemCertData'] = SystemCertData
