@@ -17,16 +17,29 @@
 // --- END COPYRIGHT BLOCK ---
 package com.netscape.admin.certsrv.config;
 
-import com.netscape.management.client.util.*;
-import com.netscape.certsrv.common.*;
-import com.netscape.admin.certsrv.*;
-import com.netscape.admin.certsrv.connection.*;
-import javax.swing.*;
-import java.awt.*;
-import java.awt.event.*;
+import java.awt.Color;
+import java.awt.GridBagConstraints;
+import java.awt.GridBagLayout;
+import java.awt.Insets;
+import java.awt.event.ActionEvent;
 import java.util.StringTokenizer;
 import java.util.Vector;
 
+import javax.swing.JCheckBox;
+import javax.swing.JLabel;
+import javax.swing.JPanel;
+import javax.swing.JTextField;
+
+import com.netscape.admin.certsrv.CMSAdminUtil;
+import com.netscape.admin.certsrv.CMSBaseResourceModel;
+import com.netscape.admin.certsrv.EAdminException;
+import com.netscape.admin.certsrv.connection.AdminConnection;
+import com.netscape.certsrv.common.Constants;
+import com.netscape.certsrv.common.DestDef;
+import com.netscape.certsrv.common.NameValuePairs;
+import com.netscape.certsrv.common.ScopeDef;
+import com.netscape.management.client.util.Debug;
+
 /**
  * CRL Publishing Setting Panel
  *
@@ -105,8 +118,8 @@ public class CMSCRLSettingPanel extends CMSBaseTab {
         JPanel schemaPanel = new JPanel();
         schemaPanel.setBorder(makeTitledBorder("SCHEMA"));
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTH;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.anchor = GridBagConstraints.NORTH;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.weightx = 1.0;
         gbc.weighty = 0.0;
         gb.setConstraints(schemaPanel, gbc);
@@ -119,8 +132,8 @@ public class CMSCRLSettingPanel extends CMSBaseTab {
         // enable CRL generation
         CMSAdminUtil.resetGBC(gbc);
         JLabel enableCRLLabel = makeJLabel("CRL");
-        gbc.anchor = gbc.EAST;
-        gbc.fill = gbc.NONE;
+        gbc.anchor = GridBagConstraints.EAST;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.gridx = 0;
         gbc.weightx = 0.0;
         gbc.gridwidth = 1;
@@ -128,10 +141,10 @@ public class CMSCRLSettingPanel extends CMSBaseTab {
         schemaPanel.add(enableCRLLabel, gbc );
 
         mEnableCRL = makeJCheckBox();
-        gbc.anchor = gbc.WEST;
+        gbc.anchor = GridBagConstraints.WEST;
         gbc.gridx++;
         gbc.weightx = 1.0;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.insets = new Insets(COMPONENT_SPACE,COMPONENT_SPACE,0,COMPONENT_SPACE);
         schemaPanel.add(mEnableCRL, gbc);
 
@@ -139,8 +152,8 @@ public class CMSCRLSettingPanel extends CMSBaseTab {
         // generate full CRL every X deltas
         CMSAdminUtil.resetGBC(gbc);
         mCRLGenLabel = makeJLabel("GENERATION");
-        gbc.anchor = gbc.EAST;
-        gbc.fill = gbc.NONE;
+        gbc.anchor = GridBagConstraints.EAST;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.gridx = 0;
         gbc.weightx = 0.0;
         gbc.gridwidth = 1;
@@ -148,17 +161,17 @@ public class CMSCRLSettingPanel extends CMSBaseTab {
         schemaPanel.add(mCRLGenLabel, gbc );
 
         mCRLGen = makeJTextField(5);
-        gbc.anchor = gbc.WEST;
+        gbc.anchor = GridBagConstraints.WEST;
         gbc.gridx++;
         gbc.insets = new Insets(COMPONENT_SPACE,COMPONENT_SPACE,0,0);
         schemaPanel.add(mCRLGen, gbc);
         mActiveColor = mCRLGen.getBackground();
 
         mDeltaGenLabel = makeJLabel("DELTAS");
-        gbc.anchor = gbc.WEST;
+        gbc.anchor = GridBagConstraints.WEST;
         gbc.gridx++;
         gbc.weightx = 1.0;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.insets = new Insets(COMPONENT_SPACE,COMPONENT_SPACE,0,COMPONENT_SPACE);
         schemaPanel.add(mDeltaGenLabel, gbc);
 
@@ -166,8 +179,8 @@ public class CMSCRLSettingPanel extends CMSBaseTab {
         // Extend next update time
         CMSAdminUtil.resetGBC(gbc);
         mExtendNextUpdateLabel = makeJLabel("NEXTTIME");
-        gbc.anchor = gbc.EAST;
-        gbc.fill = gbc.NONE;
+        gbc.anchor = GridBagConstraints.EAST;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.gridx = 0;
         gbc.weightx = 0.0;
         gbc.gridwidth = 1;
@@ -175,10 +188,10 @@ public class CMSCRLSettingPanel extends CMSBaseTab {
         schemaPanel.add(mExtendNextUpdateLabel, gbc );
 
         mExtendNextUpdate = makeJCheckBox();
-        gbc.anchor = gbc.WEST;
+        gbc.anchor = GridBagConstraints.WEST;
         gbc.gridx++;
         gbc.weightx = 1.0;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.insets = new Insets(COMPONENT_SPACE,COMPONENT_SPACE,0,COMPONENT_SPACE);
         schemaPanel.add(mExtendNextUpdate, gbc);
 
@@ -187,9 +200,9 @@ public class CMSCRLSettingPanel extends CMSBaseTab {
         JPanel freqPanel = new JPanel();
         freqPanel.setBorder(makeTitledBorder("FREQ"));
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTH;
-        gbc.gridwidth = gbc.REMAINDER;
-        gbc.gridheight = gbc.REMAINDER;
+        gbc.anchor = GridBagConstraints.NORTH;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
+        gbc.gridheight = GridBagConstraints.REMAINDER;
         gbc.weightx = 1.0;
         gbc.weighty = 1.0;
         gb.setConstraints(freqPanel, gbc);
@@ -203,10 +216,10 @@ public class CMSCRLSettingPanel extends CMSBaseTab {
         // update every time
         CMSAdminUtil.resetGBC(gbc);
         mAlways = makeJCheckBox("ALWAYS");
-        gbc.anchor = gbc.WEST;
-        gbc.fill = gbc.NONE;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.gridx = 0;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.insets = new Insets(COMPONENT_SPACE,DIFFERENT_COMPONENT_SPACE,0,COMPONENT_SPACE);
         freqPanel.add(mAlways, gbc);
 
@@ -214,8 +227,8 @@ public class CMSCRLSettingPanel extends CMSBaseTab {
         // update at specified time
         CMSAdminUtil.resetGBC(gbc);
         mDaily = makeJCheckBox("DAILY");
-        gbc.anchor = gbc.WEST;
-        gbc.fill = gbc.NONE;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.gridx = 0;
         gbc.weightx = 0.0;
         gbc.gridwidth = 1;
@@ -223,17 +236,17 @@ public class CMSCRLSettingPanel extends CMSBaseTab {
         freqPanel.add(mDaily, gbc);
 
         mDailyAt = makeJTextField(30);
-        gbc.anchor = gbc.WEST;
+        gbc.anchor = GridBagConstraints.WEST;
         gbc.gridx++;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.insets = new Insets(COMPONENT_SPACE,COMPONENT_SPACE,0,COMPONENT_SPACE);
         freqPanel.add(mDailyAt, gbc);
 
 
         // update by time interval
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.WEST;
-        gbc.fill = gbc.NONE;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.gridx = 0;
         gbc.weightx = 0.0;
         gbc.gridwidth = 1;
@@ -242,16 +255,16 @@ public class CMSCRLSettingPanel extends CMSBaseTab {
         freqPanel.add(mEnableFreq, gbc);
 
         mFrequency = makeJTextField(5);
-        gbc.anchor = gbc.WEST;
+        gbc.anchor = GridBagConstraints.WEST;
         gbc.gridx++;
         gbc.insets = new Insets(COMPONENT_SPACE,COMPONENT_SPACE,0,0);
         freqPanel.add(mFrequency, gbc);
 
         mMinLabel = makeJLabel("MINUTES");
-        gbc.anchor = gbc.WEST;
+        gbc.anchor = GridBagConstraints.WEST;
         gbc.gridx++;
         gbc.weightx = 1.0;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.insets = new Insets(COMPONENT_SPACE,COMPONENT_SPACE,0,COMPONENT_SPACE);
         freqPanel.add(mMinLabel, gbc);
 
@@ -259,8 +272,8 @@ public class CMSCRLSettingPanel extends CMSBaseTab {
         // next update grace period
         CMSAdminUtil.resetGBC(gbc);
         mGracePeriodLabel = makeJLabel("GRACEPERIOD");
-        gbc.anchor = gbc.WEST;
-        gbc.fill = gbc.NONE;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.gridx = 0;
         // gbc.gridx = 2;
         gbc.weightx = 0.0;
@@ -269,24 +282,24 @@ public class CMSCRLSettingPanel extends CMSBaseTab {
         freqPanel.add(mGracePeriodLabel, gbc);
 
         mGracePeriod = makeJTextField(5);
-        gbc.anchor = gbc.WEST;
+        gbc.anchor = GridBagConstraints.WEST;
         gbc.gridx++;
         gbc.insets = new Insets(COMPONENT_SPACE,COMPONENT_SPACE,0,0);
         freqPanel.add(mGracePeriod, gbc);
 
         mGracePeriodMinLabel = makeJLabel("MINUTES");
-        gbc.anchor = gbc.WEST;
+        gbc.anchor = GridBagConstraints.WEST;
         gbc.gridx++;
         gbc.weightx = 1.0;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.insets = new Insets(COMPONENT_SPACE,COMPONENT_SPACE,0,COMPONENT_SPACE);
         freqPanel.add(mGracePeriodMinLabel, gbc);
 
         // next update as this update extension
         CMSAdminUtil.resetGBC(gbc);
         mNextAsThisUpdateExtensionLabel = makeJLabel("NEXTASTHISEXTENSION");
-        gbc.anchor = gbc.WEST;
-        gbc.fill = gbc.NONE;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.gridx = 0;
         // gbc.gridx = 2;
         gbc.weightx = 0.0;
@@ -295,16 +308,16 @@ public class CMSCRLSettingPanel extends CMSBaseTab {
         freqPanel.add(mNextAsThisUpdateExtensionLabel, gbc);
 
         mNextAsThisUpdateExtension = makeJTextField(5);
-        gbc.anchor = gbc.WEST;
+        gbc.anchor = GridBagConstraints.WEST;
         gbc.gridx++;
         gbc.insets = new Insets(COMPONENT_SPACE,COMPONENT_SPACE,0,0);
         freqPanel.add(mNextAsThisUpdateExtension, gbc);
 
         mNextAsThisUpdateExtensionMinLabel = makeJLabel("MINUTES");
-        gbc.anchor = gbc.WEST;
+        gbc.anchor = GridBagConstraints.WEST;
         gbc.gridx++;
         gbc.weightx = 1.0;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.insets = new Insets(COMPONENT_SPACE,COMPONENT_SPACE,0,COMPONENT_SPACE);
         freqPanel.add(mNextAsThisUpdateExtensionMinLabel, gbc);
 
@@ -442,11 +455,11 @@ public class CMSCRLSettingPanel extends CMSBaseTab {
         return trimmed;
     }
 
-    private Vector checkTimeList(String list) {
+    private Vector<Integer> checkTimeList(String list) {
         if (list == null || list.length() == 0) return null;
         if (list.charAt(0) == ',' || list.charAt(list.length()-1) == ',') return null;
 
-        Vector listedTimes = new Vector();
+        Vector<Integer> listedTimes = new Vector<>();
 
         StringTokenizer days = new StringTokenizer(list, ";");
         while (days.hasMoreTokens()) {
@@ -503,7 +516,7 @@ public class CMSCRLSettingPanel extends CMSBaseTab {
                 return false;
             }
 
-            Vector daily = null;
+            Vector<Integer> daily = null;
             if (mDaily.isSelected()) {
                 if (mDailyAt.getText().trim().equals("")) {
                     showMessageDialog("BLANKDAILY");
@@ -538,7 +551,7 @@ public class CMSCRLSettingPanel extends CMSBaseTab {
                 }
                 if (mDaily.isSelected() && daily != null && daily.size() == 1 &&
                     (freq >= 1440 ||
-                     freq + ((Integer)(daily.elementAt(0))).intValue() >= 1440)) {
+                     freq + (daily.elementAt(0)).intValue() >= 1440)) {
                     showMessageDialog("INTERVALTOBIG");
                     return false;
                 }
