@@ -17,16 +17,40 @@
 // --- END COPYRIGHT BLOCK ---
 package com.netscape.admin.certsrv.config;
 
-import com.netscape.admin.certsrv.*;
-import com.netscape.admin.certsrv.connection.*;
-import javax.swing.*;
-import javax.swing.event.*;
-import java.awt.event.*;
-import java.awt.*;
-import java.util.*;
+import java.awt.Color;
+import java.awt.GridBagConstraints;
+import java.awt.GridBagLayout;
+import java.awt.Insets;
+import java.awt.event.ActionEvent;
+import java.awt.event.ActionListener;
+import java.util.StringTokenizer;
+import java.util.Vector;
 
-import com.netscape.management.client.util.*;
-import com.netscape.certsrv.common.*;
+import javax.swing.JButton;
+import javax.swing.JComboBox;
+import javax.swing.JFrame;
+import javax.swing.JLabel;
+import javax.swing.JOptionPane;
+import javax.swing.JPanel;
+import javax.swing.JScrollPane;
+import javax.swing.JTabbedPane;
+import javax.swing.JTable;
+import javax.swing.JTextArea;
+import javax.swing.JTextField;
+import javax.swing.ListSelectionModel;
+import javax.swing.ScrollPaneConstants;
+import javax.swing.event.ChangeEvent;
+import javax.swing.event.ChangeListener;
+
+import com.netscape.admin.certsrv.CMSAdminUtil;
+import com.netscape.admin.certsrv.EAdminException;
+import com.netscape.admin.certsrv.connection.AdminConnection;
+import com.netscape.certsrv.common.Constants;
+import com.netscape.certsrv.common.DestDef;
+import com.netscape.certsrv.common.NameValuePairs;
+import com.netscape.certsrv.common.ScopeDef;
+import com.netscape.management.client.util.Debug;
+import com.netscape.management.client.util.JButtonFactory;
 
 /**
  * Policy Parameter Configuration Dialog
@@ -41,7 +65,7 @@ public class ProfileEditDialog extends CMSBaseConfigDialog
     protected JButton mRefresh, mOrder, mHelp;
     protected JTextField mAuthField=null,mNameField=null, mDescField=null, mConfigField=null;
     protected JLabel mVisibleLabel=null,mAuthLabel=null,mNameLabel=null, mDescLabel = null, mConfigLabel =null;
-    protected JComboBox mVisibleField = null;
+    protected JComboBox<String> mVisibleField = null;
     protected JTable mPolicyTable=null, mInputTable=null, mOutputTable=null,
       mAuthTable=null;
 
@@ -87,18 +111,18 @@ public class ProfileEditDialog extends CMSBaseConfigDialog
         mPluginLabel.setVisible(false);
         mPluginName = new JTextField();
 
-        gbc.fill = gbc.NONE;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weightx = 0.0;
         gbc.gridwidth = 1;
-        gbc.anchor = gbc.EAST;
+        gbc.anchor = GridBagConstraints.EAST;
         gbc.insets = new Insets(CMSAdminUtil.COMPONENT_SPACE,
                                  CMSAdminUtil.COMPONENT_SPACE,0,0);
         mListPanel.add(mRulenameCaption, gbc);
 
-        gbc.anchor = gbc.WEST;
-        gbc.fill = gbc.HORIZONTAL;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.fill = GridBagConstraints.HORIZONTAL;
         gbc.weightx = 1.0;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.insets = new Insets(CMSAdminUtil.COMPONENT_SPACE,
                                  CMSAdminUtil.COMPONENT_SPACE,
                                  0,CMSAdminUtil.COMPONENT_SPACE);
@@ -111,18 +135,18 @@ public class ProfileEditDialog extends CMSBaseConfigDialog
          "NAMENAME", null);
         mNameLabel.addMouseListener(this);
 
-        gbc.fill = gbc.NONE;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weightx = 0.0;
         gbc.gridwidth = 1;
-        gbc.anchor = gbc.EAST;
+        gbc.anchor = GridBagConstraints.EAST;
         gbc.insets = new Insets(CMSAdminUtil.COMPONENT_SPACE,
                                  CMSAdminUtil.COMPONENT_SPACE,0,0);
         mListPanel.add( mNameLabel, gbc );
 
-        gbc.anchor = gbc.WEST;
-        gbc.fill = gbc.HORIZONTAL;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.fill = GridBagConstraints.HORIZONTAL;
         gbc.weightx = 1.0;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         mNameField = new JTextField();
         mListPanel.add( mNameField, gbc );
 
@@ -132,18 +156,18 @@ public class ProfileEditDialog extends CMSBaseConfigDialog
          "DESCNAME", null);
         mDescLabel.addMouseListener(this);
 
-        gbc.fill = gbc.NONE;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weightx = 0.0;
         gbc.gridwidth = 1;
-        gbc.anchor = gbc.EAST;
+        gbc.anchor = GridBagConstraints.EAST;
         gbc.insets = new Insets(CMSAdminUtil.COMPONENT_SPACE,
                                  CMSAdminUtil.COMPONENT_SPACE,0,0);
         mListPanel.add( mDescLabel, gbc );
 
-        gbc.anchor = gbc.WEST;
-        gbc.fill = gbc.HORIZONTAL;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.fill = GridBagConstraints.HORIZONTAL;
         gbc.weightx = 1.0;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         mDescField = new JTextField();
         mListPanel.add( mDescField, gbc );
 
@@ -153,20 +177,20 @@ public class ProfileEditDialog extends CMSBaseConfigDialog
          "VISIBLENAME", null);
         mVisibleLabel.addMouseListener(this);
 
-        gbc.fill = gbc.NONE;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weightx = 0.0;
         gbc.gridwidth = 1;
-        gbc.anchor = gbc.EAST;
+        gbc.anchor = GridBagConstraints.EAST;
         gbc.insets = new Insets(CMSAdminUtil.COMPONENT_SPACE,
                                  CMSAdminUtil.COMPONENT_SPACE,0,0);
         mListPanel.add( mVisibleLabel, gbc );
 
-        gbc.anchor = gbc.WEST;
-        gbc.fill = gbc.HORIZONTAL;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.fill = GridBagConstraints.HORIZONTAL;
         gbc.weightx = 1.0;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         String[] item = {"true", "false"};
-        mVisibleField = new JComboBox(item);
+        mVisibleField = new JComboBox<>(item);
         mListPanel.add( mVisibleField, gbc );
 
 	// auth
@@ -175,18 +199,18 @@ public class ProfileEditDialog extends CMSBaseConfigDialog
          "AUTHNAME", null);
         mAuthLabel.addMouseListener(this);
 
-        gbc.fill = gbc.NONE;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weightx = 0.0;
         gbc.gridwidth = 1;
-        gbc.anchor = gbc.EAST;
+        gbc.anchor = GridBagConstraints.EAST;
         gbc.insets = new Insets(CMSAdminUtil.COMPONENT_SPACE,
                                  CMSAdminUtil.COMPONENT_SPACE,0,0);
         mListPanel.add( mAuthLabel, gbc );
 
-        gbc.anchor = gbc.WEST;
-        gbc.fill = gbc.HORIZONTAL;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.fill = GridBagConstraints.HORIZONTAL;
         gbc.weightx = 1.0;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         mAuthField = new JTextField();
         mListPanel.add( mAuthField, gbc );
 
@@ -220,30 +244,30 @@ public class ProfileEditDialog extends CMSBaseConfigDialog
          "IMPLNAME", null);
         mImplnameCaption.addMouseListener(this);
 
-        gbc.fill = gbc.NONE;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weightx = 0.0;
         gbc.gridwidth = 1;
-        gbc.anchor = gbc.EAST;
+        gbc.anchor = GridBagConstraints.EAST;
         gbc.insets = new Insets(CMSAdminUtil.COMPONENT_SPACE,
                                  CMSAdminUtil.COMPONENT_SPACE,0,0);
         mListPanel.add( mImplnameCaption, gbc );
 
-        gbc.anchor = gbc.WEST;
-        gbc.fill = gbc.HORIZONTAL;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.fill = GridBagConstraints.HORIZONTAL;
         gbc.weightx = 1.0;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         mImplName = new JLabel();
         mListPanel.add( mImplName, gbc );
 
         /* Tab */
         mTabbedPane = new JTabbedPane();
-        Vector policyColNames = new Vector();
+        Vector<String> policyColNames = new Vector<>();
         policyColNames.addElement("Set Id");
         policyColNames.addElement("Id");
         policyColNames.addElement("Defaults");
         policyColNames.addElement("Constraints");
-        Vector policyData = new Vector();
-        Vector policyRow = new Vector();
+        Vector<Vector<Object>> policyData = new Vector<>();
+        Vector<Object> policyRow = new Vector<>();
         policyRow.addElement("p1");
         policyRow.addElement("p1");
         policyRow.addElement("NoDefault");
@@ -260,11 +284,11 @@ public class ProfileEditDialog extends CMSBaseConfigDialog
         JPanel lpanel = createListPanel(mPolicyTable, buttonPanel,
           policyColNames, policyData);
 
-        Vector inputColNames = new Vector();
+        Vector<String> inputColNames = new Vector<>();
         inputColNames.addElement("Id");
         inputColNames.addElement("Inputs");
-        Vector inputData = new Vector();
-        Vector inputRow = new Vector();
+        Vector<Vector<Object>> inputData = new Vector<>();
+        Vector<Object> inputRow = new Vector<>();
         inputRow.addElement("i1");
         inputRow.addElement("NoInput");
         inputData.addElement(inputRow);
@@ -279,11 +303,11 @@ public class ProfileEditDialog extends CMSBaseConfigDialog
         JPanel lpanel1 = createListPanel(mInputTable, buttonPanel1,
           inputColNames, inputData);
 
-        Vector outputColNames = new Vector();
+        Vector<String> outputColNames = new Vector<>();
         outputColNames.addElement("Id");
         outputColNames.addElement("Outputs");
-        Vector outputData = new Vector();
-        Vector outputRow = new Vector();
+        Vector<Vector<Object>> outputData = new Vector<>();
+        Vector<Object> outputRow = new Vector<>();
         outputRow.addElement("i1");
         outputRow.addElement("NoOutput");
         outputData.addElement(outputRow);
@@ -302,9 +326,9 @@ public class ProfileEditDialog extends CMSBaseConfigDialog
 //        JPanel lpanel2 = createOutputPanel();
 //        JPanel lpanel3 = createAuthPanel();
         CMSAdminUtil.resetGBC(gbc);
-        gbc.fill = gbc.BOTH;
-        gbc.anchor = gbc.WEST;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.fill = GridBagConstraints.BOTH;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.weightx = 1.0;
         gbc.weighty = 1.0;
         mTabbedPane.addTab(mResource.getString(PREFIX+"_POLICIES_TAB"), lpanel);
@@ -343,9 +367,9 @@ public class ProfileEditDialog extends CMSBaseConfigDialog
         GridBagConstraints gbc2 = new GridBagConstraints();
 
         CMSAdminUtil.resetGBC(gbc2);
-        gbc2.fill = gbc.BOTH;
-        gbc2.anchor = gbc.WEST;
-        gbc2.gridwidth = gbc.REMAINDER;
+        gbc2.fill = GridBagConstraints.BOTH;
+        gbc2.anchor = GridBagConstraints.WEST;
+        gbc2.gridwidth = GridBagConstraints.REMAINDER;
         gbc2.weightx = 1.0;
         gbc2.weighty = 1.0;
         gb2.setConstraints(mHelpLabel, gbc2);
@@ -353,9 +377,9 @@ public class ProfileEditDialog extends CMSBaseConfigDialog
         mHelpPanel.add(mHelpLabel);
 
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.SOUTH;
-        gbc.gridwidth = gbc.REMAINDER;
-        gbc.gridheight = gbc.REMAINDER;
+        gbc.anchor = GridBagConstraints.SOUTH;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
+        gbc.gridheight = GridBagConstraints.REMAINDER;
         gbc.weightx = 1.0;
         gbc.weighty = 0.0;
         gb.setConstraints(mHelpPanel, gbc);
@@ -378,10 +402,10 @@ public class ProfileEditDialog extends CMSBaseConfigDialog
     }
 
     public JPanel createListPanel(JTable table, JPanel buttonPanel,
-      Vector column, Vector datav)
+      Vector<String> column, Vector<Vector<Object>> datav)
     {
-        Vector colNames = column;
-        Vector data = datav;
+        Vector<String> colNames = column;
+        Vector<Vector<Object>> data = datav;
 
         JPanel listPanel = new JPanel();
         GridBagLayout gb = new GridBagLayout();
@@ -390,8 +414,8 @@ public class ProfileEditDialog extends CMSBaseConfigDialog
 
         //center table
         JScrollPane mScrollPane = JTable.createScrollPaneForTable(table);
-        mScrollPane.setHorizontalScrollBarPolicy(mScrollPane.HORIZONTAL_SCROLLBAR_NEVER);
-        mScrollPane.setVerticalScrollBarPolicy(mScrollPane.VERTICAL_SCROLLBAR_ALWAYS);
+        mScrollPane.setHorizontalScrollBarPolicy(ScrollPaneConstants.HORIZONTAL_SCROLLBAR_NEVER);
+        mScrollPane.setVerticalScrollBarPolicy(ScrollPaneConstants.VERTICAL_SCROLLBAR_ALWAYS);
         table.setAutoscrolls(true);
         table.sizeColumnsToFit(true);
         table.getSelectionModel().setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
@@ -400,8 +424,8 @@ public class ProfileEditDialog extends CMSBaseConfigDialog
         table.addMouseListener(this);
 
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTH;
-        gbc.fill = gbc.BOTH;
+        gbc.anchor = GridBagConstraints.NORTH;
+        gbc.fill = GridBagConstraints.BOTH;
         gbc.gridwidth = 1;
         gbc.weightx = 1.0;
         gbc.insets = CMSAdminUtil.DEFAULT_EMPTY_INSETS;
@@ -409,9 +433,9 @@ public class ProfileEditDialog extends CMSBaseConfigDialog
         listPanel.add(mScrollPane);
 
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTH;
-        gbc.gridwidth = gbc.REMAINDER;
-        gbc.gridheight = gbc.REMAINDER;
+        gbc.anchor = GridBagConstraints.NORTH;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
+        gbc.gridheight = GridBagConstraints.REMAINDER;
         gbc.weightx = 0.0;
         gbc.weighty = 1.0;
         gbc.insets = CMSAdminUtil.DEFAULT_EMPTY_INSETS;
@@ -873,7 +897,7 @@ public class ProfileEditDialog extends CMSBaseConfigDialog
         colNames.addElement("Id");
         colNames.addElement("Defaults");
         colNames.addElement("Constraints");
-        Vector<Vector<String>> d = new Vector<Vector<String>>();
+        Vector<Vector<Object>> d = new Vector<>();
 
         for (String entry : response.keySet()) {
             entry = entry.trim();
@@ -884,7 +908,7 @@ public class ProfileEditDialog extends CMSBaseConfigDialog
             StringTokenizer st = new StringTokenizer(value, ";");
             String def = st.nextToken();
             String con = st.nextToken();
-            Vector<String> row = new Vector<String>();
+            Vector<Object> row = new Vector<>();
 
             StringTokenizer st1 = new StringTokenizer(entry, ":");
             String setId = st1.nextToken();
@@ -911,7 +935,7 @@ public class ProfileEditDialog extends CMSBaseConfigDialog
             colNames.addElement("Inputs");
         else if (table == mOutputTable)
             colNames.addElement("Outputs");
-        Vector<Vector<String>> d = new Vector<Vector<String>>();
+        Vector<Vector<Object>> d = new Vector<>();
 
         for (String entry : response.keySet()) {
             entry = entry.trim();
@@ -919,7 +943,7 @@ public class ProfileEditDialog extends CMSBaseConfigDialog
             Debug.println("populateNonPolicy entry= " + entry);
             Debug.println("populateNonPolicy value= " + value);
 
-            Vector<String> row = new Vector<String>();
+            Vector<Object> row = new Vector<>();
             row.addElement(entry);
             row.addElement(value);
             d.addElement(row);
