@@ -17,16 +17,44 @@
 // --- END COPYRIGHT BLOCK ---
 package com.netscape.admin.certsrv.config;
 
-import com.netscape.admin.certsrv.*;
-import com.netscape.admin.certsrv.connection.*;
-import javax.swing.*;
-import javax.swing.table.*;
-import java.awt.event.*;
-import java.awt.*;
-import java.util.*;
+import java.awt.Color;
+import java.awt.Component;
+import java.awt.GridBagConstraints;
+import java.awt.GridBagLayout;
+import java.awt.Insets;
+import java.awt.event.ActionEvent;
+import java.awt.event.ActionListener;
+import java.awt.event.FocusEvent;
+import java.awt.event.FocusListener;
+import java.util.Hashtable;
+import java.util.StringTokenizer;
+import java.util.Vector;
 
-import com.netscape.management.client.util.*;
-import com.netscape.certsrv.common.*;
+import javax.swing.DefaultCellEditor;
+import javax.swing.JButton;
+import javax.swing.JComboBox;
+import javax.swing.JComponent;
+import javax.swing.JFrame;
+import javax.swing.JLabel;
+import javax.swing.JPanel;
+import javax.swing.JScrollPane;
+import javax.swing.JTabbedPane;
+import javax.swing.JTable;
+import javax.swing.JTextArea;
+import javax.swing.JTextField;
+import javax.swing.ListSelectionModel;
+import javax.swing.ScrollPaneConstants;
+import javax.swing.table.DefaultTableCellRenderer;
+import javax.swing.table.TableCellRenderer;
+
+import com.netscape.admin.certsrv.CMSAdminUtil;
+import com.netscape.admin.certsrv.EAdminException;
+import com.netscape.admin.certsrv.connection.AdminConnection;
+import com.netscape.certsrv.common.Constants;
+import com.netscape.certsrv.common.NameValuePairs;
+import com.netscape.certsrv.common.ScopeDef;
+import com.netscape.management.client.util.Debug;
+import com.netscape.management.client.util.JButtonFactory;
 
 /**
  * Policy Parameter Configuration Dialog
@@ -43,7 +71,7 @@ public class ProfilePolicyEditDialog extends CMSBaseConfigDialog
     protected JLabel mNameLabel=null, mIdLabel=null, mDescLabel = null, mConfigLabel =null;
     protected JTable mConstraintTable = null;
     protected ProfileDataTable mDefaultTable = null;
-    protected Hashtable mHelpDesc = new Hashtable();
+    protected Hashtable<Object, String> mHelpDesc = new Hashtable<>();
 
     /*==========================================================
      * constructors
@@ -79,18 +107,18 @@ public class ProfilePolicyEditDialog extends CMSBaseConfigDialog
         mPluginLabel.setVisible(false);
         mPluginName = new JTextField();
 
-        gbc.fill = gbc.NONE;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weightx = 0.0;
         gbc.gridwidth = 1;
-        gbc.anchor = gbc.EAST;
+        gbc.anchor = GridBagConstraints.EAST;
         gbc.insets = new Insets(CMSAdminUtil.COMPONENT_SPACE,
                                  CMSAdminUtil.COMPONENT_SPACE,0,0);
         mListPanel.add(mRulenameCaption, gbc);
 
-        gbc.anchor = gbc.WEST;
-        gbc.fill = gbc.HORIZONTAL;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.fill = GridBagConstraints.HORIZONTAL;
         gbc.weightx = 1.0;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.insets = new Insets(CMSAdminUtil.COMPONENT_SPACE,
                                  CMSAdminUtil.COMPONENT_SPACE,
                                  0,CMSAdminUtil.COMPONENT_SPACE);
@@ -103,20 +131,20 @@ public class ProfilePolicyEditDialog extends CMSBaseConfigDialog
          "NAMENAME", null);
         mNameLabel.addMouseListener(this);
 
-        gbc.fill = gbc.NONE;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weightx = 0.0;
         gbc.gridwidth = 1;
-        gbc.anchor = gbc.EAST;
+        gbc.anchor = GridBagConstraints.EAST;
         gbc.insets = new Insets(CMSAdminUtil.COMPONENT_SPACE,
                                  CMSAdminUtil.COMPONENT_SPACE,0,0);
         // mListPanel.add( mNameLabel, gbc );
 	mNameLabel.setBackground(getBackground());
 	mNameLabel.setEnabled(false);
 
-        gbc.anchor = gbc.WEST;
-        gbc.fill = gbc.HORIZONTAL;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.fill = GridBagConstraints.HORIZONTAL;
         gbc.weightx = 1.0;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         mNameField = new JTextField();
        // mListPanel.add( mNameField, gbc );
 
@@ -126,18 +154,18 @@ public class ProfilePolicyEditDialog extends CMSBaseConfigDialog
          "DESCNAME", null);
        // mDescLabel.addMouseListener(this);
 
-        gbc.fill = gbc.NONE;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weightx = 0.0;
         gbc.gridwidth = 1;
-        gbc.anchor = gbc.EAST;
+        gbc.anchor = GridBagConstraints.EAST;
         gbc.insets = new Insets(CMSAdminUtil.COMPONENT_SPACE,
                                  CMSAdminUtil.COMPONENT_SPACE,0,0);
         mListPanel.add( mDescLabel, gbc );
 
-        gbc.anchor = gbc.WEST;
-        gbc.fill = gbc.HORIZONTAL;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.fill = GridBagConstraints.HORIZONTAL;
         gbc.weightx = 1.0;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         mDescField = new JTextField();
         mListPanel.add( mDescField, gbc );
 
@@ -145,18 +173,18 @@ public class ProfilePolicyEditDialog extends CMSBaseConfigDialog
         mIdLabel = CMSAdminUtil.makeJLabel(mResource, PREFIX,
          "IDNAME", null);
 
-        gbc.fill = gbc.NONE;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weightx = 0.0;
         gbc.gridwidth = 1;
-        gbc.anchor = gbc.EAST;
+        gbc.anchor = GridBagConstraints.EAST;
         gbc.insets = new Insets(CMSAdminUtil.COMPONENT_SPACE,
                                  CMSAdminUtil.COMPONENT_SPACE,0,0);
         mListPanel.add( mIdLabel, gbc );
 
-        gbc.anchor = gbc.WEST;
-        gbc.fill = gbc.HORIZONTAL;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.fill = GridBagConstraints.HORIZONTAL;
         gbc.weightx = 1.0;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         mIdField = new JTextField();
         mListPanel.add( mIdField, gbc );
 
@@ -190,18 +218,18 @@ public class ProfilePolicyEditDialog extends CMSBaseConfigDialog
          "IMPLNAME", null);
         mImplnameCaption.addMouseListener(this);
 
-        gbc.fill = gbc.NONE;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weightx = 0.0;
         gbc.gridwidth = 1;
-        gbc.anchor = gbc.EAST;
+        gbc.anchor = GridBagConstraints.EAST;
         gbc.insets = new Insets(CMSAdminUtil.COMPONENT_SPACE,
                                  CMSAdminUtil.COMPONENT_SPACE,0,0);
  //       mListPanel.add( mImplnameCaption, gbc );
 
-        gbc.anchor = gbc.WEST;
-        gbc.fill = gbc.HORIZONTAL;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.fill = GridBagConstraints.HORIZONTAL;
         gbc.weightx = 1.0;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         mImplName = new JLabel();
 //        mListPanel.add( mImplName, gbc );
 
@@ -210,9 +238,9 @@ public class ProfilePolicyEditDialog extends CMSBaseConfigDialog
        JPanel lpanel1 = createDefaultListPanel();
        JPanel lpanel2 = createConstraintListPanel();
         CMSAdminUtil.resetGBC(gbc);
-        gbc.fill = gbc.BOTH;
-        gbc.anchor = gbc.WEST;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.fill = GridBagConstraints.BOTH;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.weightx = 1.0;
         gbc.weighty = 1.0;
         gb.setConstraints(tabPane, gbc);
@@ -247,9 +275,9 @@ public class ProfilePolicyEditDialog extends CMSBaseConfigDialog
         GridBagConstraints gbc2 = new GridBagConstraints();
 
         CMSAdminUtil.resetGBC(gbc2);
-        gbc2.fill = gbc.BOTH;
-        gbc2.anchor = gbc.WEST;
-        gbc2.gridwidth = gbc.REMAINDER;
+        gbc2.fill = GridBagConstraints.BOTH;
+        gbc2.anchor = GridBagConstraints.WEST;
+        gbc2.gridwidth = GridBagConstraints.REMAINDER;
         gbc2.weightx = 1.0;
         gbc2.weighty = 1.0;
         gb2.setConstraints(mHelpLabel, gbc2);
@@ -257,9 +285,9 @@ public class ProfilePolicyEditDialog extends CMSBaseConfigDialog
         mHelpPanel.add(mHelpLabel);
 
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.SOUTH;
-        gbc.gridwidth = gbc.REMAINDER;
-        gbc.gridheight = gbc.REMAINDER;
+        gbc.anchor = GridBagConstraints.SOUTH;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
+        gbc.gridheight = GridBagConstraints.REMAINDER;
         gbc.weightx = 1.0;
         gbc.weighty = 0.0;
         gb.setConstraints(mHelpPanel, gbc);
@@ -270,11 +298,11 @@ public class ProfilePolicyEditDialog extends CMSBaseConfigDialog
 
     public JPanel createDefaultListPanel()
     {
-       Vector colNames = new Vector();
+       Vector<String> colNames = new Vector<>();
        colNames.addElement("Parameter");
        colNames.addElement("Value");
-       Vector data = new Vector();
-       Vector row = new Vector();
+       Vector<Vector<Object>> data = new Vector<>();
+       Vector<Object> row = new Vector<>();
        row.addElement("x");
        row.addElement("x");
        data.addElement(row);
@@ -289,8 +317,8 @@ public class ProfilePolicyEditDialog extends CMSBaseConfigDialog
        model.setInfo(data, colNames);
         mDefaultTable = new ProfileDataTable(model);
         JScrollPane mScrollPane = JTable.createScrollPaneForTable(mDefaultTable);
-        mScrollPane.setHorizontalScrollBarPolicy(mScrollPane.HORIZONTAL_SCROLLBAR_NEVER);
-        mScrollPane.setVerticalScrollBarPolicy(mScrollPane.VERTICAL_SCROLLBAR_ALWAYS);
+        mScrollPane.setHorizontalScrollBarPolicy(ScrollPaneConstants.HORIZONTAL_SCROLLBAR_NEVER);
+        mScrollPane.setVerticalScrollBarPolicy(ScrollPaneConstants.VERTICAL_SCROLLBAR_ALWAYS);
         mDefaultTable.setAutoscrolls(true);
         mDefaultTable.sizeColumnsToFit(true);
         mDefaultTable.getSelectionModel().setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
@@ -304,10 +332,10 @@ public class ProfilePolicyEditDialog extends CMSBaseConfigDialog
           new ProfileComponentCellEditor());
 
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTH;
-        gbc.fill = gbc.BOTH;
-        gbc.gridwidth = gbc.REMAINDER;
-        gbc.gridheight = gbc.REMAINDER;
+        gbc.anchor = GridBagConstraints.NORTH;
+        gbc.fill = GridBagConstraints.BOTH;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
+        gbc.gridheight = GridBagConstraints.REMAINDER;
         gbc.weightx = 1.0;
         gbc.weighty = 1.0;
       //  gbc.gridwidth = 1;
@@ -334,11 +362,11 @@ public class ProfilePolicyEditDialog extends CMSBaseConfigDialog
 
     public JPanel createConstraintListPanel()
     {
-       Vector colNames = new Vector();
+       Vector<String> colNames = new Vector<>();
        colNames.addElement("Parameter");
        colNames.addElement("Value");
-       Vector data = new Vector();
-       Vector row = new Vector();
+       Vector<Vector<Object>> data = new Vector<>();
+       Vector<Object> row = new Vector<>();
        row.addElement("x");
        row.addElement("x");
        data.addElement(row);
@@ -353,8 +381,8 @@ public class ProfilePolicyEditDialog extends CMSBaseConfigDialog
        model.setInfo(data, colNames);
         mConstraintTable = new ProfileDataTable(model);
         JScrollPane mScrollPane = JTable.createScrollPaneForTable(mConstraintTable);
-        mScrollPane.setHorizontalScrollBarPolicy(mScrollPane.HORIZONTAL_SCROLLBAR_NEVER);
-        mScrollPane.setVerticalScrollBarPolicy(mScrollPane.VERTICAL_SCROLLBAR_ALWAYS);
+        mScrollPane.setHorizontalScrollBarPolicy(ScrollPaneConstants.HORIZONTAL_SCROLLBAR_NEVER);
+        mScrollPane.setVerticalScrollBarPolicy(ScrollPaneConstants.VERTICAL_SCROLLBAR_ALWAYS);
         mConstraintTable.setAutoscrolls(true);
         mConstraintTable.sizeColumnsToFit(true);
         mConstraintTable.getSelectionModel().setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
@@ -367,10 +395,10 @@ public class ProfilePolicyEditDialog extends CMSBaseConfigDialog
           new ProfileComponentCellEditor());
 
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTH;
-        gbc.fill = gbc.BOTH;
-        gbc.gridwidth = gbc.REMAINDER;
-        gbc.gridheight = gbc.REMAINDER;
+        gbc.anchor = GridBagConstraints.NORTH;
+        gbc.fill = GridBagConstraints.BOTH;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
+        gbc.gridheight = GridBagConstraints.REMAINDER;
         gbc.weightx = 1.0;
         gbc.weighty = 1.0;
       //  gbc.gridwidth = 1;
@@ -457,7 +485,7 @@ public class ProfilePolicyEditDialog extends CMSBaseConfigDialog
             if (comp instanceof JTextField) {
                 val = ((JTextField)comp).getText().trim();
             } else if (comp instanceof JComboBox) {
-                val = (String)(((JComboBox)comp).getSelectedItem());
+                val = (String)(((JComboBox<String>)comp).getSelectedItem());
             }
             String name1 = ((JLabel)(mDefaultTable.getValueAt(i,0))).getText();
 			nvp.put(name1, val);
@@ -479,7 +507,7 @@ public class ProfilePolicyEditDialog extends CMSBaseConfigDialog
             if (comp instanceof JTextField) {
                 val = ((JTextField)comp).getText().trim();
             } else if (comp instanceof JComboBox) {
-                val = (String)(((JComboBox)comp).getSelectedItem());
+                val = (String)(((JComboBox<String>)comp).getSelectedItem());
             }
 
             String name1 = ((JLabel)(mConstraintTable.getValueAt(i,0))).getText();
@@ -575,10 +603,10 @@ public class ProfilePolicyEditDialog extends CMSBaseConfigDialog
         }
         mModel.progressStop();
 
-        Vector defcolNames = new Vector();
+        Vector<String> defcolNames = new Vector<>();
         defcolNames.addElement("Parameter");
         defcolNames.addElement("Value");
-        Vector defdata = new Vector();
+        Vector<Vector<Object>> defdata = new Vector<>();
 
         for (String entry : response.keySet()) {
            entry = entry.trim();
@@ -587,7 +615,7 @@ public class ProfilePolicyEditDialog extends CMSBaseConfigDialog
                   Debug.println("ProfilePolicyEditDialog value= "+value);
 
             Object obj = getComponent(value);
-           Vector row = new Vector();
+           Vector<Object> row = new Vector<>();
            JLabel label = new JLabel(entry);
            ((Component)obj).addFocusListener(this);
            mHelpDesc.put(obj, getHelpDescription(value));
@@ -626,10 +654,10 @@ public class ProfilePolicyEditDialog extends CMSBaseConfigDialog
         }
         mModel.progressStop();
 
-        Vector colNames = new Vector();
+        Vector<String> colNames = new Vector<>();
         colNames.addElement("Parameter");
         colNames.addElement("Value");
-        Vector d = new Vector();
+        Vector<Vector<Object>> d = new Vector<>();
 
         for (String entry : response.keySet()) {
            entry = entry.trim();
@@ -638,7 +666,7 @@ public class ProfilePolicyEditDialog extends CMSBaseConfigDialog
                   Debug.println("value= "+value);
 
            Object obj = getComponent(value);
-           Vector row = new Vector();
+           Vector<Object> row = new Vector<>();
            JLabel label = new JLabel(entry);
            ((Component)obj).addFocusListener(this);
            mHelpDesc.put(obj, getHelpDescription(value));
@@ -682,7 +710,7 @@ public class ProfilePolicyEditDialog extends CMSBaseConfigDialog
         public void focusGained(FocusEvent f) {
            Debug.println("focusGained");
            Component comp = f.getComponent();
-           String desc = (String)mHelpDesc.get(comp);
+           String desc = mHelpDesc.get(comp);
            if (desc != null) {
                 mHelpLabel.setText(desc);
            }
