@@ -83,10 +83,8 @@ import com.netscape.certsrv.security.ITransportKeyUnit;
 import com.netscape.cms.logging.Logger;
 import com.netscape.cms.logging.SignedAuditLogger;
 import com.netscape.cmscore.apps.CMS;
-import com.netscape.cmscore.apps.CMSEngine;
 import com.netscape.cmscore.apps.EngineConfig;
 import com.netscape.cmscore.dbs.DBSubsystem;
-import com.netscape.cmscore.dbs.IDBSubsystem;
 import com.netscape.cmscore.dbs.KeyRecord;
 import com.netscape.cmscore.dbs.KeyRepository;
 import com.netscape.cmscore.dbs.ReplicaIDRepository;
@@ -266,6 +264,7 @@ public class KeyRecoveryAuthority implements IAuthority, IKeyService, IKeyRecove
 
         KRAEngine engine = KRAEngine.getInstance();
         KRAEngineConfig engineConfig = engine.getConfig();
+        DBSubsystem dbSubsystem = engine.getDBSubsystem();
 
         mConfig = engineConfig.getKRAConfig();
 
@@ -276,11 +275,11 @@ public class KeyRecoveryAuthority implements IAuthority, IKeyService, IKeyRecove
         // create key repository
         int keydb_inc = mConfig.getInteger(PROP_KEYDB_INC, 5);
 
-        mKeyDB = new KeyRepository(getDBSubsystem(),
+        mKeyDB = new KeyRepository(dbSubsystem,
                     keydb_inc,
                     "ou=" + KEY_RESP_NAME + ",ou=" +
                             getId() + "," +
-                            getDBSubsystem().getBaseDN());
+                            dbSubsystem.getBaseDN());
 
         // read transport key from internal database
         mTransportKeyUnit = new TransportKeyUnit();
@@ -363,7 +362,7 @@ public class KeyRecoveryAuthority implements IAuthority, IKeyService, IKeyRecove
 
         mNotify = new KRANotify(this);
         mPNotify = new ARequestNotifier();
-        RequestSubsystem reqSub = (RequestSubsystem) engine.getSubsystem(RequestSubsystem.ID);
+        RequestSubsystem reqSub = engine.getRequestSubsystem();
         int reqdb_inc = mConfig.getInteger("reqdbInc", 5);
 
         mRequestQueue = reqSub.getRequestQueue(getId(), reqdb_inc,
@@ -392,11 +391,11 @@ public class KeyRecoveryAuthority implements IAuthority, IKeyService, IKeyRecove
 
         String replicaReposDN = mConfig.getString(PROP_REPLICAID_DN, null);
         if (replicaReposDN == null) {
-            replicaReposDN = "ou=Replica," + getDBSubsystem().getBaseDN();
+            replicaReposDN = "ou=Replica," + dbSubsystem.getBaseDN();
         }
 
         mReplicaRepot = new ReplicaIDRepository(
-                DBSubsystem.getInstance(), 1, replicaReposDN);
+                dbSubsystem, 1, replicaReposDN);
         logger.debug("Replica Repot inited");
 
     }
@@ -682,7 +681,7 @@ public class KeyRecoveryAuthority implements IAuthority, IKeyService, IKeyRecove
     private void verifyCredential(Vector<Credential> creds, String uid,
             String pwd) throws EBaseException {
 
-        CMSEngine engine = CMS.getCMSEngine();
+        KRAEngine engine = KRAEngine.getInstance();
 
         // see if we have the uid already
         if (!mConfig.getBoolean("keySplitting")) {
@@ -909,7 +908,7 @@ public class KeyRecoveryAuthority implements IAuthority, IKeyService, IKeyRecove
     public void addAgentAsyncKeyRecovery(String reqID, String agentID)
             throws EBaseException {
 
-        CMSEngine engine = CMS.getCMSEngine();
+        KRAEngine engine = KRAEngine.getInstance();
         IRequestQueue queue = null;
         IRequest r = null;
 
@@ -1388,13 +1387,6 @@ public class KeyRecoveryAuthority implements IAuthority, IKeyService, IKeyRecove
         return getX500Name().toString();
     }
 
-    /**
-     * Retrieves database connection.
-     */
-    public IDBSubsystem getDBSubsystem() {
-        return DBSubsystem.getInstance();
-    }
-
     /**
      * Logs an event.
      *
@@ -1757,7 +1749,7 @@ public class KeyRecoveryAuthority implements IAuthority, IKeyService, IKeyRecove
             throws NoSuchAlgorithmException, TokenException, InvalidAlgorithmParameterException,
             InvalidParameterException, PQGParamGenException {
 
-        CMSEngine engine = CMS.getCMSEngine();
+        KRAEngine engine = KRAEngine.getInstance();
         CryptoToken token = getKeygenToken();
 
         logger.debug("NetkeyKeygenService: key pair is to be generated on slot: " + token.getName());
