@@ -60,6 +60,7 @@ public class TransportKeyUnit extends EncryptionUnit implements
     // private RSAPrivateKey mPrivateKey = null;
     private IConfigStore mConfig = null;
     private org.mozilla.jss.crypto.X509Certificate mCert = null;
+    private org.mozilla.jss.crypto.X509Certificate[] chain;
     private org.mozilla.jss.crypto.X509Certificate mNewCert = null;
     private CryptoManager mManager = null;
 
@@ -91,8 +92,13 @@ public class TransportKeyUnit extends EncryptionUnit implements
             throws EBaseException {
         mConfig = config;
         try {
+            String nickname = getNickName();
+            logger.info("TransportKeyUnit: Loading " + nickname + " certificate");
+
             mManager = CryptoManager.getInstance();
-            mCert = mManager.findCertByNickname(getNickName());
+            mCert = mManager.findCertByNickname(nickname);
+            chain = mManager.buildCertificateChain(mCert);
+
             String algo = config.getString("signingAlgorithm", "SHA256withRSA");
 
             // #613795 - initialize this; otherwise JSS is not happy
@@ -107,14 +113,16 @@ public class TransportKeyUnit extends EncryptionUnit implements
             }
 
         } catch (NotInitializedException e) {
-            throw new EBaseException(CMS.getUserMessage("CMS_BASE_INTERNAL_ERROR", e.toString()));
+            throw new EBaseException(CMS.getUserMessage("CMS_BASE_INTERNAL_ERROR", e.toString()), e);
 
         } catch (TokenException e) {
-            throw new EBaseException(CMS.getUserMessage("CMS_BASE_INTERNAL_ERROR", e.toString()));
+            throw new EBaseException(CMS.getUserMessage("CMS_BASE_INTERNAL_ERROR", e.toString()), e);
+
         } catch (ObjectNotFoundException e) {
-            throw new EBaseException(CMS.getUserMessage("CMS_BASE_INTERNAL_ERROR", e.toString()));
+            throw new EBaseException(CMS.getUserMessage("CMS_BASE_INTERNAL_ERROR", e.toString()), e);
+
         } catch (Exception e) {
-            throw new EBaseException(CMS.getUserMessage("CMS_BASE_INTERNAL_ERROR", e.toString()));
+            throw new EBaseException(CMS.getUserMessage("CMS_BASE_INTERNAL_ERROR", e.toString()), e);
         }
     }
 
@@ -199,6 +207,10 @@ public class TransportKeyUnit extends EncryptionUnit implements
         return mCert;
     }
 
+    public org.mozilla.jss.crypto.X509Certificate[] getChain() {
+        return chain;
+    }
+
     public org.mozilla.jss.crypto.X509Certificate getNewCertificate() {
         return mNewCert;
     }
