@@ -22,7 +22,6 @@ import org.dogtagpki.legacy.policy.IPolicyProcessor;
 
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.IConfigStore;
-import com.netscape.certsrv.base.ISubsystem;
 import com.netscape.certsrv.logging.ILogger;
 import com.netscape.certsrv.request.IPolicy;
 import com.netscape.certsrv.request.IRequest;
@@ -46,9 +45,9 @@ public class KRAPolicy implements IPolicy {
     public KRAPolicy() {
     }
 
-    public void init(ISubsystem owner, IConfigStore config)
+    public void init(KeyRecoveryAuthority owner, IConfigStore config)
             throws EBaseException {
-        mKRA = (KeyRecoveryAuthority) owner;
+        mKRA = owner;
         mConfig = config;
 
         mPolicies = new GenericPolicyProcessor(false);
