@@ -18,16 +18,20 @@
 
 package org.dogtagpki.server.kra;
 
-import com.netscape.certsrv.base.EBaseException;
+import javax.servlet.ServletContextListener;
+import javax.servlet.annotation.WebListener;
+
+import com.netscape.certsrv.base.IConfigStore;
+import com.netscape.certsrv.base.ISubsystem;
 import com.netscape.certsrv.kra.IKeyRecoveryAuthority;
 import com.netscape.cmscore.apps.CMS;
 import com.netscape.cmscore.apps.CMSEngine;
 import com.netscape.cmscore.apps.EngineConfig;
 import com.netscape.cmscore.base.ConfigStorage;
-import com.netscape.cmscore.selftests.SelfTestSubsystem;
 import com.netscape.kra.KeyRecoveryAuthority;
 
-public class KRAEngine extends CMSEngine {
+@WebListener
+public class KRAEngine extends CMSEngine implements ServletContextListener {
 
     public KRAEngine() throws Exception {
         super("KRA");
@@ -49,20 +53,17 @@ public class KRAEngine extends CMSEngine {
         return new KRAConfigurator(this);
     }
 
-    protected void loadSubsystems() throws EBaseException {
+    public void initSubsystem(ISubsystem subsystem, IConfigStore subsystemConfig) throws Exception {
 
-        super.loadSubsystems();
-
-        if (isPreOpMode()) {
-            // Disable some subsystems before database initialization
-            // in pre-op mode to prevent misleading exceptions.
-
-            setSubsystemEnabled(KeyRecoveryAuthority.ID, false);
-            setSubsystemEnabled(SelfTestSubsystem.ID, false);
+        if (subsystem instanceof KeyRecoveryAuthority) {
+            // skip initialization during installation
+            if (isPreOpMode()) return;
         }
+
+        super.initSubsystem(subsystem, subsystemConfig);
     }
 
-    public void startupSubsystems() throws EBaseException {
+    public void startupSubsystems() throws Exception {
 
         super.startupSubsystems();
 
