@@ -18,15 +18,19 @@
 
 package org.dogtagpki.server.ocsp;
 
-import com.netscape.certsrv.base.EBaseException;
+import javax.servlet.ServletContextListener;
+import javax.servlet.annotation.WebListener;
+
+import com.netscape.certsrv.base.IConfigStore;
+import com.netscape.certsrv.base.ISubsystem;
 import com.netscape.cmscore.apps.CMS;
 import com.netscape.cmscore.apps.CMSEngine;
 import com.netscape.cmscore.apps.EngineConfig;
 import com.netscape.cmscore.base.ConfigStorage;
-import com.netscape.cmscore.selftests.SelfTestSubsystem;
 import com.netscape.ocsp.OCSPAuthority;
 
-public class OCSPEngine extends CMSEngine {
+@WebListener
+public class OCSPEngine extends CMSEngine implements ServletContextListener {
 
     public OCSPEngine() throws Exception {
         super("OCSP");
@@ -48,16 +52,13 @@ public class OCSPEngine extends CMSEngine {
         return new OCSPConfigurator(this);
     }
 
-    protected void loadSubsystems() throws EBaseException {
+    public void initSubsystem(ISubsystem subsystem, IConfigStore subsystemConfig) throws Exception {
 
-        super.loadSubsystems();
-
-        if (isPreOpMode()) {
-            // Disable some subsystems before database initialization
-            // in pre-op mode to prevent misleading exceptions.
-
-            setSubsystemEnabled(OCSPAuthority.ID, false);
-            setSubsystemEnabled(SelfTestSubsystem.ID, false);
+        if (subsystem instanceof OCSPAuthority) {
+            // skip initialization during installation
+            if (isPreOpMode()) return;
         }
+
+        super.initSubsystem(subsystem, subsystemConfig);
     }
 }
