@@ -59,8 +59,7 @@ DEFAULT_FILE_MODE = 0o0660
 DEFAULT_LINK_MODE = 0o0777
 
 SCHEMA_FILES = [
-    '/usr/share/pki/server/conf/schema.ldif',
-    '/usr/share/pki/acme/database/ldap/schema.ldif'
+    '/usr/share/pki/server/conf/schema.ldif'
 ]
 
 logger = logging.getLogger(__name__)
@@ -318,7 +317,7 @@ class PKIServer(object):
 
             # switch to systemd user if different from current user
             if current_user != self.user:
-                prefix.extend(['sudo', '-u', self.user])
+                prefix.extend(['/usr/sbin/runuser', '-u', self.user, '--'])
 
         java_path = os.getenv('PKI_JAVA_PATH')
         java_home = self.config.get('JAVA_HOME')
