@@ -139,7 +139,7 @@ class AuditConfigShowCLI(pki.cli.CLI):
                 sys.exit(1)
 
         instance = pki.server.instance.PKIInstance(instance_name)
-        if not instance.is_valid():
+        if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
@@ -268,7 +268,7 @@ class AuditConfigModifyCLI(pki.cli.CLI):
                 sys.exit(1)
 
         instance = pki.server.instance.PKIInstance(instance_name)
-        if not instance.is_valid():
+        if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
@@ -392,7 +392,7 @@ class AuditEventFindCLI(pki.cli.CLI):
                 sys.exit(1)
 
         instance = pki.server.instance.PKIInstance(instance_name)
-        if not instance.is_valid():
+        if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
@@ -481,7 +481,7 @@ class AuditEventShowCLI(pki.cli.CLI):
         event_name = args[0]
 
         instance = pki.server.instance.PKIInstance(instance_name)
-        if not instance.is_valid():
+        if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
@@ -508,7 +508,7 @@ class AuditEventEnableCLI(pki.cli.CLI):
         self.parent = parent
 
     def print_help(self):
-        print('Usage: pki-server %s-audit-event-enable <event_name> [OPTIONS]'
+        print('Usage: pki-server %s-audit-event-enable [OPTIONS] <event_name>'
               % self.parent.parent.name)
         print()
         print('  -i, --instance <instance ID>       Instance ID (default: pki-tomcat).')
@@ -557,7 +557,7 @@ class AuditEventEnableCLI(pki.cli.CLI):
         event_name = args[0]
 
         instance = pki.server.instance.PKIInstance(instance_name)
-        if not instance.is_valid():
+        if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
@@ -652,7 +652,7 @@ class AuditEventUpdateCLI(pki.cli.CLI):
         event_name = args[0]
 
         instance = pki.server.instance.PKIInstance(instance_name)
-        if not instance.is_valid():
+        if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
@@ -681,7 +681,7 @@ class AuditEventDisableCLI(pki.cli.CLI):
         self.parent = parent
 
     def print_help(self):
-        print('Usage: pki-server %s-audit-event-disable <event_name> [OPTIONS]'
+        print('Usage: pki-server %s-audit-event-disable [OPTIONS] <event_name>'
               % self.parent.parent.name)
         print()
         print('  -i, --instance <instance ID>       Instance ID (default: pki-tomcat).')
@@ -731,7 +731,7 @@ class AuditEventDisableCLI(pki.cli.CLI):
         event_name = args[0]
 
         instance = pki.server.instance.PKIInstance(instance_name)
-        if not instance.is_valid():
+        if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
@@ -813,7 +813,7 @@ class AuditFileFindCLI(pki.cli.CLI):
                 sys.exit(1)
 
         instance = pki.server.instance.PKIInstance(instance_name)
-        if not instance.is_valid():
+        if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
@@ -891,7 +891,7 @@ class AuditFileVerifyCLI(pki.cli.CLI):
                 sys.exit(1)
 
         instance = pki.server.instance.PKIInstance(instance_name)
-        if not instance.is_valid():
+        if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
