@@ -33,7 +33,9 @@ import pki.server
 import pki.server.cli.audit
 import pki.server.cli.config
 import pki.server.cli.db
+import pki.server.cli.group
 import pki.server.cli.range
+import pki.server.cli.user
 import pki.server.instance
 
 logger = logging.getLogger(__name__)
@@ -50,7 +52,10 @@ class CACLI(pki.cli.CLI):
         self.add_module(CACloneCLI())
         self.add_module(pki.server.cli.config.SubsystemConfigCLI(self))
         self.add_module(pki.server.cli.db.SubsystemDBCLI(self))
+        self.add_module(pki.server.cli.group.GroupCLI(self))
+        self.add_module(CAProfileCLI())
         self.add_module(pki.server.cli.range.RangeCLI(self))
+        self.add_module(pki.server.cli.user.UserCLI(self))
 
 
 class CACertCLI(pki.cli.CLI):
@@ -59,10 +64,80 @@ class CACertCLI(pki.cli.CLI):
         super(CACertCLI, self).__init__(
             'cert', 'CA certificates management commands')
 
+        self.add_module(CACertRemoveCLI())
         self.add_module(CACertChainCLI())
         self.add_module(CACertRequestCLI())
 
 
+class CACertRemoveCLI(pki.cli.CLI):
+
+    def __init__(self):
+        super(CACertRemoveCLI, self).__init__(
+            'del', 'Remove certificate in CA')
+
+    def print_help(self):
+        print('Usage: pki-server ca-cert-remove [OPTIONS] <serial number>')
+        print()
+        print('  -i, --instance <instance ID>       Instance ID (default: pki-tomcat).')
+        print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
+        print('      --help                         Show help message.')
+        print()
+
+    def execute(self, argv):
+
+        try:
+            opts, args = getopt.gnu_getopt(argv, 'i:v', [
+                'instance=',
+                'verbose', 'debug', 'help'])
+
+        except getopt.GetoptError as e:
+            logger.error(e)
+            self.print_help()
+            sys.exit(1)
+
+        if len(args) != 1:
+            logger.error('Missing serial number')
+            self.print_help()
+            sys.exit(1)
+
+        serial_number = args[0]
+        instance_name = 'pki-tomcat'
+
+        for o, a in opts:
+            if o in ('-i', '--instance'):
+                instance_name = a
+
+            elif o in ('-v', '--verbose'):
+                logging.getLogger().setLevel(logging.INFO)
+
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
+            elif o == '--help':
+                self.print_help()
+                sys.exit()
+
+            else:
+                logger.error('Invalid option: %s', o)
+                self.print_help()
+                sys.exit(1)
+
+        instance = pki.server.instance.PKIInstance(instance_name)
+        if not instance.exists():
+            logger.error('Invalid instance: %s', instance_name)
+            sys.exit(1)
+
+        instance.load()
+
+        subsystem = instance.get_subsystem('ca')
+        if not subsystem:
+            logger.error('No CA subsystem in instance %s', instance_name)
+            sys.exit(1)
+
+        subsystem.remove_cert(serial_number)
+
+
 class CACertChainCLI(pki.cli.CLI):
 
     def __init__(self):
@@ -476,3 +551,88 @@ class CAClonePrepareCLI(pki.cli.CLI):
 
         finally:
             shutil.rmtree(tmpdir)
+
+
+class CAProfileCLI(pki.cli.CLI):
+
+    def __init__(self):
+        super(CAProfileCLI, self).__init__(
+            'profile', 'CA profile management commands')
+
+        self.add_module(CAProfileImportCLI())
+
+
+class CAProfileImportCLI(pki.cli.CLI):
+
+    def __init__(self):
+        super(CAProfileImportCLI, self).__init__(
+            'import', 'Import CA profiles')
+
+    def print_help(self):
+        print('Usage: pki-server ca-profile-import [OPTIONS]')
+        print()
+        print('  -i, --instance <instance ID>       Instance ID (default: pki-tomcat).')
+        print('      --input-folder <path>          Input folder.')
+        print('      --as-current-user              Run as current user.')
+        print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
+        print('      --help                         Show help message.')
+        print()
+
+    def execute(self, argv):
+
+        try:
+            opts, _ = getopt.gnu_getopt(argv, 'i:v', [
+                'instance=',
+                'input-folder=',
+                'verbose', 'debug', 'help'])
+
+        except getopt.GetoptError as e:
+            logger.error(e)
+            self.print_help()
+            sys.exit(1)
+
+        instance_name = 'pki-tomcat'
+        input_folder = '/usr/share/pki/ca/profiles/ca'
+        as_current_user = False
+
+        for o, a in opts:
+            if o in ('-i', '--instance'):
+                instance_name = a
+
+            elif o == '--input-folder':
+                input_folder = a
+
+            elif o == '--as-current-user':
+                as_current_user = True
+
+            elif o in ('-v', '--verbose'):
+                logging.getLogger().setLevel(logging.INFO)
+
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
+            elif o == '--help':
+                self.print_help()
+                sys.exit()
+
+            else:
+                logger.error('Invalid option: %s', o)
+                self.print_help()
+                sys.exit(1)
+
+        instance = pki.server.instance.PKIInstance(instance_name)
+        if not instance.exists():
+            logger.error('Invalid instance: %s', instance_name)
+            sys.exit(1)
+
+        instance.load()
+
+        subsystem = instance.get_subsystem('ca')
+        if not subsystem:
+            logger.error('No CA subsystem in instance %s', instance_name)
+            sys.exit(1)
+
+        subsystem.import_profiles(
+            input_folder=input_folder,
+            as_current_user=as_current_user)
