@@ -44,8 +44,6 @@ class DBCLI(pki.cli.CLI):
 
 class DBSchemaUpgradeCLI(pki.cli.CLI):
 
-    SCHEMA_PATH = '/usr/share/pki/server/conf/schema.ldif'
-
     def __init__(self):
         super(DBSchemaUpgradeCLI, self).__init__(
             'schema-upgrade', 'Upgrade PKI database schema')
@@ -102,12 +100,12 @@ class DBSchemaUpgradeCLI(pki.cli.CLI):
                 sys.exit(1)
 
         instance = pki.server.instance.PKIInstance(instance_name)
-        if not instance.is_valid():
+        if not instance.exists():
             logger.error('Invalid instance: %s', instance_name)
             sys.exit(1)
         instance.load()
 
-        if not instance.subsystems:
+        if not instance.get_subsystems():
             logger.error('No subsystem in instance %s', instance_name)
             sys.exit(1)
 
@@ -115,7 +113,7 @@ class DBSchemaUpgradeCLI(pki.cli.CLI):
             bind_password = getpass.getpass(prompt='Enter password: ')
 
         try:
-            self.update_schema(instance.subsystems[0], bind_dn, bind_password)
+            self.update_schema(instance.get_subsystems()[0], bind_dn, bind_password)
 
         except subprocess.CalledProcessError as e:
             logger.error('Unable to update schema: %s', e)
@@ -125,25 +123,9 @@ class DBSchemaUpgradeCLI(pki.cli.CLI):
 
     def update_schema(self, subsystem, bind_dn, bind_password):
 
-        logger.info('Updating schema with %s', self.SCHEMA_PATH)
-
-        # TODO(alee) re-implement this using open_database
-        host = subsystem.config['internaldb.ldapconn.host']
-        port = subsystem.config['internaldb.ldapconn.port']
-        secure = subsystem.config['internaldb.ldapconn.secureConn']
-        cmd = ['ldapmodify',
-               '-c',
-               '-D', bind_dn,
-               '-w', bind_password,
-               '-h', host,
-               '-p', port,
-               '-f', self.SCHEMA_PATH
-               ]
-
-        if secure.lower() == "true":
-            cmd.append('-Z')
-
-        subprocess.check_output(cmd, stderr=subprocess.STDOUT)
+        for filename in pki.server.SCHEMA_FILES:
+            logger.info('Updating schema with %s', filename)
+            subsystem.import_ldif(bind_dn, bind_password, filename)
 
 
 class DBUpgradeCLI(pki.cli.CLI):
@@ -204,14 +186,14 @@ class DBUpgradeCLI(pki.cli.CLI):
 
         instance = pki.server.instance.PKIInstance(instance_name)
 
-        if not instance.is_valid():
+        if not instance.exists():
             logger.error('Invalid instance: %s', instance_name)
             sys.exit(1)
 
         instance.load()
 
         # upgrade all subsystems
-        for subsystem in instance.subsystems:
+        for subsystem in instance.get_subsystems():
 
             cmd = [subsystem.name + '-db-upgrade']
 
@@ -242,42 +224,42 @@ class SubsystemDBCLI(pki.cli.CLI):
 
         name = 'internaldb.%s'
 
-        hostname = subsystem.config.get(name % 'ldapconn.host', None)
+        hostname = subsystem.config.get(name % 'ldapconn.host')
         print('  Hostname: %s' % hostname)
 
-        port = subsystem.config.get(name % 'ldapconn.port', None)
+        port = subsystem.config.get(name % 'ldapconn.port')
         print('  Port: %s' % port)
 
-        secure = subsystem.config.get(name % 'ldapconn.secureConn', None)
+        secure = subsystem.config.get(name % 'ldapconn.secureConn')
         print('  Secure: %s' % secure)
 
-        auth = subsystem.config.get(name % 'ldapauth.authtype', None)
+        auth = subsystem.config.get(name % 'ldapauth.authtype')
         print('  Authentication: %s' % auth)
 
         if auth == 'BasicAuth':
-            bindDN = subsystem.config.get(name % 'ldapauth.bindDN', None)
+            bindDN = subsystem.config.get(name % 'ldapauth.bindDN')
             print('  Bind DN: %s' % bindDN)
 
-            bindPWPrompt = subsystem.config.get(name % 'ldapauth.bindPWPrompt', None)
+            bindPWPrompt = subsystem.config.get(name % 'ldapauth.bindPWPrompt')
             print('  Bind Password Prompt: %s' % bindPWPrompt)
 
         if auth == 'SslClientAuth':
-            nickname = subsystem.config.get(name % 'ldapauth.clientCertNickname', None)
+            nickname = subsystem.config.get(name % 'ldapauth.clientCertNickname')
             print('  Client Certificate: %s' % nickname)
 
-        database = subsystem.config.get(name % 'database', None)
+        database = subsystem.config.get(name % 'database')
         print('  Database: %s' % database)
 
-        baseDN = subsystem.config.get(name % 'basedn', None)
+        baseDN = subsystem.config.get(name % 'basedn')
         print('  Base DN: %s' % baseDN)
 
-        multipleSuffix = subsystem.config.get(name % 'multipleSuffix.enable', None)
+        multipleSuffix = subsystem.config.get(name % 'multipleSuffix.enable')
         print('  Multiple suffix: %s' % multipleSuffix)
 
-        maxConns = subsystem.config.get(name % 'maxConns', None)
+        maxConns = subsystem.config.get(name % 'maxConns')
         print('  Maximum connections: %s' % maxConns)
 
-        minConns = subsystem.config.get(name % 'minConns', None)
+        minConns = subsystem.config.get(name % 'minConns')
         print('  Minimum connections: %s' % minConns)
 
 
@@ -344,7 +326,7 @@ class SubsystemDBConfigShowCLI(pki.cli.CLI):
                 sys.exit(1)
 
         instance = pki.server.instance.PKIInstance(instance_name)
-        if not instance.is_valid():
+        if not instance.exists():
             logger.error('Invalid instance: %s', instance_name)
             sys.exit(1)
 
@@ -490,7 +472,7 @@ class SubsystemDBConfigModifyCLI(pki.cli.CLI):
                 sys.exit(1)
 
         instance = pki.server.instance.PKIInstance(instance_name)
-        if not instance.is_valid():
+        if not instance.exists():
             logger.error('Invalid instance: %s', instance_name)
             sys.exit(1)
 
@@ -615,7 +597,7 @@ class SubsystemDBInfoCLI(pki.cli.CLI):
                 sys.exit(1)
 
         instance = pki.server.instance.PKIInstance(instance_name)
-        if not instance.is_valid():
+        if not instance.exists():
             logger.error('Invalid instance: %s', instance_name)
             sys.exit(1)
 
@@ -694,7 +676,7 @@ class SubsystemDBEmptyCLI(pki.cli.CLI):
                 sys.exit(1)
 
         instance = pki.server.instance.PKIInstance(instance_name)
-        if not instance.is_valid():
+        if not instance.exists():
             logger.error('Invalid instance: %s', instance_name)
             sys.exit(1)
 
@@ -775,7 +757,7 @@ class SubsystemDBRemoveCLI(pki.cli.CLI):
                 sys.exit(1)
 
         instance = pki.server.instance.PKIInstance(instance_name)
-        if not instance.is_valid():
+        if not instance.exists():
             logger.error('Invalid instance: %s', instance_name)
             sys.exit(1)
 
@@ -820,7 +802,7 @@ class SubsystemDBUpgradeCLI(pki.cli.CLI):
                 'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            logging.error(e)
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
@@ -850,14 +832,14 @@ class SubsystemDBUpgradeCLI(pki.cli.CLI):
                 sys.exit()
 
             else:
-                logging.error('Invalid option: %s', o)
+                logger.error('Invalid option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
         instance = pki.server.instance.PKIInstance(instance_name)
 
-        if not instance.is_valid():
-            logging.error('Invalid instance: %s', instance_name)
+        if not instance.exists():
+            logger.error('Invalid instance: %s', instance_name)
             sys.exit(1)
 
         instance.load()
@@ -865,8 +847,8 @@ class SubsystemDBUpgradeCLI(pki.cli.CLI):
         subsystem = instance.get_subsystem(subsystem_name)
 
         if not subsystem:
-            logging.error('No %s subsystem in instance %s.',
-                          subsystem_name.upper(), instance_name)
+            logger.error('No %s subsystem in instance %s.',
+                         subsystem_name.upper(), instance_name)
             sys.exit(1)
 
         subsystem.run(cmd, as_current_user=as_current_user)
