@@ -37,7 +37,9 @@ import pki.cli
 import pki.server.cli.audit
 import pki.server.cli.config
 import pki.server.cli.db
+import pki.server.cli.group
 import pki.server.cli.range
+import pki.server.cli.user
 import pki.server.instance
 
 logger = logging.getLogger(__name__)
@@ -61,7 +63,9 @@ class KRACLI(pki.cli.CLI):
         self.add_module(KRACloneCLI())
         self.add_module(pki.server.cli.config.SubsystemConfigCLI(self))
         self.add_module(KRADBCLI(self))
+        self.add_module(pki.server.cli.group.GroupCLI(self))
         self.add_module(pki.server.cli.range.RangeCLI(self))
+        self.add_module(pki.server.cli.user.UserCLI(self))
 
 
 class KRACloneCLI(pki.cli.CLI):
