@@ -108,16 +108,16 @@ class SubsystemFindCLI(pki.cli.CLI):
 
         instance = pki.server.instance.PKIInstance(instance_name)
 
-        if not instance.is_valid():
+        if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
         instance.load()
 
-        self.print_message('%s entries matched' % len(instance.subsystems))
+        self.print_message('%s entries matched' % len(instance.get_subsystems()))
 
         first = True
-        for subsystem in instance.subsystems:
+        for subsystem in instance.get_subsystems():
             if first:
                 first = False
             else:
@@ -182,7 +182,7 @@ class SubsystemShowCLI(pki.cli.CLI):
 
         instance = pki.server.instance.PKIInstance(instance_name)
 
-        if not instance.is_valid():
+        if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
@@ -256,14 +256,14 @@ class SubsystemEnableCLI(pki.cli.CLI):
 
         instance = pki.server.instance.PKIInstance(instance_name)
 
-        if not instance.is_valid():
+        if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
         instance.load()
 
         if all_subsystems:
-            for subsystem in instance.subsystems:
+            for subsystem in instance.get_subsystems():
                 if not subsystem.is_enabled():
                     subsystem.enable()
 
@@ -354,14 +354,14 @@ class SubsystemDisableCLI(pki.cli.CLI):
 
         instance = pki.server.instance.PKIInstance(instance_name)
 
-        if not instance.is_valid():
+        if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
         instance.load()
 
         if all_subsystems:
-            for subsystem in instance.subsystems:
+            for subsystem in instance.get_subsystems():
                 if subsystem.is_enabled():
                     subsystem.disable()
 
@@ -483,7 +483,7 @@ class SubsystemCertFindCLI(pki.cli.CLI):
 
         instance = pki.server.instance.PKIInstance(instance_name)
 
-        if not instance.is_valid():
+        if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
@@ -582,7 +582,7 @@ class SubsystemCertShowCLI(pki.cli.CLI):
 
         instance = pki.server.instance.PKIInstance(instance_name)
 
-        if not instance.is_valid():
+        if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
@@ -711,7 +711,7 @@ class SubsystemCertExportCLI(pki.cli.CLI):
 
         instance = pki.server.instance.PKIInstance(instance_name)
 
-        if not instance.is_valid():
+        if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
@@ -734,7 +734,7 @@ class SubsystemCertExportCLI(pki.cli.CLI):
             sys.exit(1)
 
         if cert_file:
-            cert_data = subsystem_cert.get('data', None)
+            cert_data = subsystem_cert.get('data')
             if cert_data is None:
                 logger.error("Unable to find certificate data for %s", cert_id)
                 sys.exit(1)
@@ -744,7 +744,7 @@ class SubsystemCertExportCLI(pki.cli.CLI):
                 f.write(cert_data)
 
         if csr_file:
-            cert_request = subsystem_cert.get('request', None)
+            cert_request = subsystem_cert.get('request')
             if cert_request is None:
                 logger.error('Unable to find certificate request for %s', cert_id)
                 sys.exit(1)
@@ -853,7 +853,7 @@ class SubsystemCertUpdateCLI(pki.cli.CLI):
 
         instance = pki.server.instance.PKIInstance(instance_name)
 
-        if not instance.is_valid():
+        if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
@@ -998,7 +998,7 @@ class SubsystemCertValidateCLI(pki.cli.CLI):
 
         instance = pki.server.instance.PKIInstance(instance_name)
 
-        if not instance.is_valid():
+        if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
