@@ -37,6 +37,8 @@ import pki.cli
 import pki.server.cli.audit
 import pki.server.cli.config
 import pki.server.cli.db
+import pki.server.cli.group
+import pki.server.cli.user
 import pki.server.instance
 
 logger = logging.getLogger(__name__)
@@ -55,6 +57,8 @@ class TPSCLI(pki.cli.CLI):
         self.add_module(TPSCloneCLI())
         self.add_module(pki.server.cli.config.SubsystemConfigCLI(self))
         self.add_module(TPSDBCLI(self))
+        self.add_module(pki.server.cli.group.GroupCLI(self))
+        self.add_module(pki.server.cli.user.UserCLI(self))
 
 
 class TPSCloneCLI(pki.cli.CLI):
