@@ -28,6 +28,8 @@ import pki.cli
 import pki.upgrade
 import pki.server.upgrade
 
+logger = logging.getLogger(__name__)
+
 
 class UpgradeCLI(pki.cli.CLI):
 
@@ -37,15 +39,11 @@ class UpgradeCLI(pki.cli.CLI):
     def usage(self):
         print('Usage: pki-server upgrade [OPTIONS] [<instance ID>]')
         print()
-        print('  --silent                       Upgrade in silent mode.')
         print('  --status                       Show upgrade status only. Do not perform upgrade.')
         print('  --revert                       Revert the last version.')
         print('  --validate                     Validate upgrade status.')
         print()
         print('  -i, --instance <instance>      Upgrade a specific instance only.')
-        print('  -s, --subsystem <subsystem>    Upgrade a specific subsystem in an instance only.')
-        print('  -t, --instance-type <type>     Upgrade a specific instance type.')
-        print('                                 Specify 9 for PKI 9 instances, 10 for PKI 10.')
         print()
         print('  -X                             Show advanced options.')
         print('  -v, --verbose                  Run in verbose mode.')
@@ -56,9 +54,6 @@ class UpgradeCLI(pki.cli.CLI):
         print()
         print('WARNING: These options may render the system unusable.')
         print()
-        print('  --scriptlet-version <version>  Run scriptlets for a specific version only.')
-        print('  --scriptlet-index <index>      Run a specific scriptlet only.')
-        print()
         print('  --remove-tracker               Remove tracker.')
         print('  --reset-tracker                Reset tracker to match package version.')
         print('  --set-tracker <version>        Set tracker to a specific version.')
@@ -66,26 +61,19 @@ class UpgradeCLI(pki.cli.CLI):
     def execute(self, argv):
 
         try:
-            opts, args = getopt.getopt(argv, 'hi:s:t:vX', [
-                'instance=', 'subsystem=', 'instance-type=',
-                'scriptlet-version=', 'scriptlet-index=',
-                'silent', 'status', 'revert', 'validate',
+            opts, args = getopt.gnu_getopt(argv, 'hi:s:t:vX', [
+                'instance=',
+                'status', 'revert', 'validate',
                 'remove-tracker', 'reset-tracker', 'set-tracker=',
                 'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: %s' % e)
+            logger.error(e)
             self.usage()
             sys.exit(1)
 
-        instanceName = None
-        subsystemName = None
-        instance_version = None
+        instance_name = None
 
-        scriptlet_version = None
-        scriptlet_index = None
-
-        silent = False
         status = False
         revert = False
         validate = False
@@ -97,22 +85,7 @@ class UpgradeCLI(pki.cli.CLI):
 
         for o, a in opts:
             if o in ('-i', '--instance'):
-                instanceName = a
-
-            elif o in ('-s', '--subsystem'):
-                subsystemName = a
-
-            elif o in ('-t', '--instance-type'):
-                instance_version = int(a)
-
-            elif o == '--scriptlet-version':
-                scriptlet_version = a
-
-            elif o == '--scriptlet-index':
-                scriptlet_index = int(a)
-
-            elif o == '--silent':
-                silent = True
+                instance_name = a
 
             elif o == '--status':
                 status = True
@@ -148,53 +121,58 @@ class UpgradeCLI(pki.cli.CLI):
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.usage()
                 sys.exit(1)
 
         if len(args) > 0:
-            instanceName = args[0]
+            instance_name = args[0]
 
-        if subsystemName and not instanceName:
-            print('ERROR: --subsystem requires --instance')
-            self.usage()
-            sys.exit(1)
+        if instance_name:
+            instance = pki.server.instance.PKIInstance(instance_name)
 
-        if scriptlet_index and not scriptlet_version:
-            print('ERROR: --scriptlet-index requires --scriptlet-version')
-            self.usage()
-            sys.exit(1)
+            if not instance.exists():
+                raise Exception('Invalid instance: %s' % instance_name)
 
-        upgrader = pki.server.upgrade.PKIServerUpgrader(
-            instanceName=instanceName,
-            subsystemName=subsystemName,
-            instance_version=instance_version,
-            version=scriptlet_version,
-            index=scriptlet_index,
-            silent=silent)
+            instance.load()
+            instances = [instance]
+
+        else:
+            instances = pki.server.instance.PKIInstance.instances()
+
+        for instance in instances:
+            self.upgrade(
+                instance,
+                status,
+                revert,
+                validate,
+                remove_tracker,
+                reset_tracker,
+                tracker_version)
+
+    def upgrade(self, instance, status, revert, validate,
+                remove_tracker, reset_tracker, tracker_version):
+
+        upgrader = pki.server.upgrade.PKIServerUpgrader(instance=instance)
 
         if status:
             upgrader.status()
 
         elif revert:
-            logging.info('Reverting PKI server last upgrade')
             upgrader.revert()
 
         elif validate:
             upgrader.validate()
 
         elif remove_tracker:
-            logging.info('Removing PKI server upgrade tracker')
             upgrader.remove_tracker()
 
         elif reset_tracker:
-            logging.info('Resetting PKI server upgrade tracker')
             upgrader.reset_tracker()
 
         elif tracker_version is not None:
-            logging.info('Setting PKI server upgrade tracker')
             upgrader.set_tracker(tracker_version)
 
         else:
-            logging.info('Upgrading PKI server')
+            logger.info('Upgrading PKI server %s', instance)
             upgrader.upgrade()
