@@ -248,9 +248,20 @@ class PKIDeployer:
 
         ca_cert = os.path.join(self.mdict['pki_server_database_path'],
                                "ca.crt")
+
         if not os.path.exists(ca_cert):
-            if os.path.exists(self.mdict['pki_cert_chain_path']):
-                ca_cert = self.mdict['pki_cert_chain_path']
+
+            # if ca.crt doesn't exist, use provided cert chain
+            cert_chain_path = self.mdict['pki_cert_chain_path']
+            logger.info('Certificate chain: %s', cert_chain_path)
+
+            if cert_chain_path:
+
+                if not os.path.exists(cert_chain_path):
+                    # if cert chain is specified but doesn't exist, throw exception
+                    raise Exception('Certificate chain not found: %s' % cert_chain_path)
+
+                ca_cert = cert_chain_path
 
         self.sd_connection = pki.client.PKIConnection(
             protocol='https',
@@ -447,7 +458,7 @@ class PKIDeployer:
         logger.info('Adding subsystem cert into pkidbuser')
         subsystem.add_user_cert('pkidbuser', cert_data=cert_data, cert_format='PEM')
 
-        logger.info('Linking pkidbuser to subsystem cert')
+        logger.info('Linking pkidbuser to subsystem cert: %s', subject)
         subsystem.modify_user('pkidbuser', add_see_also=subject)
 
         logger.info('Finding other users linked to subsystem cert')
