@@ -558,12 +558,22 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
         logger.info('Configuring subsystem')
 
         try:
-            PKISPAWN_STARTUP_TIMEOUT_SECONDS = \
-                int(os.environ['PKISPAWN_STARTUP_TIMEOUT_SECONDS'])
+            startup_timeout = int(os.environ['PKISPAWN_STARTUP_TIMEOUT_SECONDS'])
         except (KeyError, ValueError):
-            PKISPAWN_STARTUP_TIMEOUT_SECONDS = 60
-        if PKISPAWN_STARTUP_TIMEOUT_SECONDS <= 0:
-            PKISPAWN_STARTUP_TIMEOUT_SECONDS = 60
+            startup_timeout = 60
+
+        if startup_timeout <= 0:
+            startup_timeout = 60
+
+        # Configure status request timeout. This is used for each
+        # status request in wait_for_startup().
+        value = deployer.mdict['pki_status_request_timeout']
+        if len(value) == 0:
+            request_timeout = None
+        else:
+            request_timeout = int(value)
+            if request_timeout <= 0:
+                raise ValueError("timeout must be greater than zero")
 
         instance = self.instance
         instance.load()
@@ -703,6 +713,14 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
         unsecurePort = server_config.get_unsecure_port()
         securePort = server_config.get_secure_port()
 
+        proxyUnsecurePort = subsystem.config.get('proxy.unsecurePort')
+        if not proxyUnsecurePort:
+            proxyUnsecurePort = unsecurePort
+
+        proxySecurePort = subsystem.config.get('proxy.securePort')
+        if not proxySecurePort:
+            proxySecurePort = securePort
+
         if deployer.mdict['pki_security_domain_type'] == 'existing':
 
             logger.info('Joining existing domain')
@@ -813,6 +831,16 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
 
         subsystem.save()
 
+        if clone:
+
+            if subsystem.type in ['CA', 'KRA']:
+
+                logger.info('Requesting ranges from %s master', subsystem.type)
+                subsystem.request_ranges(master_url, deployer.install_token)
+
+            logger.info('Updating configuration for %s clone', subsystem.type)
+            subsystem.update_config(master_url, deployer.install_token)
+
         if config.str2bool(deployer.mdict['pki_ds_remove_data']):
 
             if config.str2bool(deployer.mdict['pki_ds_create_new_db']):
@@ -853,6 +881,23 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
 
         create_containers = not config.str2bool(deployer.mdict['pki_clone'])
 
+        # Set up replication if required for cloning.
+
+        setup_replication = clone and \
+            config.str2bool(deployer.mdict['pki_clone_setup_replication'])
+
+        ds_port = subsystem.config['internaldb.ldapconn.port']
+        secure_conn = subsystem.config['internaldb.ldapconn.secureConn']
+        replication_security = deployer.mdict['pki_clone_replication_security']
+        replication_port = deployer.mdict['pki_clone_replication_clone_port']
+        master_replication_port = deployer.mdict['pki_clone_replication_master_port']
+
+        if replication_port == ds_port and secure_conn == 'true':
+            replication_security = 'SSL'
+
+        elif not replication_security:
+            replication_security = 'None'
+
         # If the database is already replicated but not yet indexed, rebuild the indexes.
 
         rebuild_indexes = config.str2bool(deployer.mdict['pki_clone']) and \
@@ -873,18 +918,18 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
             create_base=create_base,
             create_containers=create_containers,
             rebuild_indexes=rebuild_indexes,
+            setup_replication=setup_replication,
+            replication_security=replication_security,
+            replication_port=replication_port,
+            master_replication_port=master_replication_port,
             setup_db_manager=setup_db_manager,
             setup_vlv_indexes=setup_vlv_indexes)
 
-        if clone:
+        subsystem.load()
 
-            if subsystem.type in ['CA', 'KRA']:
-
-                logger.info('Updating ranges for %s clone', subsystem.type)
-                subsystem.update_ranges(master_url, deployer.install_token)
-
-            logger.info('Updating configuration for %s clone', subsystem.type)
-            subsystem.update_config(master_url, deployer.install_token)
+        if not clone and subsystem.type == 'CA':
+            subsystem.import_profiles(
+                input_folder='/usr/share/pki/ca/profiles/ca')
 
         # Start/Restart this Tomcat PKI Process
         # Optionally prepare to enable a java debugger
@@ -903,20 +948,10 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
             logger.info('Restarting server')
             instance.restart()
 
-        # Configure status request timeout.  This is used for each
-        # status request in wait_for_startup
-        value = deployer.mdict['pki_status_request_timeout']
-        if len(value) == 0:
-            status_request_timeout = None
-        else:
-            status_request_timeout = int(value)
-            if status_request_timeout <= 0:
-                raise ValueError("timeout must be greater than zero")
-
         deployer.instance.wait_for_startup(
             subsystem,
-            PKISPAWN_STARTUP_TIMEOUT_SECONDS,
-            request_timeout=status_request_timeout,
+            startup_timeout,
+            request_timeout,
         )
 
         # Optionally wait for debugger to attach (e. g. - 'eclipse'):
@@ -940,26 +975,22 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
         if 'pki_one_time_pin' not in deployer.mdict:
             deployer.mdict['pki_one_time_pin'] = subsystem.config['preop.pin']
 
-        logger.info('Configuring %s subsystem', subsystem.type)
-
-        if clone:
-
-            logger.info('Setting up clone')
-
-            clone_setup_request = deployer.config_client.create_clone_setup_request(subsystem)
-            clone_setup_request.domainInfo = deployer.domain_info
-            clone_setup_request.installToken = deployer.install_token
-            client.setupClone(clone_setup_request)
-
-        logger.info('Setting up database')
-
-        database_setup_request = deployer.config_client.create_database_setup_request()
-        client.setupDatabase(database_setup_request)
-
         sslserver = subsystem.get_subsystem_cert('sslserver')
 
         for tag in subsystem.config['preop.cert.list'].split(','):
 
+            if tag != 'sslserver' and clone:
+                logger.info('%s certificate is already set up', tag)
+                continue
+
+            if tag == 'sslserver' and tomcat_instance_subsystems > 1:
+                logger.info('sslserver certificate is already set up')
+                continue
+
+            if tag == 'subsystem' and tomcat_instance_subsystems > 1:
+                logger.info('subsystem certificate is already set up')
+                continue
+
             logger.info('Setting up %s certificate', tag)
             cert = deployer.setup_cert(client, tag)
 
@@ -975,9 +1006,8 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
                 sslserver['token'] = cert['token']
 
         if not clone:
-
             logger.info('Setting up admin user')
-            deployer.setup_admin(client)
+            deployer.setup_admin(subsystem, client)
 
         if config.str2bool(deployer.mdict['pki_backup_keys']):
 
@@ -990,16 +1020,45 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
             logger.info('Backing up keys into %s', deployer.mdict['pki_backup_file'])
             deployer.backup_keys(instance, subsystem)
 
-        logger.info('Setting up security domain')
-        sd_setup_request = deployer.config_client.create_security_domain_setup_request()
-        sd_setup_request.domainInfo = deployer.domain_info
-        sd_setup_request.installToken = deployer.install_token
-        client.setupSecurityDomain(sd_setup_request)
+        domain_manager = False
 
-        if not config.str2bool(deployer.mdict['pki_share_db']):
+        if subsystem.type == 'CA':
+            if clone:
+                sd_hostname = subsystem.config['securitydomain.host']
+                sd_port = subsystem.config['securitydomain.httpsadminport']
+
+                sd_subsystem = deployer.domain_info.subsystems['CA']
+                sd_host = sd_subsystem.get_host(sd_hostname, sd_port)
+
+                if sd_host.DomainManager and sd_host.DomainManager.lower() == 'true':
+                    domain_manager = True
+
+        if deployer.mdict['pki_security_domain_type'] == 'existing':
+            logger.info('Joining security domain')
+            subsystem.join_security_domain(
+                deployer.install_token,
+                deployer.mdict['pki_subsystem_name'],
+                deployer.mdict['pki_hostname'],
+                unsecure_port=proxyUnsecurePort,
+                secure_port=proxySecurePort,
+                domain_manager=domain_manager,
+                clone=clone)
+
+        else:
+            logger.info('Creating security domain')
+            subsystem.create_security_domain()
+
+            logger.info('Adding security domain manager')
+            subsystem.add_security_domain_host(
+                deployer.mdict['pki_subsystem_name'],
+                deployer.mdict['pki_hostname'],
+                unsecure_port=proxyUnsecurePort,
+                secure_port=proxySecurePort,
+                domain_manager=True)
+
+        if not config.str2bool(deployer.mdict['pki_share_db']) and not clone:
             logger.info('Setting up database user')
-            db_user_setup_request = deployer.config_client.create_database_user_setup_request()
-            client.setupDatabaseUser(db_user_setup_request)
+            deployer.setup_database_user(instance, subsystem)
 
         logger.info('Finalizing %s configuration', subsystem.type)
         finalize_config_request = deployer.config_client.create_finalize_config_request()
@@ -1007,10 +1066,63 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
         finalize_config_request.installToken = deployer.install_token
         client.finalizeConfiguration(finalize_config_request)
 
+        subsystem.load()
+
+        if subsystem.type == 'CA':
+
+            if not clone:
+                logger.info('Updating CA ranges')
+                subsystem.update_ranges()
+
+            if clone:
+                if sd_host.DomainManager and sd_host.DomainManager.lower() == 'true':
+
+                    logger.info('Cloning security domain master')
+
+                    subsystem.config['securitydomain.select'] = 'new'
+                    subsystem.config['securitydomain.host'] = deployer.mdict['pki_hostname']
+                    subsystem.config['securitydomain.httpport'] = unsecurePort
+                    subsystem.config['securitydomain.httpsadminport'] = securePort
+                    subsystem.config['securitydomain.httpsagentport'] = securePort
+                    subsystem.config['securitydomain.httpseeport'] = securePort
+
+                logger.info('Disabling CRL caching and generation on clone')
+
+                subsystem.config['ca.certStatusUpdateInterval'] = '0'
+                subsystem.config['ca.listenToCloneModifications'] = 'false'
+                subsystem.config['ca.crl.MasterCRL.enableCRLCache'] = 'false'
+                subsystem.config['ca.crl.MasterCRL.enableCRLUpdates'] = 'false'
+
+                url = urllib.parse.urlparse(master_url)
+
+                subsystem.config['master.ca.agent.host'] = url.hostname
+                subsystem.config['master.ca.agent.port'] = str(url.port)
+
+            crl_number = deployer.mdict['pki_ca_starting_crl_number']
+            logger.info('Starting CRL number: %s', crl_number)
+            subsystem.config['ca.crl.MasterCRL.startingCrlNumber'] = crl_number
+
+            logger.info('Enabling profile subsystem')
+            subsystem.enable_subsystem('profile')
+
+            # Delete CA signing cert record to avoid migration conflict
+            if not config.str2bool(deployer.mdict['pki_ca_signing_record_create']):
+                logger.info('Deleting CA signing cert record')
+                serial_number = deployer.mdict['pki_ca_signing_serial_number']
+                subsystem.remove_cert(serial_number)
+
+        if subsystem.type == 'KRA':
+
+            if not clone:
+                logger.info('Updating KRA ranges')
+                subsystem.update_ranges()
+
         if subsystem.type == 'TPS':
             logger.info('Setting up shared secret')
             deployer.setup_shared_secret(instance, subsystem)
 
+        deployer.finalize_subsystem(subsystem)
+
         logger.info('%s configuration complete', subsystem.type)
 
         # Create an empty file that designates the fact that although
@@ -1057,8 +1169,8 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
 
         deployer.instance.wait_for_startup(
             subsystem,
-            PKISPAWN_STARTUP_TIMEOUT_SECONDS,
-            request_timeout=status_request_timeout,
+            startup_timeout,
+            request_timeout,
         )
 
     def destroy(self, deployer):
