@@ -196,17 +196,23 @@ var ErrorDialog = Backbone.View.extend({
         ErrorDialog.__super__.initialize.call(self, options);
 
         var response = options.response;
-        if (response && response.responseJSON) {
+        if (response && response.responseJSON !== undefined) {
             self.title = "HTTP Error " + response.responseJSON.Code;
             self.content = response.responseJSON.Message;
 
-        } else if (response && response.responseText) {
+        } else if (response && response.responseText !== undefined) {
             self.title = "HTTP Error " + response.status;
-            self.content = response.responseText;
+
+            if (response.getResponseHeader("Content-Type") === "text/html") {
+                self.htmlContent = response.responseText;
+            } else {
+                self.content = response.responseText;
+            }
 
         } else {
             self.title = options.title;
             self.content = options.content;
+            self.htmlContent = options.htmlContent;
         }
     },
     render: function() {
@@ -217,7 +223,10 @@ var ErrorDialog = Backbone.View.extend({
         }
 
         if (self.content) {
-            self.$("span[name=content]").html(self.content);
+            self.$("span[name=content]").text(self.content);
+
+        } else if (self.htmlContent) {
+            self.$("span[name=content]").html(self.htmlContent);
         }
 
         self.$("button[name=close]").click(function(e) {
@@ -233,6 +242,7 @@ var ErrorDialog = Backbone.View.extend({
     close: function() {
         var self = this;
         self.$el.hide();
+        self.trigger("close");
     }
 });
 
@@ -356,7 +366,7 @@ var TableItem = Backbone.View.extend({
             if (value instanceof Date) value = value.toUTCString();
 
             // replace pattern occurance with attribute value
-            newContent += content.substring(0, index) + value;
+            newContent += content.substring(0, index) + _.escape(value);
 
             // process the remaining content
             content = content.substring(index + fullName.length + 3);
@@ -627,17 +637,34 @@ var Table = Backbone.View.extend({
 
             // save new entry
             dialog.save();
-            self.addEntry(dialog.entry);
-
-            // redraw table
-            self.render();
             dialog.close();
+
+            try {
+                self.addEntry(dialog.entry);
+
+                // redraw table
+                self.render();
+
+            } catch (exception) {
+                // display the error in an error dialog,
+                // then reopen the original dialog
+
+                var errorDialog = new ErrorDialog({
+                    el: $("#error-dialog"),
+                    content: exception
+                });
+                errorDialog.on("close", function() {
+                    dialog.open();
+                });
+                errorDialog.open();
+            }
         });
 
         dialog.open();
     },
     addEntry: function(entry) {
         var self = this;
+
         self.entries.push(entry);
     },
     remove: function(items) {
@@ -893,8 +920,16 @@ var EntryPage = Page.extend({
         });
 
         self.saveAction.click(function(e) {
-            self.save();
             e.preventDefault();
+            try {
+                self.saveEntry();
+            } catch (exception) {
+                new ErrorDialog({
+                    el: $("#error-dialog"),
+                    title: "ERROR",
+                    content: exception
+                }).open();
+            }
         });
 
     },
@@ -993,7 +1028,7 @@ var EntryPage = Page.extend({
         var self = this;
         self.close();
     },
-    save: function() {
+    saveEntry: function() {
         var self = this;
 
         self.saveFields();
