@@ -28,7 +28,7 @@ import java.util.Vector;
 
 import org.dogtagpki.server.authentication.AuthManagerConfig;
 import org.dogtagpki.server.authentication.AuthToken;
-import org.dogtagpki.server.authentication.IAuthManager;
+import org.dogtagpki.server.authentication.AuthManager;
 import org.mozilla.jss.netscape.security.util.Utils;
 import org.mozilla.jss.netscape.security.x509.CertificateExtensions;
 import org.mozilla.jss.netscape.security.x509.CertificateSubjectName;
@@ -54,6 +54,7 @@ import com.netscape.cmscore.ldapconn.LDAPAuthenticationConfig;
 import com.netscape.cmscore.ldapconn.LDAPConfig;
 import com.netscape.cmscore.ldapconn.LdapAnonConnFactory;
 import com.netscape.cmscore.ldapconn.LdapBoundConnFactory;
+import com.netscape.cmscore.ldapconn.PKISocketConfig;
 
 import netscape.ldap.LDAPAttribute;
 import netscape.ldap.LDAPConnection;
@@ -73,7 +74,7 @@ import netscape.ldap.LDAPv2;
  * @version $Revision$, $Date$
  */
 public abstract class DirBasedAuthentication
-        implements IAuthManager, IExtendedPluginInfo {
+        implements AuthManager, IExtendedPluginInfo {
 
     public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(DirBasedAuthentication.class);
 
@@ -301,6 +302,8 @@ public abstract class DirBasedAuthentication
             logger.info("DirBasedAuthentication: Group user ID name: " + mGroupUserIDName);
         }
 
+        PKISocketConfig socketConfig = cs.getSocketConfig();
+
         mBoundConnEnable = mLdapConfig.getBoolean(PROP_LDAP_BOUND_CONN, false);
         logger.info("DirBasedAuthentication: Bound connection enable: " + mBoundConnEnable);
 
@@ -310,12 +313,12 @@ public abstract class DirBasedAuthentication
             logger.info("DirBasedAuthentication: Bind password prompt: " + mTag);
 
             LdapBoundConnFactory connFactory = new LdapBoundConnFactory(mTag);
-            connFactory.init(cs, mLdapConfig, engine.getPasswordStore());
+            connFactory.init(socketConfig, mLdapConfig, engine.getPasswordStore());
             mConnFactory = connFactory;
 
         } else {
             LdapAnonConnFactory connFactory = new LdapAnonConnFactory("DirBasedAuthentication");
-            connFactory.init(cs, mLdapConfig);
+            connFactory.init(socketConfig, mLdapConfig);
             mConnFactory = connFactory;
         }
 
@@ -427,6 +430,8 @@ public abstract class DirBasedAuthentication
         CMSEngine engine = CMS.getCMSEngine();
         EngineConfig cs = engine.getConfig();
 
+        PKISocketConfig socketConfig = cs.getSocketConfig();
+
         try {
             if (mConnFactory == null) {
                 logger.debug(method + " mConnFactory null, getting conn factory");
@@ -437,12 +442,12 @@ public abstract class DirBasedAuthentication
                     logger.debug(method + " getting ldap bound conn factory using id= " + mTag);
 
                     LdapBoundConnFactory connFactory = new LdapBoundConnFactory(mTag);
-                    connFactory.init(cs, mLdapConfig, engine.getPasswordStore());
+                    connFactory.init(socketConfig, mLdapConfig, engine.getPasswordStore());
                     mConnFactory = connFactory;
 
                 } else {
                     LdapAnonConnFactory connFactory = new LdapAnonConnFactory("DirBasedAuthentication");
-                    connFactory.init(cs, mLdapConfig);
+                    connFactory.init(socketConfig, mLdapConfig);
                     mConnFactory = connFactory;
                 }
 
