@@ -45,7 +45,7 @@ import com.netscape.certsrv.base.IExtendedPluginInfo;
 import com.netscape.certsrv.profile.EProfileException;
 import com.netscape.certsrv.property.IDescriptor;
 import com.netscape.certsrv.request.IRequest;
-import com.netscape.cms.profile.IProfileAuthenticator;
+import com.netscape.cms.profile.ProfileAuthenticator;
 import com.netscape.cms.profile.common.Profile;
 import com.netscape.cmscore.apps.CMS;
 
@@ -56,7 +56,7 @@ import com.netscape.cmscore.apps.CMS;
  * @version $Revision$, $Date$
  */
 public class FlatFileAuth
-        implements IProfileAuthenticator, IExtendedPluginInfo {
+        implements ProfileAuthenticator, IExtendedPluginInfo {
 
     public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(FlatFileAuth.class);
 
