@@ -25,9 +25,9 @@ import java.util.Vector;
 import javax.ws.rs.core.MultivaluedHashMap;
 import javax.ws.rs.core.MultivaluedMap;
 
+import org.dogtagpki.server.authentication.AuthManager;
 import org.dogtagpki.server.authentication.AuthManagerConfig;
 import org.dogtagpki.server.authentication.AuthToken;
-import org.dogtagpki.server.authentication.IAuthManager;
 
 import com.netscape.certsrv.authentication.EInvalidCredentials;
 import com.netscape.certsrv.authentication.EMissingCredential;
@@ -40,7 +40,7 @@ import com.netscape.certsrv.client.PKIClient;
 import com.netscape.certsrv.profile.EProfileException;
 import com.netscape.certsrv.property.IDescriptor;
 import com.netscape.certsrv.request.IRequest;
-import com.netscape.cms.profile.IProfileAuthenticator;
+import com.netscape.cms.profile.ProfileAuthenticator;
 import com.netscape.cms.profile.common.Profile;
 import com.netscape.cms.servlet.csadmin.Configurator;
 import com.netscape.cmscore.apps.CMS;
@@ -55,13 +55,13 @@ import com.netscape.cmsutil.xml.XMLObject;
  *
  * @version $Revision$, $Date$
  */
-public class TokenAuthentication implements IAuthManager,
-        IProfileAuthenticator {
+public class TokenAuthentication implements AuthManager,
+        ProfileAuthenticator {
 
     public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(TokenAuthentication.class);
 
     /* required credentials */
-    public static final String CRED_SESSION_ID = IAuthManager.CRED_SESSION_ID;
+    public static final String CRED_SESSION_ID = AuthManager.CRED_SESSION_ID;
     protected String[] mRequiredCreds = { CRED_SESSION_ID };
 
     /* config parameters to pass to console (none) */
@@ -218,7 +218,7 @@ public class TokenAuthentication implements IAuthManager,
 
         String serverURL = "https://" + authHost + ":" + authPort;
         PKIClient client = Configurator.createClient(serverURL, null, null);
-        return client.post(authUrl, content);
+        return client.post(authUrl, content, String.class);
     }
 
     /**
