@@ -40,13 +40,14 @@ import com.netscape.certsrv.profile.EProfileException;
 import com.netscape.certsrv.property.Descriptor;
 import com.netscape.certsrv.property.IDescriptor;
 import com.netscape.certsrv.request.IRequest;
-import com.netscape.cms.profile.IProfileAuthenticator;
+import com.netscape.cms.profile.ProfileAuthenticator;
 import com.netscape.cms.profile.common.Profile;
 import com.netscape.cmscore.apps.CMS;
 import com.netscape.cmscore.apps.CMSEngine;
 import com.netscape.cmscore.apps.EngineConfig;
 import com.netscape.cmscore.ldapconn.LDAPConfig;
 import com.netscape.cmscore.ldapconn.LdapBoundConnFactory;
+import com.netscape.cmscore.ldapconn.PKISocketConfig;
 
 import netscape.ldap.LDAPAttribute;
 import netscape.ldap.LDAPConnection;
@@ -63,7 +64,7 @@ import netscape.ldap.LDAPv2;
  * @version $Revision$, $Date$
  */
 public class UidPwdPinDirAuthentication extends DirBasedAuthentication
-        implements IExtendedPluginInfo, IProfileAuthenticator {
+        implements IExtendedPluginInfo, ProfileAuthenticator {
 
     public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(UidPwdPinDirAuthentication.class);
 
@@ -168,9 +169,11 @@ public class UidPwdPinDirAuthentication extends DirBasedAuthentication
         }
 
         if (mRemovePin) {
+            PKISocketConfig socketConfig = cs.getSocketConfig();
+
             removePinLdapConfigStore = config.getLDAPConfig();
             removePinLdapFactory = new LdapBoundConnFactory("UidPwdPinDirAuthentication");
-            removePinLdapFactory.init(cs, removePinLdapConfigStore, engine.getPasswordStore());
+            removePinLdapFactory.init(socketConfig, removePinLdapConfigStore, engine.getPasswordStore());
 
             removePinLdapConnection = removePinLdapFactory.getConn();
         }
@@ -479,7 +482,7 @@ public class UidPwdPinDirAuthentication extends DirBasedAuthentication
 
     public void populate(IAuthToken token, IRequest request)
             throws EProfileException {
-        request.setExtData(IProfileAuthenticator.AUTHENTICATED_NAME,
+        request.setExtData(ProfileAuthenticator.AUTHENTICATED_NAME,
                 token.getInString(USER_DN));
     }
 
