@@ -28,7 +28,6 @@ import java.util.Vector;
 import com.netscape.certsrv.authentication.IAuthToken;
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.IConfigStore;
-import com.netscape.certsrv.base.ISubsystem;
 import com.netscape.certsrv.base.SessionContext;
 import com.netscape.certsrv.common.NameValuePairs;
 import com.netscape.certsrv.logging.ILogger;
@@ -48,7 +47,6 @@ import com.netscape.cms.profile.input.EnrollInput;
 import com.netscape.cms.profile.updater.IProfileUpdater;
 import com.netscape.cmscore.apps.CMS;
 import com.netscape.cmscore.apps.CMSEngine;
-import com.netscape.cmscore.profile.ProfileSubsystem;
 import com.netscape.cmscore.registry.PluginRegistry;
 
 /**
@@ -102,7 +100,6 @@ public abstract class Profile {
 
     protected IConfigStore mConfig = null;
     protected PluginRegistry registry;
-    protected ProfileSubsystem mOwner;
 
     protected Vector<String> mInputNames = new Vector<String>();
     protected Hashtable<String, ProfileInput> mInputs = new Hashtable<String, ProfileInput>();
@@ -232,15 +229,13 @@ public abstract class Profile {
 
     /**
      * Initializes this profile.
-     *
-     * @param owner profile subsystem
      * @param config configuration store for this profile
+     *
      * @exception EBaseException failed to initialize
      */
-    public void init(ISubsystem owner, IConfigStore config)
-            throws EBaseException {
+    public void init(IConfigStore config) throws EBaseException {
+
         logger.debug("Profile: start init");
-        mOwner = (ProfileSubsystem) owner;
         mConfig = config;
 
         CMSEngine engine = CMS.getCMSEngine();
