@@ -18,6 +18,8 @@
 package com.netscape.cms.profile.def;
 
 import java.io.IOException;
+import java.util.ArrayList;
+import java.util.Collection;
 import java.util.Enumeration;
 import java.util.Locale;
 import java.util.NoSuchElementException;
@@ -305,26 +307,30 @@ public abstract class EnrollDefault extends PolicyDefault {
         mValueNames.removeAllElements();
     }
 
-    protected void deleteExtension(String name, X509CertInfo info) {
-        CertificateExtensions exts = null;
+    protected void deleteExtension(String extID, X509CertInfo info) throws Exception {
 
-        try {
-            exts = (CertificateExtensions)
-                    info.get(X509CertInfo.EXTENSIONS);
-            if (exts == null)
-                return;
-            Enumeration<String> e = exts.getNames();
+        CertificateExtensions exts = (CertificateExtensions) info.get(X509CertInfo.EXTENSIONS);
 
-            while (e.hasMoreElements()) {
-                String n = e.nextElement();
-                Extension ext = (Extension) exts.get(n);
+        if (exts == null) {
+            return;
+        }
 
-                if (ext.getExtensionId().toString().equals(name)) {
-                    exts.delete(n);
-                }
+        Collection<String> names = new ArrayList<>();
+        Enumeration<String> e = exts.getNames();
+
+        // get names of extensions to remove
+        while (e.hasMoreElements()) {
+            String name = e.nextElement();
+            Extension ext = (Extension) exts.get(name);
+
+            if (ext.getExtensionId().toString().equals(extID)) {
+                names.add(name);
             }
-        } catch (Exception e) {
-            logger.warn("EnrollDefault: " + e.getMessage(), e);
+        }
+
+        // remove extensions in separate loop to avoid ConcurrentModificationException
+        for (String name : names) {
+            exts.delete(name);
         }
     }
 
@@ -410,7 +416,12 @@ public abstract class EnrollDefault extends PolicyDefault {
 
     protected void replaceExtension(String name, Extension ext, X509CertInfo info)
             throws EProfileException {
-        deleteExtension(name, info);
+        try {
+            deleteExtension(name, info);
+        } catch (Exception e) {
+            throw new EProfileException(e);
+        }
+
         addExtension(name, ext, info);
     }
 
