@@ -7,10 +7,8 @@ import java.util.Enumeration;
 import java.util.List;
 
 import org.apache.catalina.realm.RealmBase;
-import org.apache.commons.lang.StringUtils;
-import org.dogtagpki.server.authentication.IAuthManager;
-import org.dogtagpki.server.authentication.IAuthSubsystem;
-import org.dogtagpki.server.authentication.ICertUserDBAuthentication;
+import org.apache.commons.lang3.StringUtils;
+import org.dogtagpki.server.authentication.AuthManager;
 import org.mozilla.jss.netscape.security.x509.X509CertImpl;
 
 import com.netscape.certsrv.authentication.EInvalidCredentials;
@@ -21,14 +19,16 @@ import com.netscape.certsrv.base.SessionContext;
 import com.netscape.certsrv.logging.ILogger;
 import com.netscape.certsrv.logging.event.AuthEvent;
 import com.netscape.certsrv.usrgrp.EUsrGrpException;
-import com.netscape.certsrv.usrgrp.IGroup;
-import com.netscape.certsrv.usrgrp.IUser;
 import com.netscape.cms.logging.Logger;
 import com.netscape.cms.logging.SignedAuditLogger;
 import com.netscape.cms.servlet.common.AuthCredentials;
 import com.netscape.cmscore.apps.CMS;
 import com.netscape.cmscore.apps.CMSEngine;
+import com.netscape.cmscore.authentication.AuthSubsystem;
+import com.netscape.cmscore.authentication.CertUserDBAuthentication;
+import com.netscape.cmscore.usrgrp.Group;
 import com.netscape.cmscore.usrgrp.UGSubsystem;
+import com.netscape.cmscore.usrgrp.User;
 
 /**
  *  PKI Realm
@@ -58,20 +58,20 @@ public class PKIRealm extends RealmBase {
         String attemptedAuditUID = username;
 
         try {
-            IAuthSubsystem authSub = (IAuthSubsystem) engine.getSubsystem(IAuthSubsystem.ID);
-            IAuthManager authMgr = authSub.getAuthManager(IAuthSubsystem.PASSWDUSERDB_AUTHMGR_ID);
+            AuthSubsystem authSub = engine.getAuthSubsystem();
+            AuthManager authMgr = authSub.getAuthManager(AuthSubsystem.PASSWDUSERDB_AUTHMGR_ID);
 
             AuthCredentials creds = new AuthCredentials();
             creds.set(IPasswdUserDBAuthentication.CRED_UID, username);
             creds.set(IPasswdUserDBAuthentication.CRED_PWD, password);
 
             IAuthToken authToken = authMgr.authenticate(creds); // throws exception if authentication fails
-            authToken.set(SessionContext.AUTH_MANAGER_ID, IAuthSubsystem.PASSWDUSERDB_AUTHMGR_ID);
+            authToken.set(SessionContext.AUTH_MANAGER_ID, AuthSubsystem.PASSWDUSERDB_AUTHMGR_ID);
             auditSubjectID = authToken.getInString(IAuthToken.USER_ID);
 
             signedAuditLogger.log(AuthEvent.createSuccessEvent(
                         auditSubjectID,
-                        IAuthSubsystem.PASSWDUSERDB_AUTHMGR_ID));
+                        AuthSubsystem.PASSWDUSERDB_AUTHMGR_ID));
 
             return getPrincipal(username, authToken);
 
@@ -81,7 +81,7 @@ public class PKIRealm extends RealmBase {
 
             signedAuditLogger.log(AuthEvent.createFailureEvent(
                         auditSubjectID,
-                        IAuthSubsystem.PASSWDUSERDB_AUTHMGR_ID,
+                        AuthSubsystem.PASSWDUSERDB_AUTHMGR_ID,
                         attemptedAuditUID));
 
             return null;
@@ -92,7 +92,7 @@ public class PKIRealm extends RealmBase {
 
             signedAuditLogger.log(AuthEvent.createFailureEvent(
                         auditSubjectID,
-                        IAuthSubsystem.PASSWDUSERDB_AUTHMGR_ID,
+                        AuthSubsystem.PASSWDUSERDB_AUTHMGR_ID,
                         attemptedAuditUID));
 
             throw new RuntimeException(e);
@@ -124,16 +124,16 @@ public class PKIRealm extends RealmBase {
                 certImpls[i] = new X509CertImpl(cert.getEncoded());
             }
 
-            IAuthSubsystem authSub = (IAuthSubsystem) engine.getSubsystem(IAuthSubsystem.ID);
-            IAuthManager authMgr = authSub.getAuthManager(IAuthSubsystem.CERTUSERDB_AUTHMGR_ID);
+            AuthSubsystem authSub = engine.getAuthSubsystem();
+            AuthManager authMgr = authSub.getAuthManager(AuthSubsystem.CERTUSERDB_AUTHMGR_ID);
 
             AuthCredentials creds = new AuthCredentials();
-            creds.set(ICertUserDBAuthentication.CRED_CERT, certImpls);
+            creds.set(CertUserDBAuthentication.CRED_CERT, certImpls);
 
             IAuthToken authToken = authMgr.authenticate(creds); // throws exception if authentication fails
-            authToken.set(SessionContext.AUTH_MANAGER_ID,IAuthSubsystem.CERTUSERDB_AUTHMGR_ID);
+            authToken.set(SessionContext.AUTH_MANAGER_ID,AuthSubsystem.CERTUSERDB_AUTHMGR_ID);
 
-            String username = authToken.getInString(ICertUserDBAuthentication.TOKEN_USERID);
+            String username = authToken.getInString(CertUserDBAuthentication.TOKEN_USERID);
             // reset it to the one authenticated with authManager
             auditSubjectID = authToken.getInString(IAuthToken.USER_ID);
 
@@ -141,7 +141,7 @@ public class PKIRealm extends RealmBase {
 
             signedAuditLogger.log(AuthEvent.createSuccessEvent(
                         auditSubjectID,
-                        IAuthSubsystem.CERTUSERDB_AUTHMGR_ID));
+                        AuthSubsystem.CERTUSERDB_AUTHMGR_ID));
 
             return getPrincipal(username, authToken);
 
@@ -151,7 +151,7 @@ public class PKIRealm extends RealmBase {
 
             signedAuditLogger.log(AuthEvent.createFailureEvent(
                     auditSubjectID,
-                    IAuthSubsystem.CERTUSERDB_AUTHMGR_ID,
+                    AuthSubsystem.CERTUSERDB_AUTHMGR_ID,
                     attemptedAuditUID));
 
             return null;
@@ -162,7 +162,7 @@ public class PKIRealm extends RealmBase {
 
             signedAuditLogger.log(AuthEvent.createFailureEvent(
                         auditSubjectID,
-                        IAuthSubsystem.CERTUSERDB_AUTHMGR_ID,
+                        AuthSubsystem.CERTUSERDB_AUTHMGR_ID,
                         attemptedAuditUID));
 
             throw new RuntimeException(e);
@@ -189,34 +189,34 @@ public class PKIRealm extends RealmBase {
     }
 
     protected Principal getPrincipal(String username, IAuthToken authToken) throws Exception {
-        IUser user = getUser(username);
+        User user = getUser(username);
         return getPrincipal(user, authToken);
     }
 
-    protected Principal getPrincipal(IUser user, IAuthToken authToken) throws EUsrGrpException {
+    protected Principal getPrincipal(User user, IAuthToken authToken) throws EUsrGrpException {
         List<String> roles = getRoles(user);
         return new PKIPrincipal(user, null, roles, authToken);
     }
 
-    protected IUser getUser(String username) throws EUsrGrpException {
+    protected User getUser(String username) throws EUsrGrpException {
         CMSEngine engine = CMS.getCMSEngine();
         UGSubsystem ugSub = engine.getUGSubsystem();
-        IUser user = ugSub.getUser(username);
+        User user = ugSub.getUser(username);
         logger.info("PKIRealm: User DN: " + user.getUserDN());
         return user;
     }
 
-    protected List<String> getRoles(IUser user) throws EUsrGrpException {
+    protected List<String> getRoles(User user) throws EUsrGrpException {
 
         List<String> roles = new ArrayList<String>();
 
         CMSEngine engine = CMS.getCMSEngine();
         UGSubsystem ugSub = engine.getUGSubsystem();
-        Enumeration<IGroup> groups = ugSub.findGroupsByUser(user.getUserDN(), null);
+        Enumeration<Group> groups = ugSub.findGroupsByUser(user.getUserDN(), null);
 
         logger.info("PKIRealm: Roles:");
         while (groups.hasMoreElements()) {
-            IGroup group = groups.nextElement();
+            Group group = groups.nextElement();
 
             String name = group.getName();
             logger.info("PKIRealm: - " + name);
