@@ -35,11 +35,9 @@ import javax.servlet.http.HttpServlet;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
-import org.dogtagpki.server.authentication.IAuthManager;
-import org.dogtagpki.server.authentication.IAuthSubsystem;
+import org.dogtagpki.server.authentication.AuthManager;
 import org.dogtagpki.server.authorization.AuthorizationConfig;
 import org.dogtagpki.server.authorization.AuthzToken;
-import org.dogtagpki.server.authorization.IAuthzSubsystem;
 import org.mozilla.jss.netscape.security.util.Utils;
 import org.mozilla.jss.netscape.security.x509.X509CertImpl;
 
@@ -58,15 +56,17 @@ import com.netscape.certsrv.logging.event.AuthEvent;
 import com.netscape.certsrv.logging.event.AuthzEvent;
 import com.netscape.certsrv.logging.event.RoleAssumeEvent;
 import com.netscape.certsrv.usrgrp.EUsrGrpException;
-import com.netscape.certsrv.usrgrp.IUser;
 import com.netscape.cms.logging.Logger;
 import com.netscape.cms.logging.SignedAuditLogger;
 import com.netscape.cms.servlet.base.UserInfo;
 import com.netscape.cmscore.apps.CMS;
 import com.netscape.cmscore.apps.CMSEngine;
 import com.netscape.cmscore.apps.EngineConfig;
+import com.netscape.cmscore.authentication.AuthSubsystem;
+import com.netscape.cmscore.authorization.AuthzSubsystem;
 import com.netscape.cmscore.logging.Auditor;
 import com.netscape.cmscore.usrgrp.UGSubsystem;
+import com.netscape.cmscore.usrgrp.User;
 
 /**
  * A class represents an administration servlet that
@@ -107,7 +107,7 @@ public class AdminServlet extends HttpServlet {
     protected Auditor auditor = Auditor.getAuditor();
     private UGSubsystem mUG = null;
     protected EngineConfig mConfig = null;
-    protected IAuthzSubsystem mAuthz = null;
+    protected AuthzSubsystem mAuthz;
 
     // we don't allow to switch authz db mid-way, for now
     protected String mAclMethod = null;
@@ -129,10 +129,8 @@ public class AdminServlet extends HttpServlet {
     public static final String CERT_ATTR =
             "javax.servlet.request.X509Certificate";
 
-    private final static String CERTUSERDB =
-            IAuthSubsystem.CERTUSERDB_AUTHMGR_ID;
-    private final static String PASSWDUSERDB =
-            IAuthSubsystem.PASSWDUSERDB_AUTHMGR_ID;
+    private final static String CERTUSERDB = AuthSubsystem.CERTUSERDB_AUTHMGR_ID;
+    private final static String PASSWDUSERDB = AuthSubsystem.PASSWDUSERDB_AUTHMGR_ID;
 
     /**
      * Constructs generic administration servlet.
@@ -158,7 +156,7 @@ public class AdminServlet extends HttpServlet {
         } catch (EBaseException e) {
             logger.warn("AdminServlet: " + CMS.getLogMessage("ADMIN_SRVLT_FAIL_SRC_TYPE") + ": " + e.getMessage(), e);
         }
-        mAuthz = (IAuthzSubsystem) engine.getSubsystem(IAuthzSubsystem.ID);
+        mAuthz = engine.getAuthzSubsystem();
 
         mServletID = getSCparam(sc, PROP_ID, "servlet id unknown");
         logger.debug("AdminServlet: " + CMS.getLogMessage("ADMIN_SRVLT_AUTHZ_INITED", mServletID));
@@ -282,7 +280,7 @@ public class AdminServlet extends HttpServlet {
             } catch (EBaseException e) {
                 // do nothing for now.
             }
-            IAuthSubsystem auth = (IAuthSubsystem) engine.getSubsystem(IAuthSubsystem.ID);
+            AuthSubsystem auth = engine.getAuthSubsystem();
             X509Certificate cert = null;
 
             if (authType.equals("sslclientauth")) {
@@ -329,7 +327,7 @@ public class AdminServlet extends HttpServlet {
                     mServletID));
             try {
                 if (authType.equals("sslclientauth")) {
-                    IAuthManager authMgr = auth.get(IAuthSubsystem.CERTUSERDB_AUTHMGR_ID);
+                    AuthManager authMgr = auth.get(AuthSubsystem.CERTUSERDB_AUTHMGR_ID);
                     IAuthCredentials authCreds =
                             getAuthCreds(authMgr, cert);
 
@@ -360,8 +358,7 @@ public class AdminServlet extends HttpServlet {
                     cred.set("uid", userid);
                     cred.set("pwd", password);
 
-                    token = auth.authenticate(cred,
-                                IAuthSubsystem.PASSWDUSERDB_AUTHMGR_ID);
+                    token = auth.authenticate(cred, AuthSubsystem.PASSWDUSERDB_AUTHMGR_ID);
                     logger.debug("AdminServlet: " + CMS.getLogMessage("ADMIN_SRVLT_AUTH_FOR_SRVLT",
                             mServletID));
                 }
@@ -422,7 +419,7 @@ public class AdminServlet extends HttpServlet {
                 // get user.
                 // this either returns null or
                 // throws exception when user not found
-                IUser user = mUG.getUser(tuserid);
+                User user = mUG.getUser(tuserid);
 
                 if (user == null) {
                     logger.error(CMS.getLogMessage("ADMIN_SRVLT_USER_NOT_FOUND",
@@ -512,7 +509,7 @@ public class AdminServlet extends HttpServlet {
     }
 
     public static AuthCredentials getAuthCreds(
-            IAuthManager authMgr, X509Certificate clientCert)
+            AuthManager authMgr, X509Certificate clientCert)
             throws EBaseException {
         // get credentials from http parameters.
         String[] reqCreds = authMgr.getRequiredCreds();
@@ -521,7 +518,7 @@ public class AdminServlet extends HttpServlet {
         for (int i = 0; i < reqCreds.length; i++) {
             String reqCred = reqCreds[i];
 
-            if (reqCred.equals(IAuthManager.CRED_SSL_CLIENT_CERT)) {
+            if (reqCred.equals(AuthManager.CRED_SSL_CLIENT_CERT)) {
                 // cert could be null;
                 creds.set(reqCred, new X509Certificate[] { clientCert }
                         );
@@ -826,7 +823,7 @@ public class AdminServlet extends HttpServlet {
 
             // get user.
             // this either returns null or throws exception when user not found
-            IUser user = mUG.getUser(userid);
+            User user = mUG.getUser(userid);
 
             if (user == null) {
                 logger.error(CMS.getLogMessage("ADMIN_SRVLT_USER_NOT_IN_DB", userid));
