@@ -30,8 +30,7 @@ import org.dogtagpki.server.authentication.AuthManagerConfig;
 import org.dogtagpki.server.authentication.AuthManagerProxy;
 import org.dogtagpki.server.authentication.AuthManagersConfig;
 import org.dogtagpki.server.authentication.AuthenticationConfig;
-import org.dogtagpki.server.authentication.IAuthManager;
-import org.dogtagpki.server.authentication.IAuthSubsystem;
+import org.dogtagpki.server.authentication.AuthManager;
 
 import com.netscape.certsrv.authentication.AuthMgrPlugin;
 import com.netscape.certsrv.authentication.EAuthException;
@@ -49,6 +48,7 @@ import com.netscape.certsrv.logging.ILogger;
 import com.netscape.cmscore.apps.CMS;
 import com.netscape.cmscore.apps.CMSEngine;
 import com.netscape.cmscore.apps.EngineConfig;
+import com.netscape.cmscore.authentication.AuthSubsystem;
 import com.netscape.cmscore.ldapconn.LdapAuthInfo;
 
 /**
@@ -66,7 +66,7 @@ public class AuthAdminServlet extends AdminServlet {
      */
     private static final long serialVersionUID = -6258411211380144425L;
     private final static String INFO = "AuthAdminServlet";
-    private IAuthSubsystem mAuths = null;
+    private AuthSubsystem mAuths;
 
     private final static String PW_PASSWORD_CACHE_ADD =
             "PASSWORD_CACHE_ADD";
@@ -82,7 +82,7 @@ public class AuthAdminServlet extends AdminServlet {
     public void init(ServletConfig config) throws ServletException {
         super.init(config);
         CMSEngine engine = CMS.getCMSEngine();
-        mAuths = (IAuthSubsystem) engine.getSubsystem(IAuthSubsystem.ID);
+        mAuths = engine.getAuthSubsystem();
         AUTHZ_RES_NAME = "certServer.auth.configuration";
     }
 
@@ -461,11 +461,11 @@ public class AuthAdminServlet extends AdminServlet {
 
             // Does the class exist?
 
-            Class<IAuthManager> newImpl = null;
+            Class<AuthManager> newImpl = null;
 
             try {
                 @SuppressWarnings("unchecked")
-                Class<IAuthManager> tmpImpl = (Class<IAuthManager>) Class.forName(classPath);
+                Class<AuthManager> tmpImpl = (Class<AuthManager>) Class.forName(classPath);
                 newImpl = tmpImpl;
             } catch (ClassNotFoundException e) {
                 // store a message in the signed audit log file
@@ -499,7 +499,7 @@ public class AuthAdminServlet extends AdminServlet {
 
             // is the class an IAuthManager?
             try {
-                if (IAuthManager.class.isAssignableFrom(newImpl) == false) {
+                if (AuthManager.class.isAssignableFrom(newImpl) == false) {
                     // store a message in the signed audit log file
                     auditMessage = CMS.getLogMessage(
                                 AuditEvent.CONFIG_AUTH,
@@ -694,8 +694,8 @@ public class AuthAdminServlet extends AdminServlet {
             }
 
             // prevent agent & admin creation.
-            if (implname.equals(IAuthSubsystem.PASSWDUSERDB_PLUGIN_ID) ||
-                    implname.equals(IAuthSubsystem.CERTUSERDB_PLUGIN_ID)) {
+            if (implname.equals(AuthSubsystem.PASSWDUSERDB_PLUGIN_ID) ||
+                    implname.equals(AuthSubsystem.CERTUSERDB_PLUGIN_ID)) {
                 sendResponse(ERROR,
                         CMS.getUserMessage(getLocale(req), "CMS_BASE_PERMISSION_DENIED"), null, resp);
             }
@@ -741,7 +741,7 @@ public class AuthAdminServlet extends AdminServlet {
                     }
                 }
             }
-            substore.put(IAuthSubsystem.PROP_PLUGIN, implname);
+            substore.put(AuthSubsystem.PROP_PLUGIN, implname);
 
             String pwadd = req.getParameter(PW_PASSWORD_CACHE_ADD);
 
@@ -751,10 +751,10 @@ public class AuthAdminServlet extends AdminServlet {
 
             // Instantiate an object for this implementation
             String className = plugin.getClassPath();
-            IAuthManager authMgrInst = null;
+            AuthManager authMgrInst = null;
 
             try {
-                authMgrInst = (IAuthManager) Class.forName(className).newInstance();
+                authMgrInst = (AuthManager) Class.forName(className).newInstance();
             } catch (ClassNotFoundException e) {
                 // store a message in the signed audit log file
                 auditMessage = CMS.getLogMessage(
@@ -935,8 +935,8 @@ public class AuthAdminServlet extends AdminServlet {
 
         for (Enumeration<?> e = mAuths.getInstances().keys(); e.hasMoreElements();) {
             String name = (String) e.nextElement();
-            AuthManagerProxy proxy = (AuthManagerProxy) mAuths.getInstances().get(name);
-            IAuthManager value = proxy.getAuthManager();
+            AuthManagerProxy proxy = mAuths.getInstances().get(name);
+            AuthManager value = proxy.getAuthManager();
             String enableStr = "enabled";
 
             if (!proxy.isEnable()) {
@@ -1002,8 +1002,8 @@ public class AuthAdminServlet extends AdminServlet {
             }
 
             // prevent deletion of admin and agent.
-            if (id.equals(IAuthSubsystem.PASSWDUSERDB_PLUGIN_ID) ||
-                    id.equals(IAuthSubsystem.CERTUSERDB_PLUGIN_ID)) {
+            if (id.equals(AuthSubsystem.PASSWDUSERDB_PLUGIN_ID) ||
+                    id.equals(AuthSubsystem.CERTUSERDB_PLUGIN_ID)) {
                 sendResponse(ERROR,
                         CMS.getUserMessage(getLocale(req), "CMS_BASE_PERMISSION_DENIED"), null, resp);
             }
@@ -1030,7 +1030,7 @@ public class AuthAdminServlet extends AdminServlet {
             // first check if any instances from this auth manager
             // DON'T remove auth manager if any instance
             for (Enumeration<?> e = mAuths.getInstances().keys(); e.hasMoreElements();) {
-                IAuthManager authMgr = mAuths.get((String) e.nextElement());
+                AuthManager authMgr = mAuths.get((String) e.nextElement());
 
                 if (authMgr.getImplName() == id) {
                     // store a message in the signed audit log file
@@ -1171,8 +1171,8 @@ public class AuthAdminServlet extends AdminServlet {
             }
 
             // prevent deletion of admin and agent.
-            if (id.equals(IAuthSubsystem.PASSWDUSERDB_AUTHMGR_ID) ||
-                    id.equals(IAuthSubsystem.CERTUSERDB_AUTHMGR_ID)) {
+            if (id.equals(AuthSubsystem.PASSWDUSERDB_AUTHMGR_ID) ||
+                    id.equals(AuthSubsystem.CERTUSERDB_AUTHMGR_ID)) {
                 sendResponse(ERROR,
                         CMS.getUserMessage(getLocale(req), "CMS_BASE_PERMISSION_DENIED"), null, resp);
             }
@@ -1343,7 +1343,7 @@ public class AuthAdminServlet extends AdminServlet {
             return;
         }
 
-        IAuthManager mgrInst = mAuths.get(id);
+        AuthManager mgrInst = mAuths.get(id);
         IConfigStore config = mgrInst.getConfigStore();
         String[] configParams = mgrInst.getConfigParams();
         NameValuePairs params = new NameValuePairs();
@@ -1418,8 +1418,8 @@ public class AuthAdminServlet extends AdminServlet {
             }
 
             // prevent modification of admin and agent.
-            if (id.equals(IAuthSubsystem.PASSWDUSERDB_AUTHMGR_ID) ||
-                    id.equals(IAuthSubsystem.CERTUSERDB_AUTHMGR_ID)) {
+            if (id.equals(AuthSubsystem.PASSWDUSERDB_AUTHMGR_ID) ||
+                    id.equals(AuthSubsystem.CERTUSERDB_AUTHMGR_ID)) {
                 sendResponse(ERROR,
                         CMS.getUserMessage(getLocale(req), "CMS_BASE_PERMISSION_DENIED"), null, resp);
             }
@@ -1483,15 +1483,15 @@ public class AuthAdminServlet extends AdminServlet {
 
             // save old instance substore params in case new one fails.
 
-            IAuthManager oldinst = mAuths.get(id);
+            AuthManager oldinst = mAuths.get(id);
             IConfigStore oldConfig = oldinst.getConfigStore();
 
             String[] oldConfigParms = oldinst.getConfigParams();
             NameValuePairs saveParams = new NameValuePairs();
 
             // implName is always required so always include it it.
-            saveParams.put(IAuthSubsystem.PROP_PLUGIN,
-                    oldConfig.get(IAuthSubsystem.PROP_PLUGIN));
+            saveParams.put(AuthSubsystem.PROP_PLUGIN,
+                    oldConfig.get(AuthSubsystem.PROP_PLUGIN));
             if (oldConfigParms != null) {
                 for (int i = 0; i < oldConfigParms.length; i++) {
                     String key = oldConfigParms[i];
@@ -1518,7 +1518,7 @@ public class AuthAdminServlet extends AdminServlet {
 
             AuthManagerConfig substore = instancesConfig.createAuthManagerConfig(id);
 
-            substore.put(IAuthSubsystem.PROP_PLUGIN, implname);
+            substore.put(AuthSubsystem.PROP_PLUGIN, implname);
             if (configParams != null) {
                 for (int i = 0; i < configParams.length; i++) {
                     String key = configParams[i];
@@ -1533,10 +1533,10 @@ public class AuthAdminServlet extends AdminServlet {
             // Instantiate an object for new implementation
 
             String className = plugin.getClassPath();
-            IAuthManager newMgrInst = null;
+            AuthManager newMgrInst = null;
 
             try {
-                newMgrInst = (IAuthManager) Class.forName(className).newInstance();
+                newMgrInst = (AuthManager) Class.forName(className).newInstance();
             } catch (ClassNotFoundException e) {
                 // store a message in the signed audit log file
                 auditMessage = CMS.getLogMessage(
