@@ -32,7 +32,6 @@ import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
 import org.dogtag.util.cert.CertUtil;
-import org.dogtagpki.server.authorization.IAuthzSubsystem;
 import org.dogtagpki.server.ca.ICertificateAuthority;
 import org.mozilla.jss.CryptoManager;
 import org.mozilla.jss.crypto.InternalCertificate;
@@ -58,13 +57,12 @@ import com.netscape.certsrv.password.IPasswordCheck;
 import com.netscape.certsrv.ra.IRegistrationAuthority;
 import com.netscape.certsrv.tks.ITKSAuthority;
 import com.netscape.certsrv.usrgrp.EUsrGrpException;
-import com.netscape.certsrv.usrgrp.IGroup;
-import com.netscape.certsrv.usrgrp.IGroupConstants;
-import com.netscape.certsrv.usrgrp.IUser;
 import com.netscape.cmscore.apps.CMS;
 import com.netscape.cmscore.apps.CMSEngine;
 import com.netscape.cmscore.cert.CertPrettyPrint;
+import com.netscape.cmscore.usrgrp.Group;
 import com.netscape.cmscore.usrgrp.UGSubsystem;
+import com.netscape.cmscore.usrgrp.User;
 
 /**
  * A class representing an administration servlet for
@@ -105,7 +103,7 @@ public class UsrGrpAdminServlet extends AdminServlet {
     public UsrGrpAdminServlet() {
         super();
         CMSEngine engine = CMS.getCMSEngine();
-        mAuthz = (IAuthzSubsystem) engine.getSubsystem(IAuthzSubsystem.ID);
+        mAuthz = engine.getAuthzSubsystem();
     }
 
     /**
@@ -326,7 +324,7 @@ public class UsrGrpAdminServlet extends AdminServlet {
             IOException, EBaseException {
 
         String id = super.getParameter(req, Constants.RS_ID);
-        IUser user = mMgr.getUser(id);
+        User user = mMgr.getUser(id);
         String val = user.getUserType();
 
         if (val == null || val.equals(""))
@@ -350,7 +348,7 @@ public class UsrGrpAdminServlet extends AdminServlet {
 
         NameValuePairs params = new NameValuePairs();
 
-        Enumeration<IUser> e = null;
+        Enumeration<User> e = null;
 
         try {
             e = mMgr.listUsers("*");
@@ -364,7 +362,7 @@ public class UsrGrpAdminServlet extends AdminServlet {
         int i = 0;
 
         while (e.hasMoreElements()) {
-            IUser user = e.nextElement();
+            User user = e.nextElement();
 
             if (i > 0) {
                 sb.append(";");
@@ -410,7 +408,7 @@ public class UsrGrpAdminServlet extends AdminServlet {
 
         NameValuePairs params = new NameValuePairs();
 
-        IUser user = null;
+        User user = null;
 
         try {
             user = mMgr.getUser(id);
@@ -429,7 +427,7 @@ public class UsrGrpAdminServlet extends AdminServlet {
 
             // get list of groups, and get a list of those that this
             //			uid belongs to
-            Enumeration<IGroup> e = null;
+            Enumeration<Group> e = null;
 
             try {
                 e = mMgr.findGroups("*");
@@ -443,7 +441,7 @@ public class UsrGrpAdminServlet extends AdminServlet {
             StringBuffer grpString = new StringBuffer();
 
             while (e.hasMoreElements()) {
-                IGroup group = e.nextElement();
+                Group group = e.nextElement();
 
                 if (group.isMember(id) == true) {
                     if (grpString.length() != 0) {
@@ -491,7 +489,7 @@ public class UsrGrpAdminServlet extends AdminServlet {
 
         NameValuePairs params = new NameValuePairs();
 
-        IUser user = null;
+        User user = null;
 
         try {
             user = mMgr.getUser(id);
@@ -557,7 +555,7 @@ public class UsrGrpAdminServlet extends AdminServlet {
             IOException, EBaseException {
         NameValuePairs params = new NameValuePairs();
 
-        Enumeration<IGroup> e = null;
+        Enumeration<Group> e = null;
 
         try {
             e = mMgr.listGroups(null);
@@ -568,7 +566,7 @@ public class UsrGrpAdminServlet extends AdminServlet {
         }
 
         while (e.hasMoreElements()) {
-            IGroup group = e.nextElement();
+            Group group = e.nextElement();
             String desc = group.getDescription();
 
             if (desc != null) {
@@ -604,7 +602,7 @@ public class UsrGrpAdminServlet extends AdminServlet {
             return;
         }
 
-        Enumeration<IGroup> e = null;
+        Enumeration<Group> e = null;
 
         try {
             e = mMgr.findGroups(id);
@@ -615,7 +613,7 @@ public class UsrGrpAdminServlet extends AdminServlet {
         }
 
         if (e.hasMoreElements()) {
-            IGroup group = e.nextElement();
+            Group group = e.nextElement();
 
             params.put(Constants.PR_GROUP_GROUP, group.getGroupID());
             params.put(Constants.PR_GROUP_DESC,
@@ -725,7 +723,7 @@ public class UsrGrpAdminServlet extends AdminServlet {
                 return;
             }
 
-            IUser user = mMgr.createUser(id);
+            User user = mMgr.createUser(id);
             String fname = super.getParameter(req, Constants.PR_USER_FULLNAME);
 
             if ((fname == null) || (fname.length() == 0)) {
@@ -799,7 +797,7 @@ public class UsrGrpAdminServlet extends AdminServlet {
                         Constants.PR_USER_GROUP);
 
                 if (groupName != null) {
-                    Enumeration<IGroup> e = null;
+                    Enumeration<Group> e = null;
 
                     try {
                         e = mMgr.findGroups(groupName);
@@ -817,7 +815,7 @@ public class UsrGrpAdminServlet extends AdminServlet {
                     }
 
                     if (e.hasMoreElements()) {
-                        IGroup group = e.nextElement();
+                        Group group = e.nextElement();
 
                         group.addMemberName(id);
                         try {
@@ -962,7 +960,7 @@ public class UsrGrpAdminServlet extends AdminServlet {
                 return;
             }
 
-            IUser user = mMgr.createUser(id);
+            User user = mMgr.createUser(id);
             String certS = super.getParameter(req, Constants.PR_USER_CERT);
             String certsString = Cert.stripBrackets(certS);
 
@@ -1127,7 +1125,7 @@ public class UsrGrpAdminServlet extends AdminServlet {
                 certs[0].checkValidity(); // throw exception if fails
 
                 user.setX509Certificates(certs);
-                mMgr.addUserCert(user);
+                mMgr.addUserCert(id, certs[0]);
                 NameValuePairs params = new NameValuePairs();
 
                 audit(new ConfigRoleEvent(
@@ -1269,7 +1267,7 @@ public class UsrGrpAdminServlet extends AdminServlet {
                 return;
             }
 
-            IUser user = mMgr.createUser(id);
+            User user = mMgr.createUser(id);
             String certDN = super.getParameter(req, Constants.PR_USER_CERT);
 
             // no certDN is a success
@@ -1400,7 +1398,7 @@ public class UsrGrpAdminServlet extends AdminServlet {
                 return;
             }
             // get list of groups, and see if uid belongs to any
-            Enumeration<IGroup> e = null;
+            Enumeration<Group> e = null;
 
             try {
                 e = mMgr.findGroups("*");
@@ -1417,7 +1415,7 @@ public class UsrGrpAdminServlet extends AdminServlet {
             }
 
             while (e.hasMoreElements()) {
-                IGroup group = e.nextElement();
+                Group group = e.nextElement();
 
                 if (group.isMember(id) == true) {
                     if (mustDelete) {
@@ -1537,12 +1535,12 @@ public class UsrGrpAdminServlet extends AdminServlet {
                 return;
             }
 
-            IGroup group = mMgr.createGroup(id);
+            Group group = mMgr.createGroup(id);
 
             // add description if specified
             String description = super.getParameter(req, Constants.PR_GROUP_DESC);
             if (description != null && !description.equals("")) {
-                group.set(IGroupConstants.ATTR_DESCRIPTION, description);
+                group.set(Group.ATTR_DESCRIPTION, description);
             }
 
             // add members if specified
@@ -1747,15 +1745,15 @@ public class UsrGrpAdminServlet extends AdminServlet {
                 return;
             }
 
-            IGroup group = mMgr.getGroupFromName(id);
+            Group group = mMgr.getGroupFromName(id);
 
             // update description if specified
             String description = super.getParameter(req, Constants.PR_GROUP_DESC);
             if (description != null) {
                 if (description.equals("")) {
-                    group.delete(IGroupConstants.ATTR_DESCRIPTION);
+                    group.delete(Group.ATTR_DESCRIPTION);
                 } else {
-                    group.set(IGroupConstants.ATTR_DESCRIPTION, description);
+                    group.set(Group.ATTR_DESCRIPTION, description);
                 }
             }
 
@@ -1763,7 +1761,7 @@ public class UsrGrpAdminServlet extends AdminServlet {
             String members = super.getParameter(req, Constants.PR_GROUP_USER);
             if (members != null) {
                 // empty old member list
-                group.delete(IGroupConstants.ATTR_MEMBERS);
+                group.delete(Group.ATTR_MEMBERS);
 
                 // read new member list
                 StringTokenizer st = new StringTokenizer(members, ",");
@@ -1892,7 +1890,7 @@ public class UsrGrpAdminServlet extends AdminServlet {
      * TODO: replace this with GroupMemberProcessor.isDuplicate()
      */
     private boolean isDuplicate(String groupName, String memberName) {
-        Enumeration<IGroup> groups = null;
+        Enumeration<Group> groups = null;
 
         // Let's not mess with users that are already a member of this group
         boolean isMember = false;
@@ -1907,10 +1905,10 @@ public class UsrGrpAdminServlet extends AdminServlet {
         try {
             groups = mMgr.listGroups(null);
             while (groups.hasMoreElements()) {
-                IGroup group = groups.nextElement();
+                Group group = groups.nextElement();
                 String name = group.getName();
-                Enumeration<IGroup> g = mMgr.findGroups(name);
-                IGroup g1 = g.nextElement();
+                Enumeration<Group> g = mMgr.findGroups(name);
+                Group g1 = g.nextElement();
                 if (!name.equals(groupName)) {
                     if (isGroupInMultiRoleEnforceList(name)) {
                         Enumeration<String> members = g1.getMemberNames();
@@ -1974,7 +1972,7 @@ public class UsrGrpAdminServlet extends AdminServlet {
                 return;
             }
 
-            IUser user = mMgr.createUser(id);
+            User user = mMgr.createUser(id);
             String fname = super.getParameter(req, Constants.PR_USER_FULLNAME);
 
             if ((fname == null) || (fname.length() == 0)) {
