@@ -44,10 +44,9 @@ import javax.servlet.http.HttpServlet;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
-import org.apache.commons.lang.StringEscapeUtils;
-import org.dogtagpki.server.authentication.IAuthManager;
+import org.apache.commons.lang3.StringEscapeUtils;
+import org.dogtagpki.server.authentication.AuthManager;
 import org.dogtagpki.server.authorization.AuthzToken;
-import org.dogtagpki.server.authorization.IAuthzSubsystem;
 import org.dogtagpki.server.ca.ICertificateAuthority;
 import org.mozilla.jss.netscape.security.pkcs.ContentInfo;
 import org.mozilla.jss.netscape.security.pkcs.PKCS7;
@@ -71,7 +70,6 @@ import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.base.SessionContext;
 import com.netscape.certsrv.common.ICMSRequest;
 import com.netscape.certsrv.dbs.certdb.ICertRecord;
-import com.netscape.certsrv.dbs.certdb.ICertificateRepository;
 import com.netscape.certsrv.kra.IKeyRecoveryAuthority;
 import com.netscape.certsrv.logging.ILogger;
 import com.netscape.certsrv.logging.LogEvent;
@@ -82,7 +80,6 @@ import com.netscape.certsrv.logging.event.RoleAssumeEvent;
 import com.netscape.certsrv.ra.IRegistrationAuthority;
 import com.netscape.certsrv.request.IRequest;
 import com.netscape.certsrv.request.IRequestQueue;
-import com.netscape.certsrv.usrgrp.IGroup;
 import com.netscape.cms.logging.Logger;
 import com.netscape.cms.logging.SignedAuditLogger;
 import com.netscape.cms.servlet.common.AuthCredentials;
@@ -105,8 +102,11 @@ import com.netscape.cmscore.apps.CMS;
 import com.netscape.cmscore.apps.CMSEngine;
 import com.netscape.cmscore.apps.CommandQueue;
 import com.netscape.cmscore.apps.EngineConfig;
+import com.netscape.cmscore.authorization.AuthzSubsystem;
 import com.netscape.cmscore.base.ArgBlock;
+import com.netscape.cmscore.dbs.CertificateRepository;
 import com.netscape.cmscore.security.JssSubsystem;
+import com.netscape.cmscore.usrgrp.Group;
 import com.netscape.cmscore.usrgrp.UGSubsystem;
 import com.netscape.cmsutil.xml.XMLObject;
 
@@ -244,7 +244,7 @@ public abstract class CMSServlet extends HttpServlet {
 
     protected String mGetClientCert = "false";
     protected String mAuthMgr = null;
-    protected IAuthzSubsystem mAuthz = null;
+    protected AuthzSubsystem mAuthz;
 
     protected String mAclMethod = null;
     protected String mAuthzResourceName = null;
@@ -276,7 +276,7 @@ public abstract class CMSServlet extends HttpServlet {
         CMSEngine engine = CMS.getCMSEngine();
         EngineConfig cs = engine.getConfig();
 
-        mAuthz = (IAuthzSubsystem) engine.getSubsystem(IAuthzSubsystem.ID);
+        mAuthz = engine.getAuthzSubsystem();
         mId = sc.getInitParameter(PROP_ID);
 
         try {
@@ -758,7 +758,7 @@ public abstract class CMSServlet extends HttpServlet {
         if (tokenIdx != -1) {
             finalErrMsg =
                     mFinalErrorMsg.substring(0, tokenIdx) +
-                            StringEscapeUtils.escapeHtml(ex.toString()) +
+                            StringEscapeUtils.escapeHtml4(ex.toString()) +
                             mFinalErrorMsg.substring(
                                     tokenIdx + ERROR_MSG_TOKEN.length());
         }
@@ -793,7 +793,7 @@ public abstract class CMSServlet extends HttpServlet {
      * manager.
      */
     public static AuthCredentials getAuthCreds(
-            IAuthManager authMgr, IArgBlock argBlock, X509Certificate clientCert)
+            AuthManager authMgr, IArgBlock argBlock, X509Certificate clientCert)
             throws EBaseException {
         // get credentials from http parameters.
         String[] reqCreds = authMgr.getRequiredCreds();
@@ -802,7 +802,7 @@ public abstract class CMSServlet extends HttpServlet {
         for (int i = 0; i < reqCreds.length; i++) {
             String reqCred = reqCreds[i];
 
-            if (reqCred.equals(IAuthManager.CRED_SSL_CLIENT_CERT)) {
+            if (reqCred.equals(AuthManager.CRED_SSL_CLIENT_CERT)) {
                 // cert could be null;
                 creds.set(reqCred, new X509Certificate[] { clientCert }
                         );
@@ -1029,8 +1029,7 @@ public abstract class CMSServlet extends HttpServlet {
             logger.error(CMS.getLogMessage("CMSGW_NON_CERT_AUTH"));
             return null;
         }
-        ICertificateRepository certdb =
-                ((ICertificateAuthority) mAuthority).getCertificateRepository();
+        CertificateRepository certdb = ((ICertificateAuthority) mAuthority).getCertificateRepository();
 
         if (certdb == null) {
             logger.error(CMS.getLogMessage("CMSGW_CERT_DB_NULL", mAuthority.toString()));
@@ -1082,8 +1081,7 @@ public abstract class CMSServlet extends HttpServlet {
             logger.error(CMS.getLogMessage("CMSGW_NOT_CERT_AUTH"));
             return null;
         }
-        ICertificateRepository certdb =
-                ((ICertificateAuthority) mAuthority).getCertificateRepository();
+        CertificateRepository certdb = ((ICertificateAuthority) mAuthority).getCertificateRepository();
 
         if (certdb == null) {
             logger.error(CMS.getLogMessage("CMSGW_CERT_DB_NULL", mAuthority.toString()));
@@ -2053,7 +2051,7 @@ public abstract class CMSServlet extends HttpServlet {
             return null;
         }
 
-        Enumeration<IGroup> groups = null;
+        Enumeration<Group> groups = null;
 
         try {
             groups = mUG.findGroups("*");
@@ -2064,7 +2062,7 @@ public abstract class CMSServlet extends HttpServlet {
         StringBuffer membersString = new StringBuffer();
 
         while (groups.hasMoreElements()) {
-            IGroup group = groups.nextElement();
+            Group group = groups.nextElement();
 
             if (group.isMember(SubjectID) == true) {
                 if (membersString.length() != 0) {
