@@ -471,7 +471,9 @@ public class Configurator {
             CertificateSetupRequest request,
             KeyPair keyPair,
             byte[] certreq,
-            String certType) throws Exception {
+            String certType,
+            String profileID,
+            String[] dnsNames) throws Exception {
 
         PreOpConfig preopConfig = cs.getPreOpConfig();
 
@@ -489,19 +491,6 @@ public class Configurator {
 
         String sessionID = request.getInstallToken().getToken();
 
-        String profileID = preopConfig.getString("cert." + tag + ".profile");
-        logger.debug("Configurator: profile ID: " + profileID);
-
-        Boolean injectSAN = cs.getBoolean("service.injectSAN", false);
-        logger.debug("Configurator: inject SAN: " + injectSAN);
-        String[] dnsNames = null;
-
-        if (tag.equals("sslserver") && injectSAN) {
-            String list = cs.getString("service.sslserver.san");
-            logger.debug("Configurator: DNS names: " + list);
-            dnsNames = StringUtils.split(list, ",");
-        }
-
         return createRemoteCert(hostname, port, sessionID, profileID, certreq, dnsNames);
     }
 
@@ -542,6 +531,9 @@ public class Configurator {
             String[] dnsNames)
             throws Exception {
 
+        String serverURL = "https://" + hostname + ":" + port;
+        logger.info("Configurator: Submitting cert request to " + serverURL);
+
         String sysType = cs.getType();
         String machineName = cs.getHostname();
         String securePort = cs.getString("service.securePort", "");
@@ -558,9 +550,7 @@ public class Configurator {
             injectSANExtension(dnsNames, content);
         }
 
-        String serverURL = "https://" + hostname + ":" + port;
         PKIClient client = Configurator.createClient(serverURL, null, null);
-
         X509CertImpl cert = CertUtils.createRemoteCert(client, content);
 
         if (cert == null) {
@@ -674,7 +664,12 @@ public class Configurator {
         }
     }
 
-    public void loadCert(String tag, byte[] certreq, X509Certificate x509Cert) throws Exception {
+    public void loadCert(
+            String tag,
+            byte[] certreq,
+            X509Certificate x509Cert,
+            String profileID,
+            String[] dnsNames) throws Exception {
     }
 
     public void processCert(
@@ -684,11 +679,26 @@ public class Configurator {
             KeyPair keyPair,
             X509Certificate x509Cert) throws Exception {
 
+        PreOpConfig preopConfig = cs.getPreOpConfig();
+
         String tag = cert.getCertTag();
         String type = cs.getType();
 
         logger.info("Configurator: Processing " + tag + " certificate");
 
+        String profileID = preopConfig.getString("cert." + tag + ".profile");
+        logger.info("Configurator: - profile ID: " + profileID);
+
+        Boolean injectSAN = cs.getBoolean("service.injectSAN", false);
+        logger.info("Configurator: - inject SAN: " + injectSAN);
+        String[] dnsNames = null;
+
+        if (tag.equals("sslserver") && injectSAN) {
+            String list = cs.getString("service.sslserver.san");
+            logger.info("Configurator: - DNS names: " + list);
+            dnsNames = StringUtils.split(list, ",");
+        }
+
         // For external/existing CA case, some/all system certs may be provided.
         // The SSL server cert will always be generated for the current host.
 
@@ -710,7 +720,7 @@ public class Configurator {
             logger.info("Configurator: Loading existing " + tag + " certificate");
             cert.setCert(x509Cert.getEncoded());
 
-            loadCert(tag, binCertRequest, x509Cert);
+            loadCert(tag, binCertRequest, x509Cert, profileID, dnsNames);
 
         } else {
             byte[] binCertRequest = createCertRequest(tag, keyPair);
@@ -720,7 +730,14 @@ public class Configurator {
             logger.debug("Configurator: request: " + certreq);
             cs.putString(type.toLowerCase() + "." + tag + ".certreq", certreq);
 
-            X509CertImpl certImpl = createCert(tag, request, keyPair, binCertRequest, certType);
+            X509CertImpl certImpl = createCert(
+                    tag,
+                    request,
+                    keyPair,
+                    binCertRequest,
+                    certType,
+                    profileID,
+                    dnsNames);
             cert.setCert(certImpl.getEncoded());
 
             String certStr = CryptoUtil.base64Encode(cert.getCert());
