@@ -28,7 +28,7 @@ import javax.servlet.ServletOutputStream;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
-import org.apache.commons.lang.StringEscapeUtils;
+import org.apache.commons.lang3.StringEscapeUtils;
 
 import com.netscape.certsrv.authentication.IAuthToken;
 import com.netscape.certsrv.base.EBaseException;
@@ -118,7 +118,7 @@ public class GetCookie extends CMSServlet {
             u = new URL(url_e);
         } catch (Exception eee) {
             throw new ECMSGWException(
-                    "Unable to parse URL: " + StringEscapeUtils.escapeHtml(url));
+                    "Unable to parse URL: " + StringEscapeUtils.escapeHtml4(url));
         }
 
         int index2 = url_e.indexOf("subsystem=");
@@ -139,9 +139,9 @@ public class GetCookie extends CMSServlet {
             header.addStringValue("sd_uid", "");
             header.addStringValue("sd_pwd", "");
             header.addStringValue("host", u.getHost());
-            header.addStringValue("sdhost", engine.getEESSLHost());
+            header.addStringValue("sdhost", cs.getHostname());
             header.addStringValue("subsystem", subsystem);
-            header.addStringValue("url", StringEscapeUtils.escapeHtml(url_e));
+            header.addStringValue("url", StringEscapeUtils.escapeHtml4(url_e));
             header.addStringValue("errorString", "Failed Authentication");
             String sdname = cs.getString("securitydomain.name", "");
             header.addStringValue("sdname", sdname);
@@ -204,7 +204,7 @@ public class GetCookie extends CMSServlet {
                         */
                     }
 
-                    header.addStringValue("url", StringEscapeUtils.escapeHtml(url));
+                    header.addStringValue("url", StringEscapeUtils.escapeHtml4(url));
                     header.addStringValue("session_id", cookie);
 
                     try {
