@@ -449,8 +449,8 @@ public class LDAPConfigurator {
 
                 String message = "Unable to add " + dn + ": " + e;
 
-                if (ignoreErrors) {
-                    logger.warn(message);
+                if (e.getLDAPResultCode() == LDAPException.ENTRY_ALREADY_EXISTS && ignoreErrors) {
+                    logger.info(message);
 
                 } else {
                     logger.error(message);
@@ -460,8 +460,6 @@ public class LDAPConfigurator {
 
         } else if (type == LDIFContent.MODIFICATION_CONTENT) {
 
-            logger.info("Modifying " + dn);
-
             LDIFModifyContent c = (LDIFModifyContent) content;
             LDAPModification[] mods = c.getModifications();
 
@@ -473,23 +471,13 @@ public class LDAPConfigurator {
 
                 switch (operation) {
                     case LDAPModification.ADD:
-                        for (String value : values) {
-                            logger.info("- adding " + name + ": " + value);
-                        }
+                        logger.info("Adding " + name + " into " + dn);
                         break;
                     case LDAPModification.REPLACE:
-                        for (String value : values) {
-                            logger.info("- replacing " + name + ": " + value);
-                        }
+                        logger.info("Replacing " + name + " in " + dn);
                         break;
                     case LDAPModification.DELETE:
-                        if (values == null) {
-                            logger.info("- deleting " + name);
-                        } else {
-                            for (String value : values) {
-                                logger.info("- deleting " + name + ": " + value);
-                            }
-                        }
+                        logger.info("Deleting " + name + " from " + dn);
                         break;
                 }
             }
@@ -501,8 +489,11 @@ public class LDAPConfigurator {
 
                 String message = "Unable to modify " + dn + ": " + e;
 
-                if (ignoreErrors) {
-                    logger.warn(message);
+                if (e.getLDAPResultCode() == LDAPException.NO_SUCH_OBJECT && ignoreErrors) {
+                    logger.info(message);
+
+                } else if (e.getLDAPResultCode() == LDAPException.ATTRIBUTE_OR_VALUE_EXISTS && ignoreErrors) {
+                    logger.info(message);
 
                 } else {
                     logger.error(message);
@@ -596,7 +587,7 @@ public class LDAPConfigurator {
     public void createSystemContainer() throws Exception {
 
         // for older subsystems, the container ou=csusers, cn=config may not yet exist
-        String dn = "ou=csusers, cn=config";
+        String dn = "ou=csusers,cn=config";
         logger.info("Adding " + dn);
 
         LDAPAttributeSet attrs = new LDAPAttributeSet();
@@ -610,11 +601,12 @@ public class LDAPConfigurator {
             connection.add(entry);
 
         } catch (LDAPException e) {
+            String message = "Unable to add " + dn + ": " + e.getMessage();
             if (e.getLDAPResultCode() == LDAPException.ENTRY_ALREADY_EXISTS) {
-                logger.warn("Entry already exists: " + dn);
+                logger.info(message);
 
             } else {
-                logger.error("Unable to add " + dn + ": " + e.getMessage(), e);
+                logger.error(message, e);
                 throw e;
             }
         }
@@ -724,6 +716,17 @@ public class LDAPConfigurator {
                 logger.warn("Changelog already exists: " + dn);
                 // leave it, don't delete it because it will cause an operation error
 
+            } else if (e.getLDAPResultCode() == LDAPException.UNWILLING_TO_PERFORM) {
+                // Since Fedora 33 the DS changelog has moved and will be created
+                // automatically when the replication is enabled. Also, the operation
+                // to add the old changelog will fail with LDAP error 53. However, in
+                // older DS versions the old changelog still needs to be added manually.
+                // To support all DS versions the code will now ignore LDAP error 53.
+                //
+                // https://github.com/dogtagpki/pki/issues/3379
+                dn = "cn=changelog,cn=" + config.getDatabase() + ",cn=ldbm database,cn=plugins,cn=config";
+                logger.warn("Changelog has moved to " + dn);
+
             } else {
                 logger.error("Unable to add " + dn + ": " + e.getMessage(), e);
                 throw e;
