@@ -25,8 +25,7 @@ import org.dogtagpki.server.authentication.AuthManagerConfig;
 import org.dogtagpki.server.authentication.AuthManagerProxy;
 import org.dogtagpki.server.authentication.AuthManagersConfig;
 import org.dogtagpki.server.authentication.AuthenticationConfig;
-import org.dogtagpki.server.authentication.IAuthManager;
-import org.dogtagpki.server.authentication.IAuthSubsystem;
+import org.dogtagpki.server.authentication.AuthManager;
 
 import com.netscape.certsrv.authentication.AuthMgrPlugin;
 import com.netscape.certsrv.authentication.EAuthException;
@@ -38,6 +37,7 @@ import com.netscape.certsrv.authentication.IAuthCredentials;
 import com.netscape.certsrv.authentication.IAuthToken;
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.IConfigStore;
+import com.netscape.certsrv.base.ISubsystem;
 import com.netscape.cms.authentication.CMCAuth;
 import com.netscape.cmscore.apps.CMS;
 import com.netscape.cmscore.apps.CMSEngine;
@@ -51,11 +51,80 @@ import com.netscape.cmscore.apps.EngineConfig;
  * @author lhsiao
  * @version $Revision$, $Date$
  */
-public class AuthSubsystem implements IAuthSubsystem {
+public class AuthSubsystem implements ISubsystem {
 
     public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(AuthSubsystem.class);
 
-    public static final String ID = "auths";
+    public final static String ID = "auths";
+
+    public final static String PROP_CLASS = "class";
+    public final static String PROP_IMPL = "impl";
+    public final static String PROP_PLUGIN = "pluginName";
+
+    /**
+     * Constant for password based authentication plugin ID.
+     */
+    public final static String PASSWDUSERDB_PLUGIN_ID = "passwdUserDBAuthPlugin";
+
+    /**
+     * Constant for certificate based authentication plugin ID.
+     */
+    public final static String CERTUSERDB_PLUGIN_ID = "certUserDBAuthPlugin";
+
+    /**
+     * Constant for challenge based authentication plugin ID.
+     */
+    public final static String CHALLENGE_PLUGIN_ID = "challengeAuthPlugin";
+
+    /**
+     * Constant for null authentication plugin ID.
+     */
+    public final static String NULL_PLUGIN_ID = "nullAuthPlugin";
+
+    /**
+     * Constant for ssl client authentication plugin ID.
+     */
+    public final static String SSLCLIENTCERT_PLUGIN_ID = "sslClientCertAuthPlugin";
+
+    /**
+     * Constant for password based authentication manager ID.
+     */
+    public final static String PASSWDUSERDB_AUTHMGR_ID = "passwdUserDBAuthMgr";
+
+    /**
+     * Constant for certificate based authentication manager ID.
+     */
+    public final static String CERTUSERDB_AUTHMGR_ID = "certUserDBAuthMgr";
+
+    /**
+     * Constant for challenge based authentication manager ID.
+     */
+    public final static String CHALLENGE_AUTHMGR_ID = "challengeAuthMgr";
+
+    /**
+     * Constant for null authentication manager ID.
+     */
+    public final static String NULL_AUTHMGR_ID = "nullAuthMgr";
+
+    /**
+     * Constant for ssl client authentication manager ID.
+     */
+    public final static String SSLCLIENTCERT_AUTHMGR_ID = "sslClientCertAuthMgr";
+
+    /**
+     * Constant for CMC authentication plugin ID.
+     */
+    public final static String CMCAUTH_PLUGIN_ID = "CMCAuth";
+
+    /**
+     * Constant for CMC authentication manager ID.
+     */
+    public final static String CMCAUTH_AUTHMGR_ID = "CMCAuth";
+
+    /**
+     * Constant for CMC user-signed authentication manager ID.
+     */
+    public final static String CMC_USER_SIGNED_AUTH_AUTHMGR_ID = "CMCUserSignedAuth";
 
     public Hashtable<String, AuthMgrPlugin> mAuthMgrPlugins = new Hashtable<String, AuthMgrPlugin>();
     public Hashtable<String, AuthManagerProxy> mAuthMgrInsts = new Hashtable<String, AuthManagerProxy>();
@@ -210,10 +279,10 @@ public class AuthSubsystem implements IAuthSubsystem {
 
                 boolean isEnable = false;
                 // Instantiate and init the authentication manager.
-                IAuthManager authMgrInst = null;
+                AuthManager authMgrInst = null;
 
                 try {
-                    authMgrInst = (IAuthManager)
+                    authMgrInst = (AuthManager)
                             Class.forName(className).newInstance();
 
                     authMgrInst.init(insName, implName, authMgrConfig);
@@ -294,7 +363,7 @@ public class AuthSubsystem implements IAuthSubsystem {
         if (!proxy.isEnable()) {
             throw new EAuthMgrNotFound(CMS.getUserMessage("CMS_AUTHENTICATION_AUTHMGR_NOT_FOUND", authMgrInstName));
         }
-        IAuthManager authMgrInst = proxy.getAuthManager();
+        AuthManager authMgrInst = proxy.getAuthManager();
 
         if (authMgrInst == null) {
             throw new EAuthMgrNotFound(CMS.getUserMessage("CMS_AUTHENTICATION_AUTHMGR_NOT_FOUND", authMgrInstName));
@@ -305,10 +374,13 @@ public class AuthSubsystem implements IAuthSubsystem {
     /**
      * Gets a list of required authentication credential names
      * of the specified authentication manager.
+     *
+     * @param authMgrName The authentication manager name
+     * @return a Vector of required credential attribute names.
      */
     public String[] getRequiredCreds(String authMgrInstName)
             throws EAuthMgrNotFound {
-        IAuthManager authMgrInst = get(authMgrInstName);
+        AuthManager authMgrInst = get(authMgrInstName);
 
         if (authMgrInst == null) {
             throw new EAuthMgrNotFound(CMS.getUserMessage("CMS_AUTHENTICATION_AUTHMGR_NOT_FOUND", authMgrInstName));
@@ -334,11 +406,11 @@ public class AuthSubsystem implements IAuthSubsystem {
         }
 
         // a temporary instance
-        IAuthManager authMgrInst = null;
+        AuthManager authMgrInst = null;
         String className = plugin.getClassPath();
 
         try {
-            authMgrInst = (IAuthManager)
+            authMgrInst = (AuthManager)
                     Class.forName(className).newInstance();
             return (authMgrInst.getConfigParams());
 
@@ -361,11 +433,11 @@ public class AuthSubsystem implements IAuthSubsystem {
      * @param name name of the authentication manager instance
      * @param authMgr the authentication manager instance to be added
      */
-    public void add(String name, IAuthManager authMgrInst) {
+    public void add(String name, AuthManager authMgrInst) {
         mAuthMgrInsts.put(name, new AuthManagerProxy(true, authMgrInst));
     }
 
-    /*
+    /**
      * Removes a authentication manager instance.
      * @param name name of the authentication manager
      */
@@ -379,7 +451,7 @@ public class AuthSubsystem implements IAuthSubsystem {
      * @param name name of the authentication manager instance
      * @return the named authentication manager instance
      */
-    public IAuthManager get(String name) {
+    public AuthManager get(String name) {
         AuthManagerProxy proxy = mAuthMgrInsts.get(name);
 
         if (proxy == null)
@@ -390,12 +462,12 @@ public class AuthSubsystem implements IAuthSubsystem {
     /**
      * Enumerate all authentication manager instances.
      */
-    public Enumeration<IAuthManager> getAuthManagers() {
-        Vector<IAuthManager> inst = new Vector<IAuthManager>();
+    public Enumeration<AuthManager> getAuthManagers() {
+        Vector<AuthManager> inst = new Vector<AuthManager>();
         Enumeration<String> e = mAuthMgrInsts.keys();
 
         while (e.hasMoreElements()) {
-            IAuthManager p = get(e.nextElement());
+            AuthManager p = get(e.nextElement());
 
             if (p != null) {
                 inst.addElement(p);
@@ -423,13 +495,13 @@ public class AuthSubsystem implements IAuthSubsystem {
      */
 
     /* getconfigparams above should be recoded to use this func */
-    public IAuthManager getAuthManagerPlugin(String name) {
+    public AuthManager getAuthManagerPlugin(String name) {
         AuthMgrPlugin plugin = mAuthMgrPlugins.get(name);
         String classpath = plugin.getClassPath();
-        IAuthManager authMgrInst = null;
+        AuthManager authMgrInst = null;
 
         try {
-            authMgrInst = (IAuthManager) Class.forName(classpath).newInstance();
+            authMgrInst = (AuthManager) Class.forName(classpath).newInstance();
             return (authMgrInst);
         } catch (Exception e) {
             logger.warn("AuthSubsystem: " + CMS.getLogMessage("CMSCORE_AUTH_INSTANCE_NOT_CREATED", e.toString()), e);
@@ -473,7 +545,7 @@ public class AuthSubsystem implements IAuthSubsystem {
     public void shutdown() {
         for (AuthManagerProxy proxy : mAuthMgrInsts.values()) {
 
-            IAuthManager mgr = proxy.getAuthManager();
+            AuthManager mgr = proxy.getAuthManager();
 
             logger.info("AuthSubsystem: " + CMS.getLogMessage("CMSCORE_AUTH_INSTANCE_SHUTDOWN", mgr.getName()));
 
@@ -483,17 +555,26 @@ public class AuthSubsystem implements IAuthSubsystem {
         mAuthMgrInsts.clear();
     }
 
+    /**
+     * Get a hashtable containing all authentication plugins.
+     *
+     * @return all authentication plugins.
+     */
     public Hashtable<String, AuthMgrPlugin> getPlugins() {
         return mAuthMgrPlugins;
     }
 
+    /**
+     * Get a hashtable containing all authentication instances.
+     *
+     * @return all authentication instances.
+     */
     public Hashtable<String, AuthManagerProxy> getInstances() {
         return mAuthMgrInsts;
     }
 
     /**
      * Returns the root configuration storage of this system.
-     * <P>
      *
      * @return configuration store of this subsystem
      */
@@ -507,7 +588,7 @@ public class AuthSubsystem implements IAuthSubsystem {
      * @param name of the authentication manager
      * @return the named authentication manager
      */
-    public IAuthManager getAuthManager(String name) {
+    public AuthManager getAuthManager(String name) {
         return get(name);
     }
 }
