@@ -44,8 +44,8 @@ import java.util.StringTokenizer;
 
 import javax.ws.rs.core.MultivaluedMap;
 
-import org.apache.commons.lang.ArrayUtils;
-import org.apache.commons.lang.StringUtils;
+import org.apache.commons.lang3.ArrayUtils;
+import org.apache.commons.lang3.StringUtils;
 import org.dogtag.util.cert.CertUtil;
 import org.dogtagpki.server.ca.ICertificateAuthority;
 import org.mozilla.jss.CertificateUsage;
@@ -77,19 +77,14 @@ import org.mozilla.jss.pkix.crmf.CertReqMsg;
 import org.xml.sax.SAXException;
 
 import com.netscape.certsrv.base.EBaseException;
-import com.netscape.certsrv.base.EPropertyNotFound;
-import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.base.MetaInfo;
 import com.netscape.certsrv.client.PKIClient;
 import com.netscape.certsrv.dbs.certdb.ICertRecord;
-import com.netscape.certsrv.dbs.certdb.ICertificateRepository;
 import com.netscape.certsrv.logging.AuditEvent;
 import com.netscape.certsrv.logging.ILogger;
 import com.netscape.certsrv.logging.LogEvent;
 import com.netscape.certsrv.profile.EProfileException;
 import com.netscape.certsrv.request.IRequest;
-import com.netscape.certsrv.request.IRequestQueue;
-import com.netscape.certsrv.request.RequestId;
 import com.netscape.certsrv.request.RequestStatus;
 import com.netscape.cms.logging.Logger;
 import com.netscape.cms.logging.SignedAuditLogger;
@@ -98,6 +93,7 @@ import com.netscape.cms.servlet.csadmin.CertInfoProfile;
 import com.netscape.cmscore.apps.CMS;
 import com.netscape.cmscore.apps.CMSEngine;
 import com.netscape.cmscore.apps.EngineConfig;
+import com.netscape.cmscore.dbs.CertificateRepository;
 import com.netscape.cmsutil.crypto.CryptoUtil;
 import com.netscape.cmsutil.xml.XMLObject;
 
@@ -941,56 +937,11 @@ public class CertUtils {
         return tmp.toString();
     }
 
-    // Dynamically apply the SubjectAlternativeName extension to a
-    // remote PKI instance's request for its SSL Server Certificate.
-    //
-    // Since this information may vary from instance to
-    // instance, obtain the necessary information from the
-    // 'service.sslserver.san' value(s) in the instance's
-    // CS.cfg, process these values converting each item into
-    // its individual SubjectAlternativeName components, and
-    // build an SSL Server Certificate URL extension consisting
-    // of this information.
-    //
-    // 03/27/2013 - Should consider removing this
-    //              "buildSANSSLserverURLExtension()"
-    //              method if it becomes possible to
-    //              embed a certificate extension into
-    //              a PKCS #10 certificate request.
-    //
-    public static void buildSANSSLserverURLExtension(IConfigStore config, MultivaluedMap<String, String> content)
-           throws Exception {
-
-        logger.debug("CertUtils: buildSANSSLserverURLExtension() " +
-                  "building SAN SSL Server Certificate URL extension . . .");
-
-        if (config == null) {
-            throw new EBaseException("injectSANextensionIntoRequest: parameter config cannot be null");
-        }
-
-        String sanHostnames = config.getString("service.sslserver.san");
-        String sans[] = StringUtils.split(sanHostnames, ",");
-
-        int i = 0;
-        for (String san : sans) {
-            logger.debug("CertUtils: buildSANSSLserverURLExtension() processing " +
-                      "SAN hostname: " + san);
-            // Add the DNSName for all SANs
-            content.putSingle("req_san_pattern_" + i, san);
-            i++;
-        }
-
-        content.putSingle("req_san_entries", "" + i);
-
-        logger.debug("CertUtils: buildSANSSLserverURLExtension() " + "placed " +
-                  i + " SAN entries into SSL Server Certificate URL.");
-    }
-
-    /*
-     * create requests so renewal can work on these initial certs
+    /**
+     * Initialize request for future renewal.
      */
-    public static IRequest createLocalRequest(
-            IRequestQueue queue,
+    public static void initLocalRequest(
+            IRequest req,
             CertInfoProfile profile,
             X509CertInfo info,
             X509Key x509key,
@@ -1004,8 +955,6 @@ public class CertUtils {
 
         logger.info("CertUtils: Creating local request");
 
-        IRequest req = queue.newRequest("enrollment");
-
         req.setExtData("profile", "true");
         req.setExtData("requestversion", "1.0.0");
         req.setExtData("req_seq_num", "0");
@@ -1072,47 +1021,6 @@ public class CertUtils {
         // mark request as complete
         logger.debug("CertUtils: calling setRequestStatus");
         req.setRequestStatus(RequestStatus.COMPLETE);
-
-        return req;
-    }
-
-    /**
-     * update local cert request with the actual request
-     * called from CertRequestPanel.java
-     * @throws EBaseException
-     * @throws EPropertyNotFound
-     */
-    public static void updateLocalRequest(
-            String reqId,
-            byte[] certReq,
-            String reqType,
-            String subjectName
-            ) throws Exception {
-
-        logger.debug("CertUtils: updateLocalRequest(" + reqId + ")");
-
-        CMSEngine engine = CMS.getCMSEngine();
-        ICertificateAuthority ca = (ICertificateAuthority) engine.getSubsystem(ICertificateAuthority.ID);
-        IRequestQueue queue = ca.getRequestQueue();
-
-        IRequest req = queue.findRequest(new RequestId(reqId));
-
-        if (certReq != null) {
-            logger.debug("CertUtils: updating cert request");
-            String certReqs = CryptoUtil.base64Encode(certReq);
-            String certReqf = CryptoUtil.reqFormat(certReqs);
-            req.setExtData("cert_request", certReqf);
-        }
-
-        req.setExtData("cert_request_type", reqType);
-
-        if (subjectName != null) {
-            logger.debug("CertUtils: updating request subject: " + subjectName);
-            req.setExtData("subject", subjectName);
-            new X500Name(subjectName); // check for errors
-        }
-
-        queue.updateRequest(req);
     }
 
     public static X509CertInfo createCertInfo(
@@ -1128,7 +1036,7 @@ public class CertUtils {
 
         CMSEngine engine = CMS.getCMSEngine();
         ICertificateAuthority ca = (ICertificateAuthority) engine.getSubsystem(ICertificateAuthority.ID);
-        ICertificateRepository cr = ca.getCertificateRepository();
+        CertificateRepository cr = ca.getCertificateRepository();
         BigInteger serialNo = cr.getNextSerialNumber();
 
         X509CertInfo info;
@@ -1172,7 +1080,7 @@ public class CertUtils {
 
         CMSEngine engine = CMS.getCMSEngine();
         ICertificateAuthority ca = (ICertificateAuthority) engine.getSubsystem(ICertificateAuthority.ID);
-        ICertificateRepository cr = ca.getCertificateRepository();
+        CertificateRepository cr = ca.getCertificateRepository();
 
         MetaInfo meta = new MetaInfo();
         meta.set(ICertRecord.META_REQUEST_ID, request.getRequestId().toString());
@@ -1182,34 +1090,6 @@ public class CertUtils {
         cr.addCertificateRecord(record);
     }
 
-    public static void createCertRecord(
-            IRequest request,
-            CertInfoProfile profile,
-            X509Certificate cert) throws Exception {
-
-        X509CertImpl certImpl = new X509CertImpl(cert.getEncoded());
-        createCertRecord(request, profile, certImpl);
-    }
-
-    public static X509CertImpl createLocalCert(
-            IRequest req,
-            CertInfoProfile profile,
-            X509CertInfo info,
-            java.security.PrivateKey signingPrivateKey,
-            String caSigningKeyAlgo) throws Exception {
-
-        profile.populate(req, info);
-
-        X509CertImpl cert = CryptoUtil.signCert(signingPrivateKey, info, caSigningKeyAlgo);
-
-        createCertRecord(req, profile, cert);
-
-        // update request with cert
-        req.setExtData(EnrollProfile.REQUEST_ISSUED_CERT, cert);
-
-        return cert;
-    }
-
     public static X509CertImpl createRemoteCert(
             PKIClient client,
             MultivaluedMap<String, String> content)
@@ -1218,19 +1098,19 @@ public class CertUtils {
         logger.debug("CertUtils: Calling profileSubmit");
         logger.debug("CertUtils: content: " + content);
 
-        String c = client.post("/ca/ee/ca/profileSubmit", content);
+        String response = client.post("/ca/ee/ca/profileSubmit", content, String.class);
+        logger.debug("CertUtils: Response: " + response);
 
-        if (c == null) {
+        if (response == null) {
             logger.error("CertUtils: Missing CA response");
             throw new Exception("Missing CA response");
         }
 
-        ByteArrayInputStream bis = new ByteArrayInputStream(c.getBytes());
+        ByteArrayInputStream bis = new ByteArrayInputStream(response.getBytes());
         XMLObject parser;
         try {
             parser = new XMLObject(bis);
         } catch (SAXException e) {
-            logger.error("Response: " + c);
             logger.error("CertUtils: Unable to parse XML response: " + e, e);
             throw e;
         }
