@@ -25,6 +25,7 @@ import org.mozilla.jss.netscape.security.x509.CertificateValidity;
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.EPropertyNotDefined;
 import com.netscape.certsrv.base.IConfigStore;
+import com.netscape.certsrv.base.ISubsystem;
 import com.netscape.certsrv.dbs.EDBException;
 import com.netscape.certsrv.dbs.EDBNotAvailException;
 import com.netscape.certsrv.dbs.IDBRegistry;
@@ -41,6 +42,7 @@ import com.netscape.cmscore.ldapconn.LDAPConfig;
 import com.netscape.cmscore.ldapconn.LdapAuthInfo;
 import com.netscape.cmscore.ldapconn.LdapBoundConnFactory;
 import com.netscape.cmscore.ldapconn.LdapConnInfo;
+import com.netscape.cmscore.ldapconn.PKISocketConfig;
 
 import netscape.ldap.LDAPAttribute;
 import netscape.ldap.LDAPAttributeSchema;
@@ -65,11 +67,15 @@ import netscape.ldap.LDAPv3;
  * @author thomask
  * @version $Revision$, $Date$
  */
-public class DBSubsystem implements IDBSubsystem {
+public class DBSubsystem implements ISubsystem {
 
     public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(DBSubsystem.class);
 
-    public static String ID = IDBSubsystem.SUB_ID;
+    public final static String ID = "dbs";
+    public final static int CERTS = 0;
+    public final static int REQUESTS = 1;
+    public final static int REPLICA_ID = 2;
+    public final static int NUM_REPOS = 3;
 
     private LDAPConfig mConfig;
     private DatabaseConfig mDBConfig;
@@ -143,9 +149,9 @@ public class DBSubsystem implements IDBSubsystem {
 
     // singleton enforcement
 
-    private static IDBSubsystem mInstance = new DBSubsystem();
+    private static DBSubsystem mInstance = new DBSubsystem();
 
-    public static IDBSubsystem getInstance() {
+    public static DBSubsystem getInstance() {
         return mInstance;
     }
 
@@ -155,7 +161,7 @@ public class DBSubsystem implements IDBSubsystem {
      *
      * @param dbSubsystem The stubbed out subsystem to override with.
      */
-    public static void setInstance(IDBSubsystem dbSubsystem) {
+    public static void setInstance(DBSubsystem dbSubsystem) {
         mInstance = dbSubsystem;
     }
 
@@ -164,14 +170,14 @@ public class DBSubsystem implements IDBSubsystem {
     /**
      * Constructs database subsystem.
      */
-    private DBSubsystem() {
+    public DBSubsystem() {
     }
 
     /**
      * Retrieves subsystem identifier.
      */
     public String getId() {
-        return IDBSubsystem.SUB_ID;
+        return ID;
     }
 
     /**
@@ -416,6 +422,7 @@ public class DBSubsystem implements IDBSubsystem {
     public String getNextRange(int repo) {
 
         CMSEngine engine = CMS.getCMSEngine();
+        EngineConfig cs = engine.getConfig();
 
         LDAPConnection conn = null;
         String nextRange = null;
@@ -457,7 +464,7 @@ public class DBSubsystem implements IDBSubsystem {
             attrs.add(new LDAPAttribute("beginRange", nextRange));
             attrs.add(new LDAPAttribute("endRange", endRange));
             attrs.add(new LDAPAttribute("cn", nextRange));
-            attrs.add(new LDAPAttribute("host", engine.getEESSLHost()));
+            attrs.add(new LDAPAttribute("host", cs.getHostname()));
             attrs.add(new LDAPAttribute("securePort", engine.getEESSLPort()));
             String dn2 = "cn=" + nextRange + "," + rangeDN;
             LDAPEntry rangeEntry = new LDAPEntry(dn2, attrs);
@@ -499,6 +506,7 @@ public class DBSubsystem implements IDBSubsystem {
     public boolean hasRangeConflict(int repo) {
 
         CMSEngine engine = CMS.getCMSEngine();
+        EngineConfig cs = engine.getConfig();
 
         LDAPConnection conn = null;
         boolean conflict = false;
@@ -511,7 +519,7 @@ public class DBSubsystem implements IDBSubsystem {
             conn = mLdapConnFactory.getConn();
             String rangedn = h.get(PROP_RANGE_DN) + "," + mBaseDN;
             String filter = "(&(nsds5ReplConflict=*)(objectClass=pkiRange)(host= " +
-                    engine.getEESSLHost() + ")(SecurePort=" + engine.getEESSLPort() +
+                    cs.getHostname() + ")(SecurePort=" + engine.getEESSLPort() +
                     ")(beginRange=" + nextRangeStart + "))";
             LDAPSearchResults results = conn.search(rangedn, LDAPv3.SCOPE_SUB,
                     filter, null, false);
@@ -553,7 +561,7 @@ public class DBSubsystem implements IDBSubsystem {
         EngineConfig cs = engine.getConfig();
 
         mDBConfig = cs.getDatabaseConfig();
-        mRepos = new Hashtable[IDBSubsystem.NUM_REPOS];
+        mRepos = new Hashtable[DBSubsystem.NUM_REPOS];
 
         mConfig = config.getSubStore(PROP_LDAP, LDAPConfig.class);
         try {
@@ -656,9 +664,11 @@ public class DBSubsystem implements IDBSubsystem {
         }
 
         try {
+            PKISocketConfig socketConfig = cs.getSocketConfig();
             LDAPConfig tmpConfig = (LDAPConfig) mConfig.clone();
             tmpConfig.setBaseDN(mBaseDN);
-            mLdapConnFactory.init(cs, tmpConfig, engine.getPasswordStore());
+
+            mLdapConnFactory.init(socketConfig, tmpConfig, engine.getPasswordStore());
 
         } catch (EPropertyNotDefined e) {
             logger.error("DBSubsystem: initialization failed: " + e.getMessage(), e);
