@@ -30,15 +30,14 @@ import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.base.ISubsystem;
 import com.netscape.certsrv.base.MetaInfo;
 import com.netscape.certsrv.dbs.certdb.ICertRecord;
-import com.netscape.certsrv.dbs.certdb.ICertificateRepository;
 import com.netscape.certsrv.ldap.ELdapException;
-import com.netscape.certsrv.publish.IPublisherProcessor;
 import com.netscape.certsrv.request.IRequest;
 import com.netscape.certsrv.request.IRequestListener;
 import com.netscape.certsrv.request.RequestId;
 import com.netscape.cms.profile.common.EnrollProfile;
 import com.netscape.cmscore.apps.CMS;
 import com.netscape.cmscore.dbs.CertRecord;
+import com.netscape.cmscore.dbs.CertificateRepository;
 
 public class LdapRequestListener implements IRequestListener {
 
@@ -160,9 +159,9 @@ class LdapEnrollmentListener implements IRequestListener {
 
     public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(LdapEnrollmentListener.class);
 
-    IPublisherProcessor mProcessor = null;
+    PublisherProcessor mProcessor = null;
 
-    public LdapEnrollmentListener(IPublisherProcessor processor) {
+    public LdapEnrollmentListener(PublisherProcessor processor) {
         mProcessor = processor;
     }
 
@@ -244,9 +243,9 @@ class LdapRenewalListener implements IRequestListener {
 
     public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(LdapRenewalListener.class);
 
-    private IPublisherProcessor mProcessor = null;
+    private PublisherProcessor mProcessor = null;
 
-    public LdapRenewalListener(IPublisherProcessor processor) {
+    public LdapRenewalListener(PublisherProcessor processor) {
         mProcessor = processor;
     }
 
@@ -301,9 +300,9 @@ class LdapRevocationListener implements IRequestListener {
 
     public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(LdapRevocationListener.class);
 
-    private IPublisherProcessor mProcessor = null;
+    private PublisherProcessor mProcessor = null;
 
-    public LdapRevocationListener(IPublisherProcessor processor) {
+    public LdapRevocationListener(PublisherProcessor processor) {
         mProcessor = processor;
     }
 
@@ -348,8 +347,7 @@ class LdapRevocationListener implements IRequestListener {
                         !(auth instanceof ICertificateAuthority)) {
                     logger.warn("Trying to get a certificate from non certificate authority.");
                 } else {
-                    ICertificateRepository certdb =
-                            ((ICertificateAuthority) auth).getCertificateRepository();
+                    CertificateRepository certdb = ((ICertificateAuthority) auth).getCertificateRepository();
 
                     if (certdb == null) {
                         logger.warn("Cert DB is null for " + auth);
@@ -407,9 +405,9 @@ class LdapUnrevocationListener implements IRequestListener {
 
     public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(LdapUnrevocationListener.class);
 
-    private IPublisherProcessor mProcessor = null;
+    private PublisherProcessor mProcessor = null;
 
-    public LdapUnrevocationListener(IPublisherProcessor processor) {
+    public LdapUnrevocationListener(PublisherProcessor processor) {
         mProcessor = processor;
     }
 
@@ -453,7 +451,7 @@ class LdapUnrevocationListener implements IRequestListener {
                         !(auth instanceof ICertificateAuthority)) {
                     logger.warn("Trying to get a certificate from non certificate authority");
                 } else {
-                    ICertificateRepository certdb = ((ICertificateAuthority) auth).getCertificateRepository();
+                    CertificateRepository certdb = ((ICertificateAuthority) auth).getCertificateRepository();
 
                     if (certdb == null) {
                         logger.warn("Cert DB is null for " + auth);
