@@ -43,6 +43,7 @@ import com.netscape.cmscore.base.LDAPConfigStore;
 import com.netscape.cmscore.base.PropConfigStore;
 import com.netscape.cmscore.ldapconn.LDAPConfig;
 import com.netscape.cmscore.ldapconn.LdapBoundConnFactory;
+import com.netscape.cmscore.ldapconn.PKISocketConfig;
 import com.netscape.cmscore.registry.PluginRegistry;
 import com.netscape.cmsutil.ldap.LDAPUtil;
 
@@ -100,9 +101,11 @@ public class LDAPProfileSubsystem
         CMSEngine engine = CMS.getCMSEngine();
         EngineConfig cs = engine.getConfig();
 
+        PKISocketConfig socketConfig = cs.getSocketConfig();
         LDAPConfig dbCfg = cs.getInternalDBConfig();
+
         dbFactory = new LdapBoundConnFactory("LDAPProfileSubsystem");
-        dbFactory.init(cs, dbCfg, engine.getPasswordStore());
+        dbFactory.init(socketConfig, dbCfg, engine.getPasswordStore());
 
         mConfig = config;
 
@@ -225,7 +228,12 @@ public class LDAPProfileSubsystem
     private synchronized Profile createProfile(
             String id, String classid, String className, InputStream data)
             throws EProfileException {
+
+        LDAPConnection conn = null;
+
         try {
+            conn = dbFactory.getConn();
+
             String[] objectClasses = {"top", "certProfile"};
             LDAPAttribute[] createAttrs = {
                 new LDAPAttribute("objectclass", objectClasses),
@@ -233,7 +241,7 @@ public class LDAPProfileSubsystem
                 new LDAPAttribute("classId", classid)
             };
 
-            ConfigStorage storage = new LDAPConfigStore(dbFactory, createProfileDN(id), createAttrs, "certProfileConfig");
+            ConfigStorage storage = new LDAPConfigStore(conn, createProfileDN(id), createAttrs, "certProfileConfig");
             IConfigStore subStoreConfig = new PropConfigStore(storage);
 
             if (data != null)
@@ -242,13 +250,17 @@ public class LDAPProfileSubsystem
             logger.debug("LDAPProfileSubsystem: initing " + className);
             Profile profile = (Profile) Class.forName(className).newInstance();
             profile.setId(id);
-            profile.init(this, subStoreConfig);
+            profile.init(subStoreConfig);
             mProfiles.put(id, profile);
             mProfileClassIds.put(id, classid);
             return profile;
+
         } catch (Exception e) {
             logger.error("LDAPProfileSubsystem: error creating or reading profile: " + e, e);
-            throw new EProfileException("Error creating or reading profile", e);
+            throw new EProfileException("Error creating or reading profile: " + e, e);
+
+        } finally {
+            if (conn != null) dbFactory.returnConn(conn);
         }
     }
 
