@@ -45,7 +45,6 @@ import com.netscape.cmscore.apps.CMSEngine;
 import com.netscape.cmscore.apps.EngineConfig;
 import com.netscape.cmscore.base.PropConfigStore;
 import com.netscape.cmscore.request.ARequestQueue;
-import com.netscape.cmscore.util.AssertionException;
 
 /**
  * This is a Generic policy processor. The three main functions of
@@ -144,14 +143,14 @@ public class GenericPolicyProcessor implements IPolicyProcessor {
      * @param config configuration of this subsystem
      * @exception EBaseException failed to initialize this Subsystem.
      */
-    public synchronized void init(ISubsystem owner, IConfigStore config)
+    public synchronized void init(IAuthority owner, IConfigStore config)
             throws EBaseException {
         logger.debug("GenericPolicyProcessor::init begins");
 
         CMSEngine engine = CMS.getCMSEngine();
         EngineConfig configStore = engine.getConfig();
 
-        mAuthority = (IAuthority) owner;
+        mAuthority = owner;
         mConfig = config;
         mGlobalStore = configStore;
 
@@ -1449,75 +1448,3 @@ public class GenericPolicyProcessor implements IPolicyProcessor {
         }
     }
 }
-
-/**
- * Class to keep track of various configurable implementations.
- */
-class RegisteredPolicy {
-    String mId;
-    String mClPath;
-
-    public RegisteredPolicy(String id, String clPath) {
-        if (id == null || clPath == null)
-            throw new AssertionException("Policy id or classpath can't be null");
-        mId = id;
-        mClPath = clPath;
-    }
-
-    public String getClassPath() {
-        return mClPath;
-    }
-
-    public String getId() {
-        return mId;
-    }
-}
-
-class PolicyInstance {
-    String mInstanceId;
-    String mImplId;
-    IPolicyRule mRule;
-    boolean mIsEnabled;
-
-    public PolicyInstance(String instanceId, String implId,
-            IPolicyRule rule, boolean isEnabled) {
-        mInstanceId = instanceId;
-        mImplId = implId;
-        mRule = rule;
-        mIsEnabled = isEnabled;
-    }
-
-    public String getInstanceId() {
-        return mInstanceId;
-    }
-
-    public String getImplId() {
-        return mImplId;
-    }
-
-    public String getRuleInfo() {
-        String enabled = mIsEnabled ? "enabled" : "disabled";
-
-        return mInstanceId + ";" + mImplId + ";visible;" + enabled;
-    }
-
-    public IPolicyRule getRule() {
-        return mRule;
-    }
-
-    public boolean isInstanceOf(String implId) {
-        return mImplId.equals(implId);
-    }
-
-    public boolean isActive() {
-        return mIsEnabled;
-    }
-
-    public void setActive(boolean stat) {
-        mIsEnabled = stat;
-    }
-
-    public void setRule(IPolicyRule newRule) {
-        mRule = newRule;
-    }
-}
