@@ -18,7 +18,6 @@
 package org.dogtagpki.server.ca;
 
 import java.util.Enumeration;
-import java.util.List;
 import java.util.Map;
 
 import javax.servlet.http.HttpServletRequest;
@@ -28,27 +27,23 @@ import org.mozilla.jss.crypto.SignatureAlgorithm;
 import org.mozilla.jss.netscape.security.x509.CertificateChain;
 import org.mozilla.jss.netscape.security.x509.CertificateIssuerName;
 import org.mozilla.jss.netscape.security.x509.CertificateSubjectName;
-import org.mozilla.jss.netscape.security.x509.CertificateVersion;
 import org.mozilla.jss.netscape.security.x509.X500Name;
 import org.mozilla.jss.netscape.security.x509.X509CRLImpl;
 import org.mozilla.jss.netscape.security.x509.X509CertImpl;
 import org.mozilla.jss.netscape.security.x509.X509CertInfo;
 
-import com.netscape.certsrv.authentication.IAuthToken;
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.base.ISubsystem;
 import com.netscape.certsrv.ca.AuthorityID;
 import com.netscape.certsrv.ca.ECAException;
-import com.netscape.certsrv.dbs.certdb.ICertificateRepository;
-import com.netscape.certsrv.dbs.crldb.ICRLRepository;
 import com.netscape.certsrv.dbs.replicadb.IReplicaIDRepository;
 import com.netscape.certsrv.request.IRequestListener;
 import com.netscape.certsrv.request.IRequestNotifier;
 import com.netscape.certsrv.request.IRequestQueue;
 import com.netscape.certsrv.request.IService;
 import com.netscape.certsrv.security.ISigningUnit;
-import com.netscape.cmscore.dbs.IDBSubsystem;
+import com.netscape.cmscore.dbs.CertificateRepository;
 import com.netscape.cmscore.ldap.PublisherProcessor;
 
 /**
@@ -62,8 +57,6 @@ public interface ICertificateAuthority extends ISubsystem {
 
     public static final String ID = "ca";
 
-    public static final String PROP_CERTDB_INC = "certdbInc";
-    public static final String PROP_CRLDB_INC = "crldbInc";
     public static final String PROP_REGISTRATION = "Registration";
     public static final String PROP_POLICY = "Policy";
     public static final String PROP_GATEWAY = "gateway";
@@ -105,24 +98,18 @@ public interface ICertificateAuthority extends ISubsystem {
     public final static String PROP_CA_NAMES = "CAs";
 
     public final static String PROP_SIGNING_SUBSTORE = "signing";
-    public final static String PROP_CA_CHAIN_NUM = "certchainNum";
-    public final static String PROP_CA_CHAIN = "certchain";
-    public final static String PROP_CA_CERT = "cert";
     public final static String PROP_ENABLE_OCSP = "ocsp";
     public final static String PROP_OCSP_SIGNING_SUBSTORE = "ocsp_signing";
     public final static String PROP_CRL_SIGNING_SUBSTORE = "crl_signing";
     public final static String PROP_ID = "id";
 
-    public final static String PROP_CERTDB_TRANS_MAXRECORDS = "transitMaxRecords";
-    public final static String PROP_CERTDB_TRANS_PAGESIZE = "transitRecordPageSize";
-
     /**
      * Retrieves the certificate repository where all the locally
      * issued certificates are kept.
      *
      * @return CA's certificate repository
      */
-    public ICertificateRepository getCertificateRepository();
+    public CertificateRepository getCertificateRepository();
 
     /**
      * Retrieves the request queue of this certificate authority.
@@ -209,16 +196,6 @@ public interface ICertificateAuthority extends ISubsystem {
      */
     public String[] getCASigningAlgorithms();
 
-    /**
-     * Allows certificates to have validities that are longer
-     * than this certificate authority's.
-     *
-     * @param enableCAPast if equals "true", it allows certificates
-     *            to have validity longer than CA's certificate validity
-     * @exception EBaseException failed to set above option
-     */
-    public void setValidity(String enableCAPast) throws EBaseException;
-
     /**
      * Retrieves the default validity period.
      *
@@ -226,21 +203,6 @@ public interface ICertificateAuthority extends ISubsystem {
      */
     public long getDefaultValidity();
 
-    /**
-     * Retrieves all the CRL issuing points.
-     *
-     * @return enumeration of all the CRL issuing points
-     */
-    public Enumeration<ICRLIssuingPoint> getCRLIssuingPoints();
-
-    /**
-     * Retrieves CRL issuing point with the given identifier.
-     *
-     * @param id CRL issuing point id
-     * @return CRL issuing point with given id
-     */
-    public ICRLIssuingPoint getCRLIssuingPoint(String id);
-
     /**
      * Adds CRL issuing point with the given identifier and description.
      *
@@ -260,13 +222,6 @@ public interface ICertificateAuthority extends ISubsystem {
      */
     public void deleteCRLIssuingPoint(IConfigStore crlSubStore, String id);
 
-    /**
-     * Retrieves the CRL repository.
-     *
-     * @return CA's CRL repository
-     */
-    public ICRLRepository getCRLRepository();
-
     /**
      * Retrieves the Replica ID repository.
      *
@@ -274,13 +229,6 @@ public interface ICertificateAuthority extends ISubsystem {
      */
     public IReplicaIDRepository getReplicaRepository();
 
-    /**
-     * Retrieves the request in queue listener.
-     *
-     * @return the request in queue listener
-     */
-    public IRequestListener getRequestInQListener();
-
     /**
      * Retrieves all request listeners.
      *
@@ -288,20 +236,6 @@ public interface ICertificateAuthority extends ISubsystem {
      */
     public Enumeration<String> getRequestListenerNames();
 
-    /**
-     * Retrieves the request listener for issued certificates.
-     *
-     * @return the request listener for issued certificates
-     */
-    public IRequestListener getCertIssuedListener();
-
-    /**
-     * Retrieves the request listener for revoked certificates.
-     *
-     * @return the request listener for revoked certificates
-     */
-    public IRequestListener getCertRevokedListener();
-
     /**
      * Retrieves the CA certificate chain.
      *
@@ -454,21 +388,6 @@ public interface ICertificateAuthority extends ISubsystem {
     public X509CertImpl sign(X509CertInfo certInfo, String algname)
             throws EBaseException;
 
-    /**
-     * Retrieves the default certificate version.
-     *
-     * @return the default version certificate
-     */
-    public CertificateVersion getDefaultCertVersion();
-
-    /**
-     * Is this CA allowed to issue certificate that has longer
-     * validty than the CA's.
-     *
-     * @return true if allows certificates to have validity longer than CA's
-     */
-    public boolean isEnablePastCATime();
-
     /**
      * Retrieves the CA service object that is responsible for
      * processing requests.
@@ -477,13 +396,6 @@ public interface ICertificateAuthority extends ISubsystem {
      */
     public IService getCAService();
 
-    /**
-     * Retrieves the DB subsystem managing internal data storage.
-     *
-     * @return DB subsystem object
-     */
-    public IDBSubsystem getDBSubsystem();
-
     /**
      * Returns the in-memory count of the processed OCSP requests.
      *
@@ -518,11 +430,6 @@ public interface ICertificateAuthority extends ISubsystem {
     public CertificateIssuerName getIssuerObj();
     public CertificateSubjectName getSubjectObj();
 
-    /**
-     * Enumerate all authorities, including host authority.
-     */
-    public List<ICertificateAuthority> getCAs();
-
     /**
      * Return whether this CA is the host authority (not a
      * lightweight authority).
@@ -559,44 +466,6 @@ public interface ICertificateAuthority extends ISubsystem {
      */
     public String getAuthorityDescription();
 
-    /**
-     * Get the CA by ID.  Returns null if CA not found.
-     */
-    public ICertificateAuthority getCA(AuthorityID aid);
-
-    /**
-     * Get the CA by DN.  Returns null if CA not found.
-     */
-    public ICertificateAuthority getCA(X500Name dn);
-
-    /**
-     * Create a new sub-CA under the specified parent CA.
-     */
-    public ICertificateAuthority createCA(
-            IAuthToken authToken,
-            String dn, AuthorityID parentAID, String desc)
-        throws EBaseException;
-
-    /**
-     * Create a new sub-CA IMMEDIATELY beneath this one.
-     *
-     * This method DOES NOT add the new CA to caMap; it is the
-     * caller's responsibility.
-     */
-    public ICertificateAuthority createSubCA(
-            IAuthToken authToken,
-            String dn, String desc)
-        throws EBaseException;
-
-    /**
-     * Update authority configurables.
-     *
-     * @param enabled Whether CA is enabled or disabled
-     * @param desc Description; null or empty removes it
-     */
-    public void modifyAuthority(Boolean enabled, String desc)
-        throws EBaseException;
-
     /**
      * Renew certificate of CA.
      */
