@@ -28,6 +28,11 @@ public class CACLI extends CLI {
     public CACLI(CLI parent) {
         super("ca", "CA subsystem management commands", parent);
 
+        addModule(new CACertCLI(this));
         addModule(new CADBCLI(this));
+        addModule(new SubsystemGroupCLI(this));
+        addModule(new CAProfileCLI(this));
+        addModule(new SubsystemRangeCLI(this));
+        addModule(new SubsystemUserCLI(this));
     }
 }
