@@ -29,5 +29,8 @@ public class KRACLI extends CLI {
         super("kra", "KRA subsystem management commands", parent);
 
         addModule(new SubsystemDBCLI(this));
+        addModule(new SubsystemGroupCLI(this));
+        addModule(new SubsystemRangeCLI(this));
+        addModule(new SubsystemUserCLI(this));
     }
 }
