@@ -29,5 +29,7 @@ public class OCSPCLI extends CLI {
         super("ocsp", "OCSP subsystem management commands", parent);
 
         addModule(new SubsystemDBCLI(this));
+        addModule(new SubsystemGroupCLI(this));
+        addModule(new SubsystemUserCLI(this));
     }
 }
