@@ -29,5 +29,7 @@ public class TPSCLI extends CLI {
         super("tps", "TPS subsystem management commands", parent);
 
         addModule(new SubsystemDBCLI(this));
+        addModule(new SubsystemGroupCLI(this));
+        addModule(new SubsystemUserCLI(this));
     }
 }
