@@ -4,7 +4,6 @@ import java.net.URI;
 import java.security.InvalidKeyException;
 import java.security.Principal;
 import java.security.cert.X509Certificate;
-import java.util.Arrays;
 import java.util.Collection;
 import java.util.Iterator;
 import java.util.List;
@@ -12,8 +11,10 @@ import java.util.TreeSet;
 
 import javax.ws.rs.core.Response;
 
-import org.apache.commons.lang.ArrayUtils;
-import org.apache.commons.lang.StringUtils;
+import org.apache.commons.lang3.StringUtils;
+import org.dogtagpki.server.tks.TKSEngine;
+import org.dogtagpki.server.tks.TKSEngineConfig;
+import org.dogtagpki.server.tks.TPSConnectorConfig;
 import org.jboss.resteasy.plugins.providers.atom.Link;
 import org.mozilla.jss.NotInitializedException;
 import org.mozilla.jss.crypto.SymmetricKey;
@@ -30,22 +31,17 @@ import com.netscape.certsrv.system.TPSConnectorCollection;
 import com.netscape.certsrv.system.TPSConnectorData;
 import com.netscape.certsrv.system.TPSConnectorResource;
 import com.netscape.certsrv.tps.cert.TPSCertResource;
-import com.netscape.certsrv.usrgrp.IUser;
 import com.netscape.cms.servlet.base.PKIService;
-import com.netscape.cmscore.apps.CMS;
-import com.netscape.cmscore.apps.CMSEngine;
-import com.netscape.cmscore.apps.EngineConfig;
 import com.netscape.cmscore.usrgrp.UGSubsystem;
+import com.netscape.cmscore.usrgrp.User;
 import com.netscape.cmsutil.crypto.CryptoUtil;
 
 public class TPSConnectorService extends PKIService implements TPSConnectorResource {
 
     public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(TPSConnectorService.class);
 
-    private static final String TPS_LIST = "tps.list";
-
-    CMSEngine engine = CMS.getCMSEngine();
-    EngineConfig cs = engine.getConfig();
+    TKSEngine engine = TKSEngine.getInstance();
+    TKSEngineConfig cs = engine.getConfig();
 
     public UGSubsystem userGroupManager = engine.getUGSubsystem();
 
@@ -58,8 +54,8 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
             start = start == null ? 0 : start;
             size = size == null ? DEFAULT_SIZE : size;
 
-            String tpsList = cs.getString(TPS_LIST, "");
-            Iterator<String> entries = Arrays.asList(StringUtils.split(tpsList, ",")).iterator();
+            Collection<String> tpsList = cs.getTPSConnectorIDs();
+            Iterator<String> entries = tpsList.iterator();
 
             TPSConnectorCollection response = new TPSConnectorCollection();
             int i = 0;
@@ -108,12 +104,14 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
 
     private TPSConnectorData createTPSConnectorData(String tpsID) throws EBaseException {
 
+        TPSConnectorConfig tpsConfig = cs.getTPSConnectorConfig(tpsID);
+
         TPSConnectorData data = new TPSConnectorData();
         data.setID(tpsID);
-        data.setHost(cs.getString("tps." + tpsID + ".host", ""));
-        data.setPort(cs.getString("tps." + tpsID + ".port", ""));
-        data.setUserID(cs.getString("tps." + tpsID + ".userid", ""));
-        data.setNickname(cs.getString("tps." + tpsID + ".nickname", ""));
+        data.setHost(tpsConfig.getHost());
+        data.setPort(tpsConfig.getPort());
+        data.setUserID(tpsConfig.getUserID());
+        data.setNickname(tpsConfig.getNickname());
 
         URI uri = uriInfo.getBaseUriBuilder().path(TPSCertResource.class).path("{id}").build(tpsID);
         data.setLink(new Link("self", uri));
@@ -229,16 +227,17 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
             logger.warn("TPSConnectorService: Attempt to save tps connection with null or empty id");
             return;
         }
-        String prefix = "tps." + id + ".";
+
+        TPSConnectorConfig tpsConfig = cs.getTPSConnectorConfig(id);
 
         if (newData.getHost() != null)
-            cs.putString(prefix + "host", newData.getHost());
+            tpsConfig.setHost(newData.getHost());
         if (newData.getPort() != null)
-            cs.putString(prefix + "port", newData.getPort());
+            tpsConfig.setPort(newData.getPort());
         if (newData.getUserID() != null)
-            cs.putString(prefix + "userid", newData.getUserID());
+            tpsConfig.setUserID(newData.getUserID());
         if (newData.getNickname() != null)
-            cs.putString(prefix + "nickname", newData.getNickname());
+            tpsConfig.setNickname(newData.getNickname());
     }
 
     @Override
@@ -254,7 +253,7 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
                 return createNoContentResponse();
 
             deleteSharedSecret(id);
-            cs.removeSubStore("tps." + id);
+            cs.removeTPSConnectorConfig(id);
             removeFromConnectorList(id);
             cs.commit(true);
 
@@ -305,7 +304,7 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
             String userid = validateUser(id);
 
             // get user cert
-            IUser user = userGroupManager.getUser(userid);
+            User user = userGroupManager.getUser(userid);
 
             logger.debug("TPSConnectorService.createSharedSecret.userid: " + userid);
             X509Certificate[] certs = user.getX509Certificates();
@@ -319,7 +318,8 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
 
             CryptoUtil.createSharedSecret(nickname);
 
-            cs.putString("tps." + id + ".nickname", nickname);
+            TPSConnectorConfig tpsConfig = cs.getTPSConnectorConfig(id);
+            tpsConfig.setNickname(nickname);
             cs.commit(true);
 
             //Create des3 session sym key to wrap the shared secret.
@@ -347,7 +347,8 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
     }
 
     private String validateUser(String id) throws EBaseException {
-        String userid = cs.getString("tps." + id + ".userid", "");
+        TPSConnectorConfig tpsConfig = cs.getTPSConnectorConfig(id);
+        String userid = tpsConfig.getUserID();
         if (userid.isEmpty()) {
             throw new PKIException("Bad TPS connection configuration: userid not defined");
         }
@@ -386,7 +387,7 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
             }
 
             // get user cert
-            IUser user = userGroupManager.getUser(userid);
+            User user = userGroupManager.getUser(userid);
             X509Certificate[] certs = user.getX509Certificates();
 
             CryptoUtil.deleteSharedSecret(nickname);
@@ -429,8 +430,10 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
                 throw new ResourceNotFoundException("TPS connection does not exist");
             }
 
+            TPSConnectorConfig tpsConfig = cs.getTPSConnectorConfig(id);
+
             // get user
-            String userid = cs.getString("tps." + id + ".userid", "");
+            String userid = tpsConfig.getUserID();
             if (userid.isEmpty()) {
                 throw new PKIException("Bad TPS connection configuration: userid not defined");
             }
@@ -441,7 +444,7 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
             }
             CryptoUtil.deleteSharedSecret(nickname);
 
-            cs.putString("tps." + id + ".nickname", "");
+            tpsConfig.setNickname("");
             cs.commit(true);
 
             return createNoContentResponse();
@@ -475,7 +478,7 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
             }
 
             // get user cert
-            IUser user = userGroupManager.getUser(userid);
+            User user = userGroupManager.getUser(userid);
             X509Certificate[] certs = user.getX509Certificates();
 
             //Create des3 session sym key to wrap the shared secrt.
@@ -502,13 +505,13 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
     }
 
     private boolean connectorExists(String id) throws EBaseException {
-        String tpsList = cs.getString(TPS_LIST, "");
-        return ArrayUtils.contains(StringUtils.split(tpsList, ","), id);
+        Collection<String> tpsList = cs.getTPSConnectorIDs();
+        return tpsList.contains(id);
     }
 
     private String getConnectorID(String host, String port) throws EBaseException {
-        String tpsList = cs.getString(TPS_LIST, "");
-        for (String tpsID : StringUtils.split(tpsList, ",")) {
+        Collection<String> tpsList = cs.getTPSConnectorIDs();
+        for (String tpsID : tpsList) {
             TPSConnectorData data = createTPSConnectorData(tpsID);
             if (data.getHost().equals(host) && data.getPort().equals(port))
                 return tpsID;
@@ -517,25 +520,25 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
     }
 
     private void addToConnectorList(String id) throws EBaseException {
-        String tpsList = cs.getString(TPS_LIST, "");
+        Collection<String> tpsList = cs.getTPSConnectorIDs();
         Collection<String> sorted = new TreeSet<String>();
-        sorted.addAll(Arrays.asList(StringUtils.split(tpsList, ",")));
+        sorted.addAll(tpsList);
         sorted.add(id);
-        cs.putString(TPS_LIST, StringUtils.join(sorted, ","));
+        cs.setTPSConnectorIDs(sorted);
     }
 
     private void removeFromConnectorList(String id) throws EBaseException {
-        String tpsList = cs.getString(TPS_LIST, "");
+        Collection<String> tpsList = cs.getTPSConnectorIDs();
         Collection<String> sorted = new TreeSet<String>();
-        sorted.addAll(Arrays.asList(StringUtils.split(tpsList, ",")));
+        sorted.addAll(tpsList);
         sorted.remove(id);
-        cs.putString(TPS_LIST, StringUtils.join(sorted, ","));
+        cs.setTPSConnectorIDs(sorted);
     }
 
     private String findNextConnectorID() throws EBaseException {
-        String tpsList = cs.getString(TPS_LIST, "");
+        Collection<String> tpsList = cs.getTPSConnectorIDs();
         Collection<String> sorted = new TreeSet<String>();
-        sorted.addAll(Arrays.asList(StringUtils.split(tpsList, ",")));
+        sorted.addAll(tpsList);
 
         int index = 0;
         while (sorted.contains(Integer.toString(index)))
