@@ -18,14 +18,16 @@
 
 package org.dogtagpki.server.tps;
 
-import com.netscape.certsrv.base.EBaseException;
+import javax.servlet.ServletContextListener;
+import javax.servlet.annotation.WebListener;
+
 import com.netscape.cmscore.apps.CMS;
 import com.netscape.cmscore.apps.CMSEngine;
 import com.netscape.cmscore.apps.EngineConfig;
 import com.netscape.cmscore.base.ConfigStorage;
-import com.netscape.cmscore.selftests.SelfTestSubsystem;
 
-public class TPSEngine extends CMSEngine {
+@WebListener
+public class TPSEngine extends CMSEngine implements ServletContextListener {
 
     public TPSEngine() throws Exception {
         super("TPS");
@@ -46,16 +48,4 @@ public class TPSEngine extends CMSEngine {
     public TPSConfigurator createConfigurator() throws Exception {
         return new TPSConfigurator(this);
     }
-
-    protected void loadSubsystems() throws EBaseException {
-
-        super.loadSubsystems();
-
-        if (isPreOpMode()) {
-            // Disable some subsystems before database initialization
-            // in pre-op mode to prevent misleading exceptions.
-
-            setSubsystemEnabled(SelfTestSubsystem.ID, false);
-        }
-    }
 }
