@@ -40,8 +40,6 @@ import org.mozilla.jss.netscape.security.x509.X509CertImpl;
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.dbs.EDBRecordNotFoundException;
 import com.netscape.certsrv.tps.token.TokenStatus;
-import com.netscape.cmscore.apps.CMS;
-import com.netscape.cmscore.apps.CMSEngine;
 import com.netscape.cmscore.apps.EngineConfig;
 
 /*
@@ -243,16 +241,62 @@ public class TPSTokendb {
 
         logger.debug(method + " found token " + cuid);
         logger.debug(method + " number of certs to update:" + certs.size());
+
+	// Keep track of which certs made it to the database and which didn't,
+        // in case of failure
+         class CnIssuerPair {
+             public final String cn;
+             public final String issuer;
+
+             public CnIssuerPair(String _cn, String _issuer) {
+                 cn = _cn;
+                 issuer = _issuer;
+             }
+
+             public String toString() {
+                 return "(cn=" + cn + ", issuerCn=" + issuer + ")";
+             }
+         }
+
+         ArrayList<CnIssuerPair> cnIssuerPairsRemaining = new ArrayList<CnIssuerPair>(certs.size());
+         for(TPSCertRecord cert : certs) {
+             String cn = cert.getId();
+             String issuerCn = cert.getIssuedBy();
+             cnIssuerPairsRemaining.add(new CnIssuerPair(cn, issuerCn));
+         }
+
+        boolean testAddCertsFailure = false;
+	//Contrive a very difficult to reproduce testing scenario
+        org.dogtagpki.server.tps.TPSEngine engine = org.dogtagpki.server.tps.TPSEngine.getInstance();
+	try {
+	    EngineConfig configStore = engine.getConfig();
+            // get conn ID
+            String config = "op.enroll." + "testAddCertsToDBFailure";
+            testAddCertsFailure = configStore.getBoolean(config,false);
+        } catch (Exception e) {
+           testAddCertsFailure = false;
+        }
+
         try {
+	    int count = 0;
             for (TPSCertRecord cert : certs) {
                 try {
                     if (!isCertOnToken(cert, cuid)) {
                         logger.debug(method + " adding cert with serial: " + cert.getSerialNumber());
+			// After at least one cert is added correctly, perform the test of a failure
+                        // if so configured.
+                        if(count > 0 && testAddCertsFailure == true) {
+                            throw new Exception(method + ": "+ "Failed to add certificate to token db, as part of a test of failure condition.");
+                        }
                         tps.certDatabase.addRecord(cert.getId(), cert);
                     } else {
                         // cert already on token
                         logger.debug(method + "retain and skip adding with serial:" + cert.getSerialNumber());
                     }
+		    // Successfully added cert or verified it was already there, so remove
+                    // it from the 'remaining' list
+                    cnIssuerPairsRemaining.removeIf(p -> (p.cn == cert.getId() && p.issuer == cert.getIssuedBy()));
+                    count ++ ;
                 } catch (Exception e) {
                     logger.warn(method + "Exception after isCertOnToken call: "+ e.getMessage(), e);
                     // ignore; go to next;
@@ -260,8 +304,13 @@ public class TPSTokendb {
             }
         } catch (Exception e) {
             logger.error(method + e.getMessage(), e);
-            // TODO: what if it throws in the middle of the cert list -- some cert records already updated?
-            throw new TPSException(e.getMessage(), e);
+	     String subjectDn = certs.get(0).getSubject();
+             String logMsg = method + ": " + "Failed to add or verify the following certs for [" + subjectDn + "] in the Certificate DB: ";
+             for(CnIssuerPair pair : cnIssuerPairsRemaining) {
+                 logMsg += pair + "; ";
+             }
+
+             throw new TPSException(logMsg);
         }
     }
 
@@ -571,7 +620,7 @@ public class TPSTokendb {
 
         logger.debug(method + "begins: tokenReason=" + tokenReason);
 
-        CMSEngine engine = CMS.getCMSEngine();
+        org.dogtagpki.server.tps.TPSEngine engine = org.dogtagpki.server.tps.TPSEngine.getInstance();
         try {
 
             EngineConfig configStore = engine.getConfig();
@@ -637,7 +686,7 @@ public class TPSTokendb {
         String method = "TPSTokendb.unrevokeCert";
         String logMsg;
 
-        CMSEngine engine = CMS.getCMSEngine();
+        org.dogtagpki.server.tps.TPSEngine engine = org.dogtagpki.server.tps.TPSEngine.getInstance();
         try {
             EngineConfig configStore = engine.getConfig();
 
@@ -692,7 +741,7 @@ public class TPSTokendb {
 
         String method = "TPSTokendb.checkShouldRevoke:";
         String msg = "";
-        CMSEngine engine = CMS.getCMSEngine();
+        org.dogtagpki.server.tps.TPSEngine engine = org.dogtagpki.server.tps.TPSEngine.getInstance();
         EngineConfig configStore = engine.getConfig();
 
         if (cert == null) {
