@@ -19,12 +19,11 @@ package org.dogtagpki.server.tps.authentication;
 
 import java.util.HashMap;
 
-import org.dogtagpki.server.authentication.IAuthManager;
-import org.dogtagpki.server.authentication.IAuthSubsystem;
+import org.dogtagpki.server.authentication.AuthManager;
+import org.dogtagpki.server.tps.TPSEngine;
 
 import com.netscape.certsrv.base.EBaseException;
-import com.netscape.cmscore.apps.CMS;
-import com.netscape.cmscore.apps.CMSEngine;
+import com.netscape.cmscore.authentication.AuthSubsystem;
 
 /**
  * Authentication is a class for an authentication instance
@@ -33,7 +32,6 @@ import com.netscape.cmscore.apps.CMSEngine;
  */
 public class TPSAuthenticator {
     private String id;
-    private IAuthManager authManager;
 
     /*
      *  for auths instance ui <locale, value>
@@ -71,10 +69,6 @@ public class TPSAuthenticator {
     public TPSAuthenticator(String authId)
             throws EBaseException {
         id = authId;
-        // retrieves and set authentication manager
-        CMSEngine engine = CMS.getCMSEngine();
-        IAuthSubsystem authSub = (IAuthSubsystem) engine.getSubsystem(IAuthSubsystem.ID);
-        authManager = authSub.getAuthManager(authId);
         uiTitle = new HashMap<String, String>();
         uiDescription = new HashMap<String, String>();
         uiParameters = new HashMap<String, AuthUIParameter>();
@@ -86,8 +80,10 @@ public class TPSAuthenticator {
         return id;
     }
 
-    public IAuthManager getAuthManager() {
-        return authManager;
+    public AuthManager getAuthManager() {
+        TPSEngine engine = TPSEngine.getInstance();
+        AuthSubsystem authSub = engine.getAuthSubsystem();
+        return authSub.getAuthManager(id);
     }
 
     public void setUiTitle(String locale, String title) {
