@@ -7,7 +7,7 @@ dscreate create-template ds.tmp
 sed \
     -e 's/;root_password = .*/root_password = Secret.123/g' \
     -e 's/;suffix = .*/suffix = dc=example,dc=com/g' \
-    -e 's/;instance_name = .*/instance_name = pkitest/g' \
+    -e 's/;instance_name = .*/instance_name = localhost/g' \
     ds.tmp > ds.inf
 
 dscreate from-file ds.inf
