@@ -7,6 +7,8 @@ CLIENT_DIR_PASSWORD = 'SECret.123'
 BACKUP_PASSWORD = 'SECret.123'
 CLIENT_DATABASE_PASSWORD = 'SECret.123'
 NSSDB = '/opt/pki/certdb'
+ROOT_CA_CERT_PATH = '/tmp/rootCA.pem'
+
 #CA Instance
 CA_HTTPS_PORT = 'capki_https_port'
 CA_HTTP_PORT = 'capki_http_port'
@@ -28,6 +30,7 @@ KRA_TOMCAT_PORT = 'krapki_tomcat_server_port'
 KRA_PASSWORD = 'SECret.123'
 KRA_CLIENT_DIR = '/opt/topology-KRA'
 KRA_ADMIN_NICK = 'PKI KRA Administrator for Example.Org'
+KRA_ADMIN_USERNAME = 'kraadmin'
 #OCSP Instance
 OCSP_INSTANCE_NAME = 'topology-OCSP'
 OCSP_HTTPS_PORT = 'ocsppki_https_port'
@@ -37,6 +40,7 @@ OCSP_TOMCAT_PORT = 'ocsppki_tomcat_server_port'
 OCSP_PASSWORD = 'SECret.123'
 OCSP_CLIENT_DIR = '/opt/topology-OCSP'
 OCSP_ADMIN_NICK = 'PKI OCSP Administrator for Example.Org'
+OCSP_ADMIN_USERNAME = 'ocspadmin'
 #TKS Instance
 TKS_INSTANCE_NAME = 'topology-TKS'
 TKS_HTTPS_PORT = 'tkspki_https_port'
@@ -46,6 +50,7 @@ TKS_TOMCAT_PORT = 'tkspki_tomcat_server_port'
 TKS_PASSWORD = 'SECret.123'
 TKS_CLIENT_DIR = '/opt/topology-TKS'
 TKS_ADMIN_NICK = 'PKI TKS Administrator for Example.Org'
+TKS_ADMIN_USERNAME = 'tksadmin'
 #TPS instance
 TPS_INSTANCE_NAME = 'topology-TPS'
 TPS_HTTPS_PORT = 'tpspki_https_port'
@@ -55,8 +60,11 @@ TPS_TOMCAT_PORT = 'tpspki_tomcat_server_port'
 TPS_PASSWORD = 'SECret.123'
 TPS_CLIENT_DIR = '/opt/topology-TPS'
 TPS_ADMIN_NICK = 'PKI TPS Administrator for Example.Org'
+TPS_ADMIN_USERNAME = 'tpsadmin'
 #LDAP Details
 LDAP_PORT = 'ldapServerPort'
+LDAPS_PORT = 'ldapSecureServerPort'
+LDAP_SECURE_CON_PEM_FILE = 'ldapSecreConPemFile'
 LDAP_BIND_DN = 'cn=Directory Manager'
 LDAP_PASSWD = 'SECret.123'
 LDAP_BASE_DN = 'dc=example,dc=org'
@@ -74,4 +82,29 @@ LDAP_USER1 = 'jdoe'
 TOKEN_FORMAT = 'ra_format'
 TOKEN_RESET_PIN = 'ra_reset_pin'
 TOKEN_CUID = '40000000000000000002'
-ACME_CONFIG_PATH = '/usr/share/pki/acme'
\ No newline at end of file
+
+
+# SubCA details
+SUBCA_INSTANCE_NAME = 'topology-SubCA'
+SUBCA_CA_INSTANCE_NAME = 'topology-CA'
+SUBCA_KRA_INSTANCE_NAME = 'topology-KRA'
+SUBCA_HTTPS_PORT = 'subpki_https_port'
+SUBCA_HTTP_PORT = 'subpki_http_port'
+SUBCA_AJP_PORT = 'subpki_ajp_port'
+SUBCA_TOMCAT_PORT = 'subpki_tomcat_port'
+SUBCA_PASSWORD = 'SECret.123'
+SUBCA_KRA_HTTPS_PORT = '19443'
+SUBCA_KRA_HTTP_PORT = '19080'
+SUBCA_KRA_AJP_PORT = '19009'
+SUBCA_KRA_TOMCAT_PORT = '19005'
+SUBCA_ADMIN_NICK = 'PKI Administrator for example.com'
+SUBCA_SECURITY_DOMAIN_NAME = 'SUBORDINATE'
+
+
+PROTOCOL_SECURE = 'https'
+PROTOCOL_UNSECURE = 'http'
+ACME_CONFIG_PATH = '/usr/share/pki/acme'
+POSTGRES_USER = 'acme'
+POSTGRES_PASSWORD = 'Secret.123'
+POSTGRES_DB = 'acme'
+POSTGRES_PORT = '5432'
